#line 3 "src/gigatron.md"

/*
#   Copyright (c) 2021, LB3361
#
#    Redistribution and use in source and binary forms, with or
#    without modification, are permitted provided that the following
#    conditions are met:
#
#    1.  Redistributions of source code must retain the above copyright
#        notice, this list of conditions and the following disclaimer.
#
#    2. Redistributions in binary form must reproduce the above
#       copyright notice, this list of conditions and the following
#       disclaimer in the documentation and/or other materials
#       provided with the distribution.
#
#    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
#    CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
#    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#    MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
#    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
#    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
#    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
#    TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
#    ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
#    OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
#    POSSIBILITY OF SUCH DAMAGE.
*/


/*---- BEGIN HEADER --*/

#include "c.h"
#include <ctype.h>
#include <math.h>

#define NODEPTR_TYPE Node
#define OP_LABEL(p) ((p)->op)
#define LEFT_CHILD(p) ((p)->kids[0])
#define RIGHT_CHILD(p) ((p)->kids[1])
#define STATE_LABEL(p) ((p)->x.state)

static void address(Symbol, Symbol, long);
static void blkfetch(/* int, int, int, int */) {}
static void blkloop(/* int, int, int, int, int, int[] */) {}
static void blkstore(/* int, int, int, int */) {}
static void defaddress(Symbol);
static void defconst(int, int, Value);
static void defstring(int, char *);
static void defsymbol(Symbol);
static void doarg(Node);
static void emit2(/* Node */) {}
static void emit3(const char*, Node, Node*, short*);
static void myemitfmt(const char*, Node, Node*, short*);
static void export(Symbol);
static void clobber(Node);
static void preralloc(Node);
static void function(Symbol, Symbol [], Symbol [], int);
static void global(Symbol);
static void import(Symbol);
static void local(Symbol);
static void progbeg(int, char **);
static void progend(void);
static void segment(int);
static void space(int);
static void target(Node);

/* string lists */
typedef struct slist *SList;
struct slist { SList prev; SList next; char s[1]; };
static struct slist lhead = { &lhead, &lhead, 0 };
static void lprint(const char *fmt, ...);

static int in_function = 0;
static struct slist xhead = { &xhead, &xhead, 0 };
static void xprint_init(void);
static void xprint(const char *fmt, ...);
static void xprint_finish(void);


/* Cost functions */
static int  if_zpconst(Node);
static int  if_zpglobal(Node);
static int  if_rmw(Node,int);
static int  if_not_asgn_tmp(Node,int);
static int  if_cv_from(Node,int,int);
static int  if_arg_reg_only(Node);
static int  if_arg_stk(Node);

#define mincpu5(cost) ((cpu<5)?LBURG_MAX:(cost))
#define mincpu6(cost) ((cpu<6)?LBURG_MAX:(cost))
#define if_spill(cost) ((spilling)?cost:LBURG_MAX)

/* Registers */
static Symbol ireg[32], lreg[32], freg[32];
static Symbol iregw, lregw, fregw;

#define REGMASK_SAVED           0x000000ff
#define REGMASK_ARGS            0x0000ff00
#define REGMASK_MOREVARS        0x000fffff
#define REGMASK_TEMPS           0x007fff00

/* Misc */
static int codenum = 0;
static int cseg = 0;
static int cpu = 5;


/*---- END HEADER --*/
#line 114 "build/gigatron.c"
/*
generated at Sat Mar 19 20:12:13 2022
by $Id$
*/
static void _kids(NODEPTR_TYPE, int, NODEPTR_TYPE[]);
static void _label(NODEPTR_TYPE);
static int _rule(void*, int);

#define _stmt_NT 1
#define _reg_NT 2
#define _conBs_NT 3
#define _conB_NT 4
#define _con_NT 5
#define _con0_NT 6
#define _con1_NT 7
#define _con1n_NT 8
#define _zddr_NT 9
#define _conBn_NT 10
#define _addr_NT 11
#define _lddr_NT 12
#define _ac_NT 13
#define _ac0_NT 14
#define _eac_NT 15
#define _eac0_NT 16
#define _iarg_NT 17
#define _spill_NT 18
#define _vdst_NT 19
#define _asrc_NT 20
#define _lsrc_NT 21
#define _lac_NT 22
#define _larg_NT 23
#define _fac_NT 24
#define _farg_NT 25
#define _rmw_NT 26

static char *_ntname[] = {
	0,
	"stmt",
	"reg",
	"conBs",
	"conB",
	"con",
	"con0",
	"con1",
	"con1n",
	"zddr",
	"conBn",
	"addr",
	"lddr",
	"ac",
	"ac0",
	"eac",
	"eac0",
	"iarg",
	"spill",
	"vdst",
	"asrc",
	"lsrc",
	"lac",
	"larg",
	"fac",
	"farg",
	"rmw",
	0
};

struct _state {
	short cost[27];
	struct {
		unsigned int _stmt:8;
		unsigned int _reg:6;
		unsigned int _conBs:2;
		unsigned int _conB:3;
		unsigned int _con:3;
		unsigned int _con0:3;
		unsigned int _con1:3;
		unsigned int _con1n:2;
		unsigned int _zddr:2;
		unsigned int _conBn:1;
		unsigned int _addr:2;
		unsigned int _lddr:2;
		unsigned int _ac:8;
		unsigned int _ac0:3;
		unsigned int _eac:6;
		unsigned int _eac0:3;
		unsigned int _iarg:3;
		unsigned int _spill:1;
		unsigned int _vdst:2;
		unsigned int _asrc:2;
		unsigned int _lsrc:1;
		unsigned int _lac:6;
		unsigned int _larg:2;
		unsigned int _fac:5;
		unsigned int _farg:2;
		unsigned int _rmw:2;
	} rule;
};

static short _nts_0[] = { 0 };
static short _nts_1[] = { _reg_NT, 0 };
static short _nts_2[] = { _conBs_NT, 0 };
static short _nts_3[] = { _conB_NT, 0 };
static short _nts_4[] = { _con_NT, 0 };
static short _nts_5[] = { _zddr_NT, 0 };
static short _nts_6[] = { _addr_NT, 0 };
static short _nts_7[] = { _ac_NT, 0 };
static short _nts_8[] = { _ac0_NT, 0 };
static short _nts_9[] = { _eac_NT, 0 };
static short _nts_10[] = { _eac0_NT, 0 };
static short _nts_11[] = { _lddr_NT, 0 };
static short _nts_12[] = { _spill_NT, 0 };
static short _nts_13[] = { _ac_NT, _iarg_NT, 0 };
static short _nts_14[] = { _iarg_NT, _ac_NT, 0 };
static short _nts_15[] = { _ac_NT, _conB_NT, 0 };
static short _nts_16[] = { _ac_NT, _conBn_NT, 0 };
static short _nts_17[] = { _ac_NT, _con1_NT, 0 };
static short _nts_18[] = { _conB_NT, _ac_NT, 0 };
static short _nts_19[] = { _conBn_NT, _ac_NT, 0 };
static short _nts_20[] = { _conB_NT, _reg_NT, 0 };
static short _nts_21[] = { _conBn_NT, _reg_NT, 0 };
static short _nts_22[] = { _con_NT, _ac_NT, 0 };
static short _nts_23[] = { _ac_NT, _con_NT, 0 };
static short _nts_24[] = { _eac_NT, _conB_NT, 0 };
static short _nts_25[] = { _eac_NT, _conBn_NT, 0 };
static short _nts_26[] = { _eac_NT, _con1_NT, 0 };
static short _nts_27[] = { _conB_NT, _eac_NT, 0 };
static short _nts_28[] = { _eac_NT, _iarg_NT, 0 };
static short _nts_29[] = { _iarg_NT, _eac_NT, 0 };
static short _nts_30[] = { _zddr_NT, _ac_NT, 0 };
static short _nts_31[] = { _ac_NT, _con0_NT, 0 };
static short _nts_32[] = { _asrc_NT, 0 };
static short _nts_33[] = { _addr_NT, _asrc_NT, 0 };
static short _nts_34[] = { _ac_NT, _asrc_NT, 0 };
static short _nts_35[] = { _lddr_NT, _lsrc_NT, 0 };
static short _nts_36[] = { _lac_NT, 0 };
static short _nts_37[] = { _lac_NT, _larg_NT, 0 };
static short _nts_38[] = { _larg_NT, _lac_NT, 0 };
static short _nts_39[] = { _lac_NT, _reg_NT, 0 };
static short _nts_40[] = { _lac_NT, _conB_NT, 0 };
static short _nts_41[] = { _vdst_NT, _lac_NT, 0 };
static short _nts_42[] = { _vdst_NT, _reg_NT, 0 };
static short _nts_43[] = { _fac_NT, 0 };
static short _nts_44[] = { _fac_NT, _farg_NT, 0 };
static short _nts_45[] = { _farg_NT, _fac_NT, 0 };
static short _nts_46[] = { _vdst_NT, _fac_NT, 0 };
static short _nts_47[] = { _spill_NT, _reg_NT, 0 };
static short _nts_48[] = { _ac_NT, _conBs_NT, 0 };
static short _nts_49[] = { _addr_NT, _ac_NT, 0 };
static short _nts_50[] = { _reg_NT, _conB_NT, 0 };
static short _nts_51[] = { _rmw_NT, _rmw_NT, _con1_NT, 0 };
static short _nts_52[] = { _rmw_NT, _rmw_NT, _con1n_NT, 0 };
static short _nts_53[] = { _rmw_NT, _rmw_NT, 0 };
static short _nts_54[] = { _rmw_NT, _conB_NT, 0 };

static short *_nts[] = {
	0,	/* 0 */
	_nts_0,	/* 1 */
	_nts_0,	/* 2 */
	_nts_0,	/* 3 */
	_nts_0,	/* 4 */
	_nts_0,	/* 5 */
	_nts_0,	/* 6 */
	_nts_0,	/* 7 */
	_nts_0,	/* 8 */
	_nts_1,	/* 9 */
	_nts_1,	/* 10 */
	_nts_1,	/* 11 */
	_nts_1,	/* 12 */
	_nts_1,	/* 13 */
	_nts_1,	/* 14 */
	_nts_1,	/* 15 */
	_nts_1,	/* 16 */
	_nts_1,	/* 17 */
	_nts_1,	/* 18 */
	_nts_1,	/* 19 */
	_nts_1,	/* 20 */
	_nts_1,	/* 21 */
	_nts_1,	/* 22 */
	_nts_1,	/* 23 */
	_nts_1,	/* 24 */
	_nts_2,	/* 25 */
	_nts_3,	/* 26 */
	_nts_4,	/* 27 */
	_nts_4,	/* 28 */
	_nts_4,	/* 29 */
	_nts_0,	/* 30 */
	_nts_0,	/* 31 */
	_nts_0,	/* 32 */
	_nts_0,	/* 33 */
	_nts_0,	/* 34 */
	_nts_0,	/* 35 */
	_nts_0,	/* 36 */
	_nts_0,	/* 37 */
	_nts_0,	/* 38 */
	_nts_0,	/* 39 */
	_nts_0,	/* 40 */
	_nts_0,	/* 41 */
	_nts_0,	/* 42 */
	_nts_0,	/* 43 */
	_nts_0,	/* 44 */
	_nts_0,	/* 45 */
	_nts_5,	/* 46 */
	_nts_0,	/* 47 */
	_nts_0,	/* 48 */
	_nts_0,	/* 49 */
	_nts_0,	/* 50 */
	_nts_0,	/* 51 */
	_nts_0,	/* 52 */
	_nts_0,	/* 53 */
	_nts_0,	/* 54 */
	_nts_6,	/* 55 */
	_nts_0,	/* 56 */
	_nts_0,	/* 57 */
	_nts_0,	/* 58 */
	_nts_4,	/* 59 */
	_nts_5,	/* 60 */
	_nts_0,	/* 61 */
	_nts_3,	/* 62 */
	_nts_1,	/* 63 */
	_nts_7,	/* 64 */
	_nts_7,	/* 65 */
	_nts_1,	/* 66 */
	_nts_8,	/* 67 */
	_nts_9,	/* 68 */
	_nts_10,	/* 69 */
	_nts_3,	/* 70 */
	_nts_4,	/* 71 */
	_nts_5,	/* 72 */
	_nts_6,	/* 73 */
	_nts_1,	/* 74 */
	_nts_10,	/* 75 */
	_nts_5,	/* 76 */
	_nts_6,	/* 77 */
	_nts_11,	/* 78 */
	_nts_9,	/* 79 */
	_nts_9,	/* 80 */
	_nts_9,	/* 81 */
	_nts_9,	/* 82 */
	_nts_9,	/* 83 */
	_nts_5,	/* 84 */
	_nts_5,	/* 85 */
	_nts_5,	/* 86 */
	_nts_5,	/* 87 */
	_nts_5,	/* 88 */
	_nts_7,	/* 89 */
	_nts_7,	/* 90 */
	_nts_7,	/* 91 */
	_nts_7,	/* 92 */
	_nts_7,	/* 93 */
	_nts_1,	/* 94 */
	_nts_5,	/* 95 */
	_nts_5,	/* 96 */
	_nts_5,	/* 97 */
	_nts_0,	/* 98 */
	_nts_12,	/* 99 */
	_nts_12,	/* 100 */
	_nts_12,	/* 101 */
	_nts_13,	/* 102 */
	_nts_13,	/* 103 */
	_nts_13,	/* 104 */
	_nts_14,	/* 105 */
	_nts_14,	/* 106 */
	_nts_14,	/* 107 */
	_nts_15,	/* 108 */
	_nts_15,	/* 109 */
	_nts_15,	/* 110 */
	_nts_16,	/* 111 */
	_nts_16,	/* 112 */
	_nts_16,	/* 113 */
	_nts_13,	/* 114 */
	_nts_13,	/* 115 */
	_nts_13,	/* 116 */
	_nts_15,	/* 117 */
	_nts_15,	/* 118 */
	_nts_15,	/* 119 */
	_nts_16,	/* 120 */
	_nts_16,	/* 121 */
	_nts_16,	/* 122 */
	_nts_7,	/* 123 */
	_nts_1,	/* 124 */
	_nts_17,	/* 125 */
	_nts_17,	/* 126 */
	_nts_15,	/* 127 */
	_nts_15,	/* 128 */
	_nts_15,	/* 129 */
	_nts_15,	/* 130 */
	_nts_13,	/* 131 */
	_nts_13,	/* 132 */
	_nts_13,	/* 133 */
	_nts_13,	/* 134 */
	_nts_18,	/* 135 */
	_nts_19,	/* 136 */
	_nts_20,	/* 137 */
	_nts_21,	/* 138 */
	_nts_22,	/* 139 */
	_nts_13,	/* 140 */
	_nts_14,	/* 141 */
	_nts_18,	/* 142 */
	_nts_22,	/* 143 */
	_nts_13,	/* 144 */
	_nts_14,	/* 145 */
	_nts_13,	/* 146 */
	_nts_13,	/* 147 */
	_nts_13,	/* 148 */
	_nts_13,	/* 149 */
	_nts_23,	/* 150 */
	_nts_23,	/* 151 */
	_nts_23,	/* 152 */
	_nts_23,	/* 153 */
	_nts_7,	/* 154 */
	_nts_7,	/* 155 */
	_nts_13,	/* 156 */
	_nts_13,	/* 157 */
	_nts_14,	/* 158 */
	_nts_14,	/* 159 */
	_nts_15,	/* 160 */
	_nts_15,	/* 161 */
	_nts_13,	/* 162 */
	_nts_13,	/* 163 */
	_nts_14,	/* 164 */
	_nts_14,	/* 165 */
	_nts_15,	/* 166 */
	_nts_15,	/* 167 */
	_nts_13,	/* 168 */
	_nts_13,	/* 169 */
	_nts_14,	/* 170 */
	_nts_14,	/* 171 */
	_nts_15,	/* 172 */
	_nts_15,	/* 173 */
	_nts_24,	/* 174 */
	_nts_24,	/* 175 */
	_nts_24,	/* 176 */
	_nts_25,	/* 177 */
	_nts_25,	/* 178 */
	_nts_25,	/* 179 */
	_nts_24,	/* 180 */
	_nts_24,	/* 181 */
	_nts_24,	/* 182 */
	_nts_25,	/* 183 */
	_nts_25,	/* 184 */
	_nts_25,	/* 185 */
	_nts_26,	/* 186 */
	_nts_26,	/* 187 */
	_nts_24,	/* 188 */
	_nts_24,	/* 189 */
	_nts_27,	/* 190 */
	_nts_27,	/* 191 */
	_nts_28,	/* 192 */
	_nts_28,	/* 193 */
	_nts_28,	/* 194 */
	_nts_29,	/* 195 */
	_nts_29,	/* 196 */
	_nts_29,	/* 197 */
	_nts_28,	/* 198 */
	_nts_28,	/* 199 */
	_nts_28,	/* 200 */
	_nts_30,	/* 201 */
	_nts_14,	/* 202 */
	_nts_30,	/* 203 */
	_nts_14,	/* 204 */
	_nts_30,	/* 205 */
	_nts_14,	/* 206 */
	_nts_30,	/* 207 */
	_nts_14,	/* 208 */
	_nts_30,	/* 209 */
	_nts_14,	/* 210 */
	_nts_31,	/* 211 */
	_nts_15,	/* 212 */
	_nts_13,	/* 213 */
	_nts_14,	/* 214 */
	_nts_31,	/* 215 */
	_nts_15,	/* 216 */
	_nts_13,	/* 217 */
	_nts_14,	/* 218 */
	_nts_31,	/* 219 */
	_nts_15,	/* 220 */
	_nts_13,	/* 221 */
	_nts_14,	/* 222 */
	_nts_31,	/* 223 */
	_nts_15,	/* 224 */
	_nts_13,	/* 225 */
	_nts_14,	/* 226 */
	_nts_31,	/* 227 */
	_nts_31,	/* 228 */
	_nts_31,	/* 229 */
	_nts_31,	/* 230 */
	_nts_31,	/* 231 */
	_nts_31,	/* 232 */
	_nts_15,	/* 233 */
	_nts_15,	/* 234 */
	_nts_15,	/* 235 */
	_nts_15,	/* 236 */
	_nts_15,	/* 237 */
	_nts_15,	/* 238 */
	_nts_15,	/* 239 */
	_nts_15,	/* 240 */
	_nts_13,	/* 241 */
	_nts_13,	/* 242 */
	_nts_13,	/* 243 */
	_nts_13,	/* 244 */
	_nts_13,	/* 245 */
	_nts_13,	/* 246 */
	_nts_13,	/* 247 */
	_nts_13,	/* 248 */
	_nts_14,	/* 249 */
	_nts_14,	/* 250 */
	_nts_14,	/* 251 */
	_nts_14,	/* 252 */
	_nts_14,	/* 253 */
	_nts_14,	/* 254 */
	_nts_14,	/* 255 */
	_nts_14,	/* 256 */
	_nts_6,	/* 257 */
	_nts_11,	/* 258 */
	_nts_9,	/* 259 */
	_nts_6,	/* 260 */
	_nts_11,	/* 261 */
	_nts_9,	/* 262 */
	_nts_6,	/* 263 */
	_nts_32,	/* 264 */
	_nts_33,	/* 265 */
	_nts_34,	/* 266 */
	_nts_35,	/* 267 */
	_nts_36,	/* 268 */
	_nts_1,	/* 269 */
	_nts_9,	/* 270 */
	_nts_9,	/* 271 */
	_nts_36,	/* 272 */
	_nts_7,	/* 273 */
	_nts_7,	/* 274 */
	_nts_11,	/* 275 */
	_nts_11,	/* 276 */
	_nts_6,	/* 277 */
	_nts_6,	/* 278 */
	_nts_1,	/* 279 */
	_nts_7,	/* 280 */
	_nts_7,	/* 281 */
	_nts_11,	/* 282 */
	_nts_11,	/* 283 */
	_nts_6,	/* 284 */
	_nts_6,	/* 285 */
	_nts_37,	/* 286 */
	_nts_37,	/* 287 */
	_nts_38,	/* 288 */
	_nts_38,	/* 289 */
	_nts_37,	/* 290 */
	_nts_37,	/* 291 */
	_nts_37,	/* 292 */
	_nts_37,	/* 293 */
	_nts_38,	/* 294 */
	_nts_38,	/* 295 */
	_nts_37,	/* 296 */
	_nts_37,	/* 297 */
	_nts_37,	/* 298 */
	_nts_37,	/* 299 */
	_nts_39,	/* 300 */
	_nts_40,	/* 301 */
	_nts_39,	/* 302 */
	_nts_40,	/* 303 */
	_nts_39,	/* 304 */
	_nts_40,	/* 305 */
	_nts_39,	/* 306 */
	_nts_40,	/* 307 */
	_nts_36,	/* 308 */
	_nts_36,	/* 309 */
	_nts_37,	/* 310 */
	_nts_38,	/* 311 */
	_nts_37,	/* 312 */
	_nts_38,	/* 313 */
	_nts_37,	/* 314 */
	_nts_38,	/* 315 */
	_nts_36,	/* 316 */
	_nts_37,	/* 317 */
	_nts_38,	/* 318 */
	_nts_37,	/* 319 */
	_nts_38,	/* 320 */
	_nts_37,	/* 321 */
	_nts_38,	/* 322 */
	_nts_37,	/* 323 */
	_nts_37,	/* 324 */
	_nts_37,	/* 325 */
	_nts_37,	/* 326 */
	_nts_37,	/* 327 */
	_nts_37,	/* 328 */
	_nts_37,	/* 329 */
	_nts_37,	/* 330 */
	_nts_37,	/* 331 */
	_nts_37,	/* 332 */
	_nts_37,	/* 333 */
	_nts_37,	/* 334 */
	_nts_38,	/* 335 */
	_nts_38,	/* 336 */
	_nts_38,	/* 337 */
	_nts_38,	/* 338 */
	_nts_38,	/* 339 */
	_nts_38,	/* 340 */
	_nts_38,	/* 341 */
	_nts_38,	/* 342 */
	_nts_38,	/* 343 */
	_nts_38,	/* 344 */
	_nts_38,	/* 345 */
	_nts_38,	/* 346 */
	_nts_41,	/* 347 */
	_nts_42,	/* 348 */
	_nts_33,	/* 349 */
	_nts_34,	/* 350 */
	_nts_35,	/* 351 */
	_nts_41,	/* 352 */
	_nts_42,	/* 353 */
	_nts_33,	/* 354 */
	_nts_34,	/* 355 */
	_nts_35,	/* 356 */
	_nts_43,	/* 357 */
	_nts_1,	/* 358 */
	_nts_9,	/* 359 */
	_nts_43,	/* 360 */
	_nts_7,	/* 361 */
	_nts_11,	/* 362 */
	_nts_6,	/* 363 */
	_nts_1,	/* 364 */
	_nts_7,	/* 365 */
	_nts_11,	/* 366 */
	_nts_6,	/* 367 */
	_nts_44,	/* 368 */
	_nts_45,	/* 369 */
	_nts_44,	/* 370 */
	_nts_45,	/* 371 */
	_nts_44,	/* 372 */
	_nts_45,	/* 373 */
	_nts_44,	/* 374 */
	_nts_43,	/* 375 */
	_nts_44,	/* 376 */
	_nts_44,	/* 377 */
	_nts_44,	/* 378 */
	_nts_44,	/* 379 */
	_nts_44,	/* 380 */
	_nts_44,	/* 381 */
	_nts_45,	/* 382 */
	_nts_45,	/* 383 */
	_nts_45,	/* 384 */
	_nts_45,	/* 385 */
	_nts_45,	/* 386 */
	_nts_45,	/* 387 */
	_nts_46,	/* 388 */
	_nts_42,	/* 389 */
	_nts_33,	/* 390 */
	_nts_34,	/* 391 */
	_nts_35,	/* 392 */
	_nts_6,	/* 393 */
	_nts_1,	/* 394 */
	_nts_7,	/* 395 */
	_nts_6,	/* 396 */
	_nts_1,	/* 397 */
	_nts_7,	/* 398 */
	_nts_6,	/* 399 */
	_nts_1,	/* 400 */
	_nts_7,	/* 401 */
	_nts_6,	/* 402 */
	_nts_1,	/* 403 */
	_nts_7,	/* 404 */
	_nts_6,	/* 405 */
	_nts_1,	/* 406 */
	_nts_7,	/* 407 */
	_nts_6,	/* 408 */
	_nts_1,	/* 409 */
	_nts_7,	/* 410 */
	_nts_6,	/* 411 */
	_nts_1,	/* 412 */
	_nts_7,	/* 413 */
	_nts_1,	/* 414 */
	_nts_1,	/* 415 */
	_nts_1,	/* 416 */
	_nts_1,	/* 417 */
	_nts_1,	/* 418 */
	_nts_1,	/* 419 */
	_nts_1,	/* 420 */
	_nts_1,	/* 421 */
	_nts_1,	/* 422 */
	_nts_1,	/* 423 */
	_nts_1,	/* 424 */
	_nts_1,	/* 425 */
	_nts_43,	/* 426 */
	_nts_36,	/* 427 */
	_nts_36,	/* 428 */
	_nts_7,	/* 429 */
	_nts_7,	/* 430 */
	_nts_7,	/* 431 */
	_nts_1,	/* 432 */
	_nts_1,	/* 433 */
	_nts_7,	/* 434 */
	_nts_7,	/* 435 */
	_nts_7,	/* 436 */
	_nts_7,	/* 437 */
	_nts_7,	/* 438 */
	_nts_1,	/* 439 */
	_nts_1,	/* 440 */
	_nts_1,	/* 441 */
	_nts_36,	/* 442 */
	_nts_36,	/* 443 */
	_nts_36,	/* 444 */
	_nts_36,	/* 445 */
	_nts_36,	/* 446 */
	_nts_43,	/* 447 */
	_nts_1,	/* 448 */
	_nts_1,	/* 449 */
	_nts_8,	/* 450 */
	_nts_8,	/* 451 */
	_nts_7,	/* 452 */
	_nts_7,	/* 453 */
	_nts_7,	/* 454 */
	_nts_7,	/* 455 */
	_nts_7,	/* 456 */
	_nts_7,	/* 457 */
	_nts_7,	/* 458 */
	_nts_7,	/* 459 */
	_nts_7,	/* 460 */
	_nts_7,	/* 461 */
	_nts_43,	/* 462 */
	_nts_43,	/* 463 */
	_nts_7,	/* 464 */
	_nts_36,	/* 465 */
	_nts_43,	/* 466 */
	_nts_43,	/* 467 */
	_nts_7,	/* 468 */
	_nts_36,	/* 469 */
	_nts_0,	/* 470 */
	_nts_6,	/* 471 */
	_nts_1,	/* 472 */
	_nts_7,	/* 473 */
	_nts_47,	/* 474 */
	_nts_47,	/* 475 */
	_nts_47,	/* 476 */
	_nts_47,	/* 477 */
	_nts_47,	/* 478 */
	_nts_47,	/* 479 */
	_nts_13,	/* 480 */
	_nts_13,	/* 481 */
	_nts_13,	/* 482 */
	_nts_13,	/* 483 */
	_nts_13,	/* 484 */
	_nts_23,	/* 485 */
	_nts_23,	/* 486 */
	_nts_23,	/* 487 */
	_nts_15,	/* 488 */
	_nts_48,	/* 489 */
	_nts_15,	/* 490 */
	_nts_49,	/* 491 */
	_nts_49,	/* 492 */
	_nts_49,	/* 493 */
	_nts_49,	/* 494 */
	_nts_49,	/* 495 */
	_nts_7,	/* 496 */
	_nts_7,	/* 497 */
	_nts_7,	/* 498 */
	_nts_7,	/* 499 */
	_nts_7,	/* 500 */
	_nts_1,	/* 501 */
	_nts_1,	/* 502 */
	_nts_1,	/* 503 */
	_nts_1,	/* 504 */
	_nts_1,	/* 505 */
	_nts_23,	/* 506 */
	_nts_23,	/* 507 */
	_nts_23,	/* 508 */
	_nts_23,	/* 509 */
	_nts_23,	/* 510 */
	_nts_23,	/* 511 */
	_nts_23,	/* 512 */
	_nts_23,	/* 513 */
	_nts_23,	/* 514 */
	_nts_23,	/* 515 */
	_nts_23,	/* 516 */
	_nts_23,	/* 517 */
	_nts_50,	/* 518 */
	_nts_50,	/* 519 */
	_nts_50,	/* 520 */
	_nts_50,	/* 521 */
	_nts_50,	/* 522 */
	_nts_50,	/* 523 */
	_nts_7,	/* 524 */
	_nts_1,	/* 525 */
	_nts_13,	/* 526 */
	_nts_13,	/* 527 */
	_nts_13,	/* 528 */
	_nts_13,	/* 529 */
	_nts_0,	/* 530 */
	_nts_5,	/* 531 */
	_nts_51,	/* 532 */
	_nts_51,	/* 533 */
	_nts_51,	/* 534 */
	_nts_51,	/* 535 */
	_nts_51,	/* 536 */
	_nts_51,	/* 537 */
	_nts_51,	/* 538 */
	_nts_51,	/* 539 */
	_nts_51,	/* 540 */
	_nts_51,	/* 541 */
	_nts_51,	/* 542 */
	_nts_52,	/* 543 */
	_nts_52,	/* 544 */
	_nts_52,	/* 545 */
	_nts_53,	/* 546 */
	_nts_53,	/* 547 */
	_nts_53,	/* 548 */
	_nts_51,	/* 549 */
	_nts_51,	/* 550 */
	_nts_54,	/* 551 */
	_nts_54,	/* 552 */
	_nts_54,	/* 553 */
	_nts_54,	/* 554 */
	_nts_54,	/* 555 */
};

static char *_templates[] = {
/* 0 */	0,
/* 1 */	"# read register\n",	/* reg: INDIRI1(VREGP) */
/* 2 */	"# read register\n",	/* reg: INDIRU1(VREGP) */
/* 3 */	"# read register\n",	/* reg: INDIRI2(VREGP) */
/* 4 */	"# read register\n",	/* reg: INDIRU2(VREGP) */
/* 5 */	"# read register\n",	/* reg: INDIRP2(VREGP) */
/* 6 */	"# read register\n",	/* reg: INDIRI4(VREGP) */
/* 7 */	"# read register\n",	/* reg: INDIRU4(VREGP) */
/* 8 */	"# read register\n",	/* reg: INDIRF5(VREGP) */
/* 9 */	"# write register\n",	/* stmt: ASGNI1(VREGP,reg) */
/* 10 */	"# write register\n",	/* stmt: ASGNU1(VREGP,reg) */
/* 11 */	"# write register\n",	/* stmt: ASGNI2(VREGP,reg) */
/* 12 */	"# write register\n",	/* stmt: ASGNU2(VREGP,reg) */
/* 13 */	"# write register\n",	/* stmt: ASGNP2(VREGP,reg) */
/* 14 */	"# write register\n",	/* stmt: ASGNI4(VREGP,reg) */
/* 15 */	"# write register\n",	/* stmt: ASGNU4(VREGP,reg) */
/* 16 */	"# write register\n",	/* stmt: ASGNF5(VREGP,reg) */
/* 17 */	"\t%{#alsoVAC}%{src!=vAC:LD(%0);}%{dst!=vAC:ST(%c);}\n",	/* reg: LOADI1(reg) */
/* 18 */	"\t%{#alsoVAC}%{src!=vAC:LD(%0);}%{dst!=vAC:ST(%c);}\n",	/* reg: LOADU1(reg) */
/* 19 */	"\t%{#alsoVAC}%{src!=vAC:LDW(%0);}%{dst!=vAC:STW(%c);}\n",	/* reg: LOADI2(reg) */
/* 20 */	"\t%{#alsoVAC}%{src!=vAC:LDW(%0);}%{dst!=vAC:STW(%c);}\n",	/* reg: LOADU2(reg) */
/* 21 */	"\t%{#alsoVAC}%{src!=vAC:LDW(%0);}%{dst!=vAC:STW(%c);}\n",	/* reg: LOADP2(reg) */
/* 22 */	"\t_LMOV(%0,%c);\n",	/* reg: LOADI4(reg) */
/* 23 */	"\t_LMOV(%0,%c);\n",	/* reg: LOADU4(reg) */
/* 24 */	"\t_FMOV(%0,%c);\n",	/* reg: LOADF5(reg) */
/* 25 */	"\tLDI(%0);%{dst!=vAC:ST(%c);}\n",	/* reg: LOADI1(conBs) */
/* 26 */	"\tLDI(%0);%{dst!=vAC:ST(%c);}\n",	/* reg: LOADU1(conB) */
/* 27 */	"\t_LDI(%0);%{dst!=vAC:STW(%c);}\n",	/* reg: LOADI2(con) */
/* 28 */	"\t_LDI(%0);%{dst!=vAC:STW(%c);}\n",	/* reg: LOADU2(con) */
/* 29 */	"\t_LDI(%0);%{dst!=vAC:STW(%c);}\n",	/* reg: LOADP2(con) */
/* 30 */	"%a",	/* con0: CNSTI1 */
/* 31 */	"%a",	/* con0: CNSTU1 */
/* 32 */	"%a",	/* con0: CNSTI2 */
/* 33 */	"%a",	/* con0: CNSTU2 */
/* 34 */	"%a",	/* con0: CNSTP2 */
/* 35 */	"%a",	/* con1: CNSTI1 */
/* 36 */	"%a",	/* con1: CNSTU1 */
/* 37 */	"%a",	/* con1: CNSTI2 */
/* 38 */	"%a",	/* con1: CNSTU2 */
/* 39 */	"%a",	/* con1n: CNSTI1 */
/* 40 */	"%a",	/* con1n: CNSTI2 */
/* 41 */	"%a",	/* conB: CNSTI2 */
/* 42 */	"%a",	/* conB: CNSTU2 */
/* 43 */	"%a",	/* conB: CNSTP2 */
/* 44 */	"%a",	/* conB: CNSTI1 */
/* 45 */	"%a",	/* conB: CNSTU1 */
/* 46 */	"%0",	/* conB: zddr */
/* 47 */	"%a",	/* conBn: CNSTI2 */
/* 48 */	"%a",	/* conBs: CNSTI2 */
/* 49 */	"%a",	/* conBs: CNSTI1 */
/* 50 */	"%a",	/* con: CNSTI1 */
/* 51 */	"%a",	/* con: CNSTU1 */
/* 52 */	"%a",	/* con: CNSTI2 */
/* 53 */	"%a",	/* con: CNSTU2 */
/* 54 */	"%a",	/* con: CNSTP2 */
/* 55 */	"%0",	/* con: addr */
/* 56 */	"%a+%F",	/* lddr: ADDRLP2 */
/* 57 */	"%a+%F",	/* lddr: ADDRFP2 */
/* 58 */	"%a",	/* addr: ADDRGP2 */
/* 59 */	"%0",	/* addr: con */
/* 60 */	"%0",	/* addr: zddr */
/* 61 */	"%a",	/* zddr: ADDRGP2 */
/* 62 */	"%0",	/* zddr: conB */
/* 63 */	"",	/* stmt: reg */
/* 64 */	"\t%0\n",	/* stmt: ac */
/* 65 */	"\t%{#alsoVAC}%0%{dst!=vAC:STW(%c);}\n",	/* reg: ac */
/* 66 */	"%{src!=vAC:LDW(%0);}",	/* ac: reg */
/* 67 */	"%0",	/* ac: ac0 */
/* 68 */	"%0",	/* ac: eac */
/* 69 */	"%0",	/* ac0: eac0 */
/* 70 */	"LDI(%0);",	/* ac0: conB */
/* 71 */	"_LDI(%0);",	/* ac: con */
/* 72 */	"LDI(%0);",	/* ac: zddr */
/* 73 */	"_LDI(%0);",	/* ac: addr */
/* 74 */	"%{src!=vAC:LDW(%0);}",	/* eac: reg */
/* 75 */	"%0",	/* eac: eac0 */
/* 76 */	"LDI(%0);",	/* eac0: zddr */
/* 77 */	"_LDI(%0);",	/* eac: addr */
/* 78 */	"_SP(%0);",	/* eac: lddr */
/* 79 */	"%0DEEK();",	/* eac: INDIRI2(eac) */
/* 80 */	"%0DEEK();",	/* eac: INDIRU2(eac) */
/* 81 */	"%0DEEK();",	/* eac: INDIRP2(eac) */
/* 82 */	"%0PEEK();",	/* eac0: INDIRI1(eac) */
/* 83 */	"%0PEEK();",	/* eac0: INDIRU1(eac) */
/* 84 */	"LDW(%0);",	/* eac: INDIRI2(zddr) */
/* 85 */	"LDW(%0);",	/* eac: INDIRU2(zddr) */
/* 86 */	"LDW(%0);",	/* eac: INDIRP2(zddr) */
/* 87 */	"LD(%0);",	/* eac0: INDIRI1(zddr) */
/* 88 */	"LD(%0);",	/* eac0: INDIRU1(zddr) */
/* 89 */	"%0DEEK();",	/* ac: INDIRI2(ac) */
/* 90 */	"%0DEEK();",	/* ac: INDIRU2(ac) */
/* 91 */	"%0DEEK();",	/* ac: INDIRP2(ac) */
/* 92 */	"%0PEEK();",	/* ac0: INDIRI1(ac) */
/* 93 */	"%0PEEK();",	/* ac0: INDIRU1(ac) */
/* 94 */	"%0",	/* iarg: reg */
/* 95 */	"%0",	/* iarg: INDIRI2(zddr) */
/* 96 */	"%0",	/* iarg: INDIRU2(zddr) */
/* 97 */	"%0",	/* iarg: INDIRP2(zddr) */
/* 98 */	"%a+%F",	/* spill: ADDRLP2 */
/* 99 */	"T3|STW(T1);_MOV([SP,%0],T3);LDW(T1);",	/* iarg: INDIRU2(spill) */
/* 100 */	"T3|STW(T1);_MOV([SP,%0],T3);LDW(T1);",	/* iarg: INDIRI2(spill) */
/* 101 */	"T3|STW(T1);_MOV([SP,%0],T3);LDW(T1);",	/* iarg: INDIRP2(spill) */
/* 102 */	"%0%[1b]ADDW(%1);",	/* ac: ADDI2(ac,iarg) */
/* 103 */	"%0%[1b]ADDW(%1);",	/* ac: ADDU2(ac,iarg) */
/* 104 */	"%0%[1b]ADDW(%1);",	/* ac: ADDP2(ac,iarg) */
/* 105 */	"%1%[0b]ADDW(%0);",	/* ac: ADDI2(iarg,ac) */
/* 106 */	"%1%[0b]ADDW(%0);",	/* ac: ADDU2(iarg,ac) */
/* 107 */	"%1%[0b]ADDW(%0);",	/* ac: ADDP2(iarg,ac) */
/* 108 */	"%0ADDI(%1);",	/* ac: ADDI2(ac,conB) */
/* 109 */	"%0ADDI(%1);",	/* ac: ADDU2(ac,conB) */
/* 110 */	"%0ADDI(%1);",	/* ac: ADDP2(ac,conB) */
/* 111 */	"%0SUBI(-(%1));",	/* ac: ADDI2(ac,conBn) */
/* 112 */	"%0SUBI(-(%1));",	/* ac: ADDU2(ac,conBn) */
/* 113 */	"%0SUBI(-(%1));",	/* ac: ADDP2(ac,conBn) */
/* 114 */	"%0%[1b]SUBW(%1);",	/* ac: SUBI2(ac,iarg) */
/* 115 */	"%0%[1b]SUBW(%1);",	/* ac: SUBU2(ac,iarg) */
/* 116 */	"%0%[1b]SUBW(%1);",	/* ac: SUBP2(ac,iarg) */
/* 117 */	"%0SUBI(%1);",	/* ac: SUBI2(ac,conB) */
/* 118 */	"%0SUBI(%1);",	/* ac: SUBU2(ac,conB) */
/* 119 */	"%0SUBI(%1);",	/* ac: SUBP2(ac,conB) */
/* 120 */	"%0ADDI(-(%1));",	/* ac: SUBI2(ac,conBn) */
/* 121 */	"%0ADDI(-(%1));",	/* ac: SUBU2(ac,conBn) */
/* 122 */	"%0ADDI(-(%1));",	/* ac: SUBP2(ac,conBn) */
/* 123 */	"%0STW(T3);LDI(0);SUBW(T3);",	/* ac: NEGI2(ac) */
/* 124 */	"LDI(0);SUBW(%0);",	/* ac: NEGI2(reg) */
/* 125 */	"%0LSLW();",	/* ac: LSHI2(ac,con1) */
/* 126 */	"%0LSLW();",	/* ac: LSHU2(ac,con1) */
/* 127 */	"%0_SHLI(%1);",	/* ac: LSHI2(ac,conB) */
/* 128 */	"%0_SHLI(%1);",	/* ac: LSHU2(ac,conB) */
/* 129 */	"%0_SHRIS(%1);",	/* ac: RSHI2(ac,conB) */
/* 130 */	"%0_SHRIU(%1);",	/* ac: RSHU2(ac,conB) */
/* 131 */	"%0%[1b]_SHL(%1);",	/* ac: LSHI2(ac,iarg) */
/* 132 */	"%0%[1b]_SHRS(%1);",	/* ac: RSHI2(ac,iarg) */
/* 133 */	"%0%[1b]_SHL(%1);",	/* ac: LSHU2(ac,iarg) */
/* 134 */	"%0%[1b]_SHRU(%1);",	/* ac: RSHU2(ac,iarg) */
/* 135 */	"%1%{mul0}",	/* ac: MULI2(conB,ac) */
/* 136 */	"%1%{mul0}",	/* ac: MULI2(conBn,ac) */
/* 137 */	"%{mul0%1}",	/* ac: MULI2(conB,reg) */
/* 138 */	"%{mul0%1}",	/* ac: MULI2(conBn,reg) */
/* 139 */	"%1_MULI(%0);",	/* ac: MULI2(con,ac) */
/* 140 */	"%0%[1b]_MUL(%1);",	/* ac: MULI2(ac,iarg) */
/* 141 */	"%1%[0b]_MUL(%0);",	/* ac: MULI2(iarg,ac) */
/* 142 */	"%1%{mul0}",	/* ac: MULU2(conB,ac) */
/* 143 */	"%1_MULI(%0);",	/* ac: MULU2(con,ac) */
/* 144 */	"%0%[1b]_MUL(%1);",	/* ac: MULU2(ac,iarg) */
/* 145 */	"%1%[0b]_MUL(%0);",	/* ac: MULU2(iarg,ac) */
/* 146 */	"%0%[1b]_DIVS(%1);",	/* ac: DIVI2(ac,iarg) */
/* 147 */	"%0%[1b]_DIVU(%1);",	/* ac: DIVU2(ac,iarg) */
/* 148 */	"%0%[1b]_MODS(%1);",	/* ac: MODI2(ac,iarg) */
/* 149 */	"%0%[1b]_MODU(%1);",	/* ac: MODU2(ac,iarg) */
/* 150 */	"%0%[1b]_DIVIS(%1);",	/* ac: DIVI2(ac,con) */
/* 151 */	"%0%[1b]_DIVIU(%1);",	/* ac: DIVU2(ac,con) */
/* 152 */	"%0%[1b]_MODIS(%1);",	/* ac: MODI2(ac,con) */
/* 153 */	"%0%[1b]_MODIU(%1);",	/* ac: MODU2(ac,con) */
/* 154 */	"%0STW(T3);_LDI(-1);XORW(T3);",	/* ac: BCOMI2(ac) */
/* 155 */	"%0STW(T3);_LDI(-1);XORW(T3);",	/* ac: BCOMU2(ac) */
/* 156 */	"%0%[1b]ANDW(%1);",	/* ac: BANDI2(ac,iarg) */
/* 157 */	"%0%[1b]ANDW(%1);",	/* ac: BANDU2(ac,iarg) */
/* 158 */	"%1%[0b]ANDW(%0);",	/* ac: BANDI2(iarg,ac) */
/* 159 */	"%1%[0b]ANDW(%0);",	/* ac: BANDU2(iarg,ac) */
/* 160 */	"%0ANDI(%1);",	/* ac: BANDI2(ac,conB) */
/* 161 */	"%0ANDI(%1);",	/* ac: BANDU2(ac,conB) */
/* 162 */	"%0%[1b]ORW(%1);",	/* ac: BORI2(ac,iarg) */
/* 163 */	"%0%[1b]ORW(%1);",	/* ac: BORU2(ac,iarg) */
/* 164 */	"%1%[0b]ORW(%0);",	/* ac: BORI2(iarg,ac) */
/* 165 */	"%1%[0b]ORW(%0);",	/* ac: BORU2(iarg,ac) */
/* 166 */	"%0ORI(%1);",	/* ac: BORI2(ac,conB) */
/* 167 */	"%0ORI(%1);",	/* ac: BORU2(ac,conB) */
/* 168 */	"%0%[1b]XORW(%1);",	/* ac: BXORI2(ac,iarg) */
/* 169 */	"%0%[1b]XORW(%1);",	/* ac: BXORU2(ac,iarg) */
/* 170 */	"%1%[0b]XORW(%0);",	/* ac: BXORI2(iarg,ac) */
/* 171 */	"%1%[0b]XORW(%0);",	/* ac: BXORU2(iarg,ac) */
/* 172 */	"%0XORI(%1);",	/* ac: BXORI2(ac,conB) */
/* 173 */	"%0XORI(%1);",	/* ac: BXORU2(ac,conB) */
/* 174 */	"%0ADDI(%1);",	/* eac: ADDI2(eac,conB) */
/* 175 */	"%0ADDI(%1);",	/* eac: ADDU2(eac,conB) */
/* 176 */	"%0ADDI(%1);",	/* eac: ADDP2(eac,conB) */
/* 177 */	"%0SUBI(-(%1));",	/* eac: ADDI2(eac,conBn) */
/* 178 */	"%0SUBI(-(%1));",	/* eac: ADDU2(eac,conBn) */
/* 179 */	"%0SUBI(-(%1));",	/* eac: ADDP2(eac,conBn) */
/* 180 */	"%0SUBI(%1);",	/* eac: SUBI2(eac,conB) */
/* 181 */	"%0SUBI(%1);",	/* eac: SUBU2(eac,conB) */
/* 182 */	"%0SUBI(%1);",	/* eac: SUBP2(eac,conB) */
/* 183 */	"%0ADDI(-(%1));",	/* eac: SUBI2(eac,conBn) */
/* 184 */	"%0ADDI(-(%1));",	/* eac: SUBU2(eac,conBn) */
/* 185 */	"%0ADDI(-(%1));",	/* eac: SUBP2(eac,conBn) */
/* 186 */	"%0LSLW();",	/* eac: LSHI2(eac,con1) */
/* 187 */	"%0LSLW();",	/* eac: LSHU2(eac,con1) */
/* 188 */	"%0_SHLI(%1);",	/* eac: LSHI2(eac,conB) */
/* 189 */	"%0_SHLI(%1);",	/* eac: LSHU2(eac,conB) */
/* 190 */	"%1%{mul0}",	/* eac: MULI2(conB,eac) */
/* 191 */	"%1%{mul0}",	/* eac: MULI2(conB,eac) */
/* 192 */	"%0%[1b]ADDW(%1);",	/* eac: ADDI2(eac,iarg) */
/* 193 */	"%0%[1b]ADDW(%1);",	/* eac: ADDU2(eac,iarg) */
/* 194 */	"%0%[1b]ADDW(%1);",	/* eac: ADDP2(eac,iarg) */
/* 195 */	"%1%[0b]ADDW(%0);",	/* eac: ADDI2(iarg,eac) */
/* 196 */	"%1%[0b]ADDW(%0);",	/* eac: ADDU2(iarg,eac) */
/* 197 */	"%1%[0b]ADDW(%0);",	/* eac: ADDP2(iarg,eac) */
/* 198 */	"%0%[1b]SUBW(%1);",	/* eac: SUBI2(eac,iarg) */
/* 199 */	"%0%[1b]SUBW(%1);",	/* eac: SUBU2(eac,iarg) */
/* 200 */	"%0%[1b]SUBW(%1);",	/* eac: SUBP2(eac,iarg) */
/* 201 */	"\t%1STW(%0);\n",	/* stmt: ASGNP2(zddr,ac) */
/* 202 */	"\t%1%[0b]DOKE(%0);\n",	/* stmt: ASGNP2(iarg,ac) */
/* 203 */	"\t%1STW(%0);\n",	/* stmt: ASGNI2(zddr,ac) */
/* 204 */	"\t%1%[0b]DOKE(%0);\n",	/* stmt: ASGNI2(iarg,ac) */
/* 205 */	"\t%1STW(%0);\n",	/* stmt: ASGNU2(zddr,ac) */
/* 206 */	"\t%1%[0b]DOKE(%0);\n",	/* stmt: ASGNU2(iarg,ac) */
/* 207 */	"\t%1ST(%0);\n",	/* stmt: ASGNI1(zddr,ac) */
/* 208 */	"\t%1%[0b]POKE(%0);\n",	/* stmt: ASGNI1(iarg,ac) */
/* 209 */	"\t%1ST(%0);\n",	/* stmt: ASGNU1(zddr,ac) */
/* 210 */	"\t%1%[0b]POKE(%0);\n",	/* stmt: ASGNU1(iarg,ac) */
/* 211 */	"\t%0_BEQ(%a);\n",	/* stmt: EQI2(ac,con0) */
/* 212 */	"\t%0XORI(%1);_BEQ(%a);\n",	/* stmt: EQI2(ac,conB) */
/* 213 */	"\t%0%[1b]XORW(%1);_BEQ(%a);\n",	/* stmt: EQI2(ac,iarg) */
/* 214 */	"\t%1%[0b]XORW(%0);_BEQ(%a);\n",	/* stmt: EQI2(iarg,ac) */
/* 215 */	"\t%0_BNE(%a);\n",	/* stmt: NEI2(ac,con0) */
/* 216 */	"\t%0XORI(%1);_BNE(%a);\n",	/* stmt: NEI2(ac,conB) */
/* 217 */	"\t%0%[1b]XORW(%1);_BNE(%a);\n",	/* stmt: NEI2(ac,iarg) */
/* 218 */	"\t%1%[0b]XORW(%0);_BNE(%a);\n",	/* stmt: NEI2(iarg,ac) */
/* 219 */	"\t%0_BEQ(%a);\n",	/* stmt: EQU2(ac,con0) */
/* 220 */	"\t%0XORI(%1);_BEQ(%a);\n",	/* stmt: EQU2(ac,conB) */
/* 221 */	"\t%0%[1b]XORW(%1);_BEQ(%a);\n",	/* stmt: EQU2(ac,iarg) */
/* 222 */	"\t%1%[0b]XORW(%0);_BEQ(%a);\n",	/* stmt: EQU2(iarg,ac) */
/* 223 */	"\t%0_BNE(%a);\n",	/* stmt: NEU2(ac,con0) */
/* 224 */	"\t%0XORI(%1);_BNE(%a);\n",	/* stmt: NEU2(ac,conB) */
/* 225 */	"\t%0%[1b]XORW(%1);_BNE(%a);\n",	/* stmt: NEU2(ac,iarg) */
/* 226 */	"\t%1%[0b]XORW(%0);_BNE(%a);\n",	/* stmt: NEU2(iarg,ac) */
/* 227 */	"\t%0_BLT(%a);\n",	/* stmt: LTI2(ac,con0) */
/* 228 */	"\t%0_BLE(%a);\n",	/* stmt: LEI2(ac,con0) */
/* 229 */	"\t%0_BGT(%a);\n",	/* stmt: GTI2(ac,con0) */
/* 230 */	"\t%0_BGE(%a);\n",	/* stmt: GEI2(ac,con0) */
/* 231 */	"\t%0_BNE(%a);\n",	/* stmt: GTU2(ac,con0) */
/* 232 */	"\t%0_BEQ(%a);\n",	/* stmt: LEU2(ac,con0) */
/* 233 */	"\t%0_CMPIS(%1);_BLT(%a);\n",	/* stmt: LTI2(ac,conB) */
/* 234 */	"\t%0_CMPIS(%1);_BLE(%a);\n",	/* stmt: LEI2(ac,conB) */
/* 235 */	"\t%0_CMPIS(%1);_BGT(%a);\n",	/* stmt: GTI2(ac,conB) */
/* 236 */	"\t%0_CMPIS(%1);_BGE(%a);\n",	/* stmt: GEI2(ac,conB) */
/* 237 */	"\t%0_CMPIU(%1);_BLT(%a);\n",	/* stmt: LTU2(ac,conB) */
/* 238 */	"\t%0_CMPIU(%1);_BLE(%a);\n",	/* stmt: LEU2(ac,conB) */
/* 239 */	"\t%0_CMPIU(%1);_BGT(%a);\n",	/* stmt: GTU2(ac,conB) */
/* 240 */	"\t%0_CMPIU(%1);_BGE(%a);\n",	/* stmt: GEU2(ac,conB) */
/* 241 */	"\t%0%[1b]_CMPWS(%1);_BLT(%a);\n",	/* stmt: LTI2(ac,iarg) */
/* 242 */	"\t%0%[1b]_CMPWS(%1);_BLE(%a);\n",	/* stmt: LEI2(ac,iarg) */
/* 243 */	"\t%0%[1b]_CMPWS(%1);_BGT(%a);\n",	/* stmt: GTI2(ac,iarg) */
/* 244 */	"\t%0%[1b]_CMPWS(%1);_BGE(%a);\n",	/* stmt: GEI2(ac,iarg) */
/* 245 */	"\t%0%[1b]_CMPWU(%1);_BLT(%a);\n",	/* stmt: LTU2(ac,iarg) */
/* 246 */	"\t%0%[1b]_CMPWU(%1);_BLE(%a);\n",	/* stmt: LEU2(ac,iarg) */
/* 247 */	"\t%0%[1b]_CMPWU(%1);_BGT(%a);\n",	/* stmt: GTU2(ac,iarg) */
/* 248 */	"\t%0%[1b]_CMPWU(%1);_BGE(%a);\n",	/* stmt: GEU2(ac,iarg) */
/* 249 */	"\t%1%[0b]_CMPWS(%0);_BGT(%a);\n",	/* stmt: LTI2(iarg,ac) */
/* 250 */	"\t%1%[0b]_CMPWS(%0);_BGE(%a);\n",	/* stmt: LEI2(iarg,ac) */
/* 251 */	"\t%1%[0b]_CMPWS(%0);_BLT(%a);\n",	/* stmt: GTI2(iarg,ac) */
/* 252 */	"\t%1%[0b]_CMPWS(%0);_BLE(%a);\n",	/* stmt: GEI2(iarg,ac) */
/* 253 */	"\t%1%[0b]_CMPWU(%0);_BGT(%a);\n",	/* stmt: LTU2(iarg,ac) */
/* 254 */	"\t%1%[0b]_CMPWU(%0);_BGE(%a);\n",	/* stmt: LEU2(iarg,ac) */
/* 255 */	"\t%1%[0b]_CMPWU(%0);_BLT(%a);\n",	/* stmt: GTU2(iarg,ac) */
/* 256 */	"\t%1%[0b]_CMPWU(%0);_BLE(%a);\n",	/* stmt: GEU2(iarg,ac) */
/* 257 */	"%0",	/* vdst: addr */
/* 258 */	"[SP,%0]",	/* vdst: lddr */
/* 259 */	"[vAC]|%0",	/* vdst: eac */
/* 260 */	"%0",	/* asrc: addr */
/* 261 */	"[SP,%0]",	/* asrc: lddr */
/* 262 */	"[vAC]|%0",	/* asrc: eac */
/* 263 */	"%0",	/* lsrc: addr */
/* 264 */	"\t_SP(%c);STW(T2);%[0b]_BMOV(%0,[T2],%a,%b);\n",	/* stmt: ARGB(INDIRB(asrc)) */
/* 265 */	"\t%[1b]_BMOV(%1,%0,%a,%b);\n",	/* stmt: ASGNB(addr,INDIRB(asrc)) */
/* 266 */	"\t%0STW(T2);%[1b]_BMOV(%1,[T2],%a,%b);\n",	/* stmt: ASGNB(ac,INDIRB(asrc)) */
/* 267 */	"\t_BMOV(%1,[SP,%0],%a,%b);\n",	/* stmt: ASGNB(lddr,INDIRB(lsrc)) */
/* 268 */	"\t%0\n",	/* stmt: lac */
/* 269 */	"LDI(%0);",	/* larg: reg */
/* 270 */	"%0",	/* larg: INDIRI4(eac) */
/* 271 */	"%0",	/* larg: INDIRU4(eac) */
/* 272 */	"\t%{#alsoLAC}%0%{dst!=LAC:_LMOV(LAC,%c);}\n",	/* reg: lac */
/* 273 */	"\t%0_LMOV([vAC],%c);\n",	/* reg: INDIRI4(ac) */
/* 274 */	"\t%0_LMOV([vAC],%c);\n",	/* reg: INDIRU4(ac) */
/* 275 */	"\t%_LMOV([SP,%0],%c);\n",	/* reg: INDIRI4(lddr) */
/* 276 */	"\t%_LMOV([SP,%0],%c);\n",	/* reg: INDIRU4(lddr) */
/* 277 */	"\t_LMOV(%0,%c);\n",	/* reg: INDIRI4(addr) */
/* 278 */	"\t_LMOV(%0,%c);\n",	/* reg: INDIRU4(addr) */
/* 279 */	"%{src!=LAC:_LMOV(%0,LAC);}",	/* lac: reg */
/* 280 */	"%0_LMOV([vAC],LAC);",	/* lac: INDIRI4(ac) */
/* 281 */	"%0_LMOV([vAC],LAC);",	/* lac: INDIRU4(ac) */
/* 282 */	"_LMOV([SP,%0],LAC);",	/* lac: INDIRU4(lddr) */
/* 283 */	"_LMOV([SP,%0],LAC);",	/* lac: INDIRU4(lddr) */
/* 284 */	"_LMOV(%0,LAC);",	/* lac: INDIRI4(addr) */
/* 285 */	"_LMOV(%0,LAC);",	/* lac: INDIRU4(addr) */
/* 286 */	"%0%1_LADD();",	/* lac: ADDI4(lac,larg) */
/* 287 */	"%0%1_LADD();",	/* lac: ADDU4(lac,larg) */
/* 288 */	"%1%0_LADD();",	/* lac: ADDI4(larg,lac) */
/* 289 */	"%1%0_LADD();",	/* lac: ADDU4(larg,lac) */
/* 290 */	"%0%1_LSUB();",	/* lac: SUBI4(lac,larg) */
/* 291 */	"%0%1_LSUB();",	/* lac: SUBU4(lac,larg) */
/* 292 */	"%0%1_LMUL();",	/* lac: MULI4(lac,larg) */
/* 293 */	"%0%1_LMUL();",	/* lac: MULU4(lac,larg) */
/* 294 */	"%1%0_LMUL();",	/* lac: MULI4(larg,lac) */
/* 295 */	"%1%0_LMUL();",	/* lac: MULU4(larg,lac) */
/* 296 */	"%0%1_LDIVS();",	/* lac: DIVI4(lac,larg) */
/* 297 */	"%0%1_LDIVU();",	/* lac: DIVU4(lac,larg) */
/* 298 */	"%0%1_LMODS();",	/* lac: MODI4(lac,larg) */
/* 299 */	"%0%1_LMODU();",	/* lac: MODU4(lac,larg) */
/* 300 */	"%0LDW(%1);_LSHL();",	/* lac: LSHI4(lac,reg) */
/* 301 */	"%0LDI(%1);_LSHL();",	/* lac: LSHI4(lac,conB) */
/* 302 */	"%0LDW(%1);_LSHL();",	/* lac: LSHU4(lac,reg) */
/* 303 */	"%0LDI(%1);_LSHL();",	/* lac: LSHU4(lac,conB) */
/* 304 */	"%0LDW(%1);_LSHRS();",	/* lac: RSHI4(lac,reg) */
/* 305 */	"%0LDI(%1);_LSHRS();",	/* lac: RSHI4(lac,conB) */
/* 306 */	"%0LDW(%1);_LSHRU();",	/* lac: RSHU4(lac,reg) */
/* 307 */	"%0LDI(%1);_LSHRU();",	/* lac: RSHU4(lac,conB) */
/* 308 */	"%0_LNEG();",	/* lac: NEGI4(lac) */
/* 309 */	"%0_LCOM();",	/* lac: BCOMU4(lac) */
/* 310 */	"%0%1_LAND();",	/* lac: BANDU4(lac,larg) */
/* 311 */	"%1%0_LAND();",	/* lac: BANDU4(larg,lac) */
/* 312 */	"%0%1_LOR();",	/* lac: BORU4(lac,larg) */
/* 313 */	"%1%0_LOR();",	/* lac: BORU4(larg,lac) */
/* 314 */	"%0%1_LXOR();",	/* lac: BXORU4(lac,larg) */
/* 315 */	"%1%0_LXOR();",	/* lac: BXORU4(larg,lac) */
/* 316 */	"%0_LCOM();",	/* lac: BCOMI4(lac) */
/* 317 */	"%0%1_LAND();",	/* lac: BANDI4(lac,larg) */
/* 318 */	"%1%0_LAND();",	/* lac: BANDI4(larg,lac) */
/* 319 */	"%0%1_LOR();",	/* lac: BORI4(lac,larg) */
/* 320 */	"%1%0_LOR();",	/* lac: BORI4(larg,lac) */
/* 321 */	"%0%1_LXOR();",	/* lac: BXORI4(lac,larg) */
/* 322 */	"%1%0_LXOR();",	/* lac: BXORI4(larg,lac) */
/* 323 */	"\t%0%1_LCMPS();_BLT(%a);\n",	/* stmt: LTI4(lac,larg) */
/* 324 */	"\t%0%1_LCMPS();_BLE(%a);\n",	/* stmt: LEI4(lac,larg) */
/* 325 */	"\t%0%1_LCMPS();_BGT(%a);\n",	/* stmt: GTI4(lac,larg) */
/* 326 */	"\t%0%1_LCMPS();_BGE(%a);\n",	/* stmt: GEI4(lac,larg) */
/* 327 */	"\t%0%1_LCMPU();_BLT(%a);\n",	/* stmt: LTU4(lac,larg) */
/* 328 */	"\t%0%1_LCMPU();_BLE(%a);\n",	/* stmt: LEU4(lac,larg) */
/* 329 */	"\t%0%1_LCMPU();_BGT(%a);\n",	/* stmt: GTU4(lac,larg) */
/* 330 */	"\t%0%1_LCMPU();_BGE(%a);\n",	/* stmt: GEU4(lac,larg) */
/* 331 */	"\t%0%1_LCMPX();_BNE(%a);\n",	/* stmt: NEI4(lac,larg) */
/* 332 */	"\t%0%1_LCMPX();_BEQ(%a);\n",	/* stmt: EQI4(lac,larg) */
/* 333 */	"\t%0%1_LCMPX();_BNE(%a);\n",	/* stmt: NEU4(lac,larg) */
/* 334 */	"\t%0%1_LCMPX();_BEQ(%a);\n",	/* stmt: EQU4(lac,larg) */
/* 335 */	"\t%1%0_LCMPS();_BGT(%a);\n",	/* stmt: LTI4(larg,lac) */
/* 336 */	"\t%1%0_LCMPS();_BGE(%a);\n",	/* stmt: LEI4(larg,lac) */
/* 337 */	"\t%1%0_LCMPS();_BLT(%a);\n",	/* stmt: GTI4(larg,lac) */
/* 338 */	"\t%1%0_LCMPS();_BLE(%a);\n",	/* stmt: GEI4(larg,lac) */
/* 339 */	"\t%1%0_LCMPU();_BGT(%a);\n",	/* stmt: LTU4(larg,lac) */
/* 340 */	"\t%1%0_LCMPU();_BGE(%a);\n",	/* stmt: LEU4(larg,lac) */
/* 341 */	"\t%1%0_LCMPU();_BLT(%a);\n",	/* stmt: GTU4(larg,lac) */
/* 342 */	"\t%1%0_LCMPU();_BLE(%a);\n",	/* stmt: GEU4(larg,lac) */
/* 343 */	"\t%1%0_LCMPX();_BNE(%a);\n",	/* stmt: NEI4(larg,lac) */
/* 344 */	"\t%1%0_LCMPX();_BEQ(%a);\n",	/* stmt: EQI4(larg,lac) */
/* 345 */	"\t%1%0_LCMPX();_BNE(%a);\n",	/* stmt: NEU4(larg,lac) */
/* 346 */	"\t%1%0_LCMPX();_BEQ(%a);\n",	/* stmt: EQU4(larg,lac) */
/* 347 */	"\t%1%[0b]_LMOV(LAC,%0);\n",	/* stmt: ASGNI4(vdst,lac) */
/* 348 */	"\t%[0b]_LMOV(%1,%0);\n",	/* stmt: ASGNI4(vdst,reg) */
/* 349 */	"\t%[1b]_LMOV(%1,%0);\n",	/* stmt: ASGNI4(addr,INDIRI4(asrc)) */
/* 350 */	"\t%0STW(T2);%[1b]_LMOV(%1,[T2]);\n",	/* stmt: ASGNI4(ac,INDIRI4(asrc)) */
/* 351 */	"\t_LMOV(%1,[SP,%0]);\n",	/* stmt: ASGNI4(lddr,INDIRI4(lsrc)) */
/* 352 */	"\t%1%[0b]_LMOV(LAC,%0);\n",	/* stmt: ASGNU4(vdst,lac) */
/* 353 */	"\t%[0b]_LMOV(%1,%0);\n",	/* stmt: ASGNU4(vdst,reg) */
/* 354 */	"\t%[1b]_LMOV(%1,%0);\n",	/* stmt: ASGNU4(addr,INDIRU4(asrc)) */
/* 355 */	"\t%0STW(T2);%[1b]_LMOV(%1,[T2]);\n",	/* stmt: ASGNU4(ac,INDIRU4(asrc)) */
/* 356 */	"\t_LMOV(%1,[SP,%0]);\n",	/* stmt: ASGNU4(lddr,INDIRU4(lsrc)) */
/* 357 */	"\t%0\n",	/* stmt: fac */
/* 358 */	"LDI(%0);",	/* farg: reg */
/* 359 */	"%0",	/* farg: INDIRF5(eac) */
/* 360 */	"\t%{#alsoFAC}%0%{dst!=FAC:_FMOV(FAC,%c);}\n",	/* reg: fac */
/* 361 */	"\t%0_FMOV([vAC],%c);\n",	/* reg: INDIRF5(ac) */
/* 362 */	"\t%_FMOV([SP,%0],%c);\n",	/* reg: INDIRF5(lddr) */
/* 363 */	"\t_FMOV(%0,%c);\n",	/* reg: INDIRF5(addr) */
/* 364 */	"%{src!=FAC:_FMOV(%0,FAC);}",	/* fac: reg */
/* 365 */	"%0_FMOV([vAC],FAC);",	/* fac: INDIRF5(ac) */
/* 366 */	"_FMOV([SP,%0],FAC);",	/* fac: INDIRF5(lddr) */
/* 367 */	"_FMOV(%0,FAC);",	/* fac: INDIRF5(addr) */
/* 368 */	"%0%1_FADD();",	/* fac: ADDF5(fac,farg) */
/* 369 */	"%1%0_FADD();",	/* fac: ADDF5(farg,fac) */
/* 370 */	"%0%1_FSUB();",	/* fac: SUBF5(fac,farg) */
/* 371 */	"%1_FNEG();%0_FADD();",	/* fac: SUBF5(farg,fac) */
/* 372 */	"%0%1_FMUL();",	/* fac: MULF5(fac,farg) */
/* 373 */	"%1%0_FMUL();",	/* fac: MULF5(farg,fac) */
/* 374 */	"%0%1_FDIV();",	/* fac: DIVF5(fac,farg) */
/* 375 */	"%0_FNEG();",	/* fac: NEGF5(fac) */
/* 376 */	"\t%0%1_FCMP();_BEQ(%a);\n",	/* stmt: EQF5(fac,farg) */
/* 377 */	"\t%0%1_FCMP();_BNE(%a);\n",	/* stmt: NEF5(fac,farg) */
/* 378 */	"\t%0%1_FCMP();_BLT(%a);\n",	/* stmt: LTF5(fac,farg) */
/* 379 */	"\t%0%1_FCMP();_BLE(%a);\n",	/* stmt: LEF5(fac,farg) */
/* 380 */	"\t%0%1_FCMP();_BGT(%a);\n",	/* stmt: GTF5(fac,farg) */
/* 381 */	"\t%0%1_FCMP();_BGE(%a);\n",	/* stmt: GEF5(fac,farg) */
/* 382 */	"\t%1%0_FCMP();_BEQ(%a);\n",	/* stmt: EQF5(farg,fac) */
/* 383 */	"\t%1%0_FCMP();_BNE(%a);\n",	/* stmt: NEF5(farg,fac) */
/* 384 */	"\t%1%0_FCMP();_BGT(%a);\n",	/* stmt: LTF5(farg,fac) */
/* 385 */	"\t%1%0_FCMP();_BGE(%a);\n",	/* stmt: LEF5(farg,fac) */
/* 386 */	"\t%1%0_FCMP();_BLT(%a);\n",	/* stmt: GTF5(farg,fac) */
/* 387 */	"\t%1%0_FCMP();_BLE(%a);\n",	/* stmt: GEF5(farg,fac) */
/* 388 */	"\t%1%[0b]_FMOV(FAC,%0);\n",	/* stmt: ASGNF5(vdst,fac) */
/* 389 */	"\t%[0b]_FMOV(%1,%0);\n",	/* stmt: ASGNF5(vdst,reg) */
/* 390 */	"\t%[1b]_FMOV(%1,%0);\n",	/* stmt: ASGNF5(addr,INDIRF5(asrc)) */
/* 391 */	"\t%0STW(T2);%[1b]_FMOV(%1,[T2]);\n",	/* stmt: ASGNF5(ac,INDIRF5(asrc)) */
/* 392 */	"\t_FMOV(%1,[SP,%0]);\n",	/* stmt: ASGNF5(lddr,INDIRF5(lsrc)) */
/* 393 */	"CALLI(%0);",	/* fac: CALLF5(addr) */
/* 394 */	"CALL(%0);",	/* fac: CALLF5(reg) */
/* 395 */	"%0CALL(vAC);",	/* fac: CALLF5(ac) */
/* 396 */	"CALLI(%0);",	/* lac: CALLI4(addr) */
/* 397 */	"CALL(%0);",	/* lac: CALLI4(reg) */
/* 398 */	"%0CALL(vAC);",	/* lac: CALLI4(ac) */
/* 399 */	"CALLI(%0);",	/* lac: CALLU4(addr) */
/* 400 */	"CALL(%0);",	/* lac: CALLU4(reg) */
/* 401 */	"%0CALL(vAC);",	/* lac: CALLU4(ac) */
/* 402 */	"CALLI(%0);",	/* ac: CALLI2(addr) */
/* 403 */	"CALL(%0);",	/* ac: CALLI2(reg) */
/* 404 */	"%0CALL(vAC);",	/* ac: CALLI2(ac) */
/* 405 */	"CALLI(%0);",	/* ac: CALLU2(addr) */
/* 406 */	"CALL(%0);",	/* ac: CALLU2(reg) */
/* 407 */	"%0CALL(vAC);",	/* ac: CALLU2(ac) */
/* 408 */	"CALLI(%0);",	/* ac: CALLP2(addr) */
/* 409 */	"CALL(%0);",	/* ac: CALLP2(reg) */
/* 410 */	"%0CALL(vAC);",	/* ac: CALLP2(ac) */
/* 411 */	"\tCALLI(%0);\n",	/* stmt: CALLV(addr) */
/* 412 */	"\tCALL(%0);\n",	/* stmt: CALLV(reg) */
/* 413 */	"\t%0CALL(vAC);\n",	/* stmt: CALLV(ac) */
/* 414 */	"\t%_FMOV(%0,[SP,%c]);\n",	/* stmt: ARGF5(reg) */
/* 415 */	"\t%_LMOV(%0,[SP,%c]);\n",	/* stmt: ARGI4(reg) */
/* 416 */	"\t%_LMOV(%0,[SP,%c]);\n",	/* stmt: ARGU4(reg) */
/* 417 */	"\t_MOV(%0,[SP,%c]);\n",	/* stmt: ARGI2(reg) */
/* 418 */	"\t_MOV(%0,[SP,%c]);\n",	/* stmt: ARGU2(reg) */
/* 419 */	"\t_MOV(%0,[SP,%c]);\n",	/* stmt: ARGP2(reg) */
/* 420 */	"# arg\n",	/* stmt: ARGF5(reg) */
/* 421 */	"# arg\n",	/* stmt: ARGI4(reg) */
/* 422 */	"# arg\n",	/* stmt: ARGU4(reg) */
/* 423 */	"# arg\n",	/* stmt: ARGI2(reg) */
/* 424 */	"# arg\n",	/* stmt: ARGU2(reg) */
/* 425 */	"# arg\n",	/* stmt: ARGP2(reg) */
/* 426 */	"\t%0\n",	/* stmt: RETF5(fac) */
/* 427 */	"\t%0\n",	/* stmt: RETI4(lac) */
/* 428 */	"\t%0\n",	/* stmt: RETU4(lac) */
/* 429 */	"\t%0\n",	/* stmt: RETI2(ac) */
/* 430 */	"\t%0\n",	/* stmt: RETU2(ac) */
/* 431 */	"\t%0\n",	/* stmt: RETP2(ac) */
/* 432 */	"LD(%0);",	/* ac0: LOADI1(reg) */
/* 433 */	"LD(%0);",	/* ac0: LOADU1(reg) */
/* 434 */	"%0",	/* ac: LOADI1(ac) */
/* 435 */	"%0",	/* ac: LOADU1(ac) */
/* 436 */	"%0",	/* ac: LOADI2(ac) */
/* 437 */	"%0",	/* ac: LOADU2(ac) */
/* 438 */	"%0",	/* ac: LOADP2(ac) */
/* 439 */	"LDW(%0);",	/* ac: LOADI2(reg) */
/* 440 */	"LDW(%0);",	/* ac: LOADU2(reg) */
/* 441 */	"LDW(%0);",	/* ac: LOADP2(reg) */
/* 442 */	"%0LDW(LAC);",	/* ac: LOADI2(lac) */
/* 443 */	"%0LDW(LAC);",	/* ac: LOADU2(lac) */
/* 444 */	"%0LDW(LAC);",	/* ac: LOADP2(lac) */
/* 445 */	"%0",	/* lac: LOADI4(lac) */
/* 446 */	"%0",	/* lac: LOADU4(lac) */
/* 447 */	"%0",	/* fac: LOADF5(fac) */
/* 448 */	"LD(%0);XORI(128);SUBI(128);",	/* ac: CVII2(reg) */
/* 449 */	"LD(%0);",	/* ac: CVUI2(reg) */
/* 450 */	"%0XORI(128);SUBI(128);",	/* ac: CVII2(ac0) */
/* 451 */	"%0",	/* ac: CVUI2(ac0) */
/* 452 */	"%0LD(vACL);XORI(128);SUBI(128);",	/* ac: CVII2(ac) */
/* 453 */	"%0LD(vACL);",	/* ac: CVUI2(ac) */
/* 454 */	"%0STW(LAC);LDI(0);STW(LAC+2);",	/* lac: CVIU4(ac) */
/* 455 */	"%0_LCVI();",	/* lac: CVII4(ac) */
/* 456 */	"%0STW(LAC);LDI(0);STW(LAC+2);",	/* lac: CVUU4(ac) */
/* 457 */	"%0STW(LAC);LDI(0);STW(LAC+2);",	/* lac: CVUI4(ac) */
/* 458 */	"\t%0STW(%c);LDI(0);STW(%c+2);\n",	/* reg: CVIU4(ac) */
/* 459 */	"\t%0STW(%c);_LEXTS();STW(%c+2);\n",	/* reg: CVII4(ac) */
/* 460 */	"\t%0STW(%c);LDI(0);STW(%c+2);\n",	/* reg: CVUU4(ac) */
/* 461 */	"\t%0STW(%c);LDI(0);STW(%c+2);\n",	/* reg: CVUI4(ac) */
/* 462 */	"%0_FTOU();LDW(LAC);",	/* ac: CVFU2(fac) */
/* 463 */	"%0_FTOU();",	/* lac: CVFU4(fac) */
/* 464 */	"%0STW(LAC);LDI(0);STW(LAC+2);_FCVU();",	/* fac: CVUF5(ac) */
/* 465 */	"%0_FCVU();",	/* fac: CVUF5(lac) */
/* 466 */	"%0_FTOI();LDW(LAC);",	/* ac: CVFI2(fac) */
/* 467 */	"%0_FTOI();",	/* lac: CVFI4(fac) */
/* 468 */	"%0_LCVI();_FCVI();",	/* fac: CVIF5(ac) */
/* 469 */	"%0_FCVI();",	/* fac: CVIF5(lac) */
/* 470 */	"\tlabel(%a);\n",	/* stmt: LABELV */
/* 471 */	"\t_BRA(%0);\n",	/* stmt: JUMPV(addr) */
/* 472 */	"\tCALL(%0);\n",	/* stmt: JUMPV(reg) */
/* 473 */	"\t%0CALL(vAC);\n",	/* stmt: JUMPV(ac) */
/* 474 */	"\tSTW(T1);_MOV(%1,[SP,%0]);LDW(T1) #genspill\n",	/* stmt: ASGNI2(spill,reg) */
/* 475 */	"\tSTW(T1);_MOV(%1,[SP,%0]);LDW(T1) #genspill\n",	/* stmt: ASGNU2(spill,reg) */
/* 476 */	"\tSTW(T1);_MOV(%1,[SP,%0]);LDW(T1) #genspill\n",	/* stmt: ASGNP2(spill,reg) */
/* 477 */	"\tSTW(T1);_LMOV(%1,[SP,%0]);LDW(T1) #genspill\n",	/* stmt: ASGNI4(spill,reg) */
/* 478 */	"\tSTW(T1);_LMOV(%1,[SP,%0]);LDW(T1) #genspill\n",	/* stmt: ASGNU4(spill,reg) */
/* 479 */	"\tSTW(T1);_FMOV(%1,[SP,%0]);LDW(T1) #genspill\n",	/* stmt: ASGNF5(spill,reg) */
/* 480 */	"\t%0%[1b]DOKEA(%1);\n",	/* stmt: ASGNP2(ac,iarg) */
/* 481 */	"\t%0%[1b]DOKEA(%1);\n",	/* stmt: ASGNI2(ac,iarg) */
/* 482 */	"\t%0%[1b]DOKEA(%1);\n",	/* stmt: ASGNU2(ac,iarg) */
/* 483 */	"\t%0%[1b]POKEA(%1);\n",	/* stmt: ASGNI1(ac,iarg) */
/* 484 */	"\t%0%[1b]POKEA(%1);\n",	/* stmt: ASGNU1(ac,iarg) */
/* 485 */	"\t%0%[1b]DOKEI(%1);\n",	/* stmt: ASGNP2(ac,con) */
/* 486 */	"\t%0%[1b]DOKEI(%1);\n",	/* stmt: ASGNI2(ac,con) */
/* 487 */	"\t%0%[1b]DOKEI(%1);\n",	/* stmt: ASGNU2(ac,con) */
/* 488 */	"\t%0%[1b]POKEI(%1);\n",	/* stmt: ASGNI1(ac,conB) */
/* 489 */	"\t%0%[1b]POKEI(%1);\n",	/* stmt: ASGNI1(ac,conBs) */
/* 490 */	"\t%0%[1b]POKEI(%1);\n",	/* stmt: ASGNU1(ac,conB) */
/* 491 */	"\t%1STW2(%0);\n",	/* stmt: ASGNP2(addr,ac) */
/* 492 */	"\t%1STW2(%0);\n",	/* stmt: ASGNI2(addr,ac) */
/* 493 */	"\t%1STW2(%0);\n",	/* stmt: ASGNU2(addr,ac) */
/* 494 */	"\t%1ST2(%0);\n",	/* stmt: ASGNI1(addr,ac) */
/* 495 */	"\t%1ST2(%0);\n",	/* stmt: ASGNU1(addr,ac) */
/* 496 */	"\t%{#canVAC}%0%{dst!=vAC:DEEKA(%c)}%{dst==vAC:DEEK()};\n",	/* reg: INDIRI2(ac) */
/* 497 */	"\t%{#canVAC}%0%{dst!=vAC:DEEKA(%c)}%{dst==vAC:DEEK()};\n",	/* reg: INDIRU2(ac) */
/* 498 */	"\t%{#canVAC}%0%{dst!=vAC:DEEKA(%c)}%{dst==vAC:DEEK()};\n",	/* reg: INDIRP2(ac) */
/* 499 */	"\t%{#canVAC}%0%{dst!=vAC:PEEKA(%c)}%{dst==vAC:PEEK()};\n",	/* reg: INDIRI1(ac) */
/* 500 */	"\t%{#canVAC}%0%{dst!=vAC:PEEKA(%c)}%{dst==vAC:PEEK()};\n",	/* reg: INDIRU1(ac) */
/* 501 */	"%{src!=vAC:DEEKV(%0)}%{src==vAC:DEEK()};",	/* ac: INDIRI2(reg) */
/* 502 */	"%{src!=vAC:DEEKV(%0)}%{src==vAC:DEEK()};",	/* ac: INDIRU2(reg) */
/* 503 */	"%{src!=vAC:DEEKV(%0)}%{src==vAC:DEEK()};",	/* ac: INDIRP2(reg) */
/* 504 */	"%{src!=vAC:PEEKV(%0)}%{src==vAC:PEEK()};",	/* ac: INDIRI1(reg) */
/* 505 */	"%{src!=vAC:PEEKV(%0)}%{src==vAC:PEEK()};",	/* ac: INDIRU1(reg) */
/* 506 */	"%0ADDWI(%1);",	/* ac: ADDI2(ac,con) */
/* 507 */	"%0ADDWI(%1);",	/* ac: ADDU2(ac,con) */
/* 508 */	"%0ADDWI(%1);",	/* ac: ADDP2(ac,con) */
/* 509 */	"%0SUBWI(%1);",	/* ac: SUBI2(ac,con) */
/* 510 */	"%0SUBWI(%1);",	/* ac: SUBU2(ac,con) */
/* 511 */	"%0SUBWI(%1);",	/* ac: SUBP2(ac,con) */
/* 512 */	"%0ANDWI(%1);",	/* ac: BANDI2(ac,con) */
/* 513 */	"%0ANDWI(%1);",	/* ac: BANDU2(ac,con) */
/* 514 */	"%0ORWI(%1);",	/* ac: BORI2(ac,con) */
/* 515 */	"%0ORWI(%1);",	/* ac: BORU2(ac,con) */
/* 516 */	"%0XORWI(%1);",	/* ac: BXORI2(ac,con) */
/* 517 */	"%0XORWI(%1);",	/* ac: BXORU2(ac,con) */
/* 518 */	"ANDBK(%0,%1);",	/* ac: BANDI2(reg,conB) */
/* 519 */	"ANDBK(%0,%1);",	/* ac: BANDU2(reg,conB) */
/* 520 */	"ORBK(%0,%1);",	/* ac: BORI2(CVUI2(reg),conB) */
/* 521 */	"ORBK(%0,%1);",	/* ac: BORU2(CVUI2(reg),conB) */
/* 522 */	"XORBK(%0,%1);",	/* ac: BXORI2(CVUI2(reg),conB) */
/* 523 */	"XORBK(%0,%1);",	/* ac: BXORU2(CVUI2(reg),conB) */
/* 524 */	"%0NEGW(vAC);",	/* ac: NEGI2(ac) */
/* 525 */	"LDW(%0);NEGW(vAC);",	/* ac: NEGI2(reg) */
/* 526 */	"%0ADDBA(%1);",	/* ac: ADDI2(ac,CVUI2(iarg)) */
/* 527 */	"%0ADDBA(%1);",	/* ac: ADDU2(ac,CVUI2(iarg)) */
/* 528 */	"%0SUBBA(%1);",	/* ac: SUBU2(ac,CVUI2(iarg)) */
/* 529 */	"%0SUBBA(%1);",	/* ac: SUBI2(ac,CVUI2(iarg)) */
/* 530 */	"%a",	/* rmw: VREGP */
/* 531 */	"%0",	/* rmw: zddr */
/* 532 */	"\tINC(%0);\n",	/* stmt: ASGNU1(rmw,LOADU1(ADDI2(CVUI2(INDIRU1(rmw)),con1))) */
/* 533 */	"\tINC(%0);\n",	/* stmt: ASGNI1(rmw,LOADI1(ADDI2(CVII2(INDIRI1(rmw)),con1))) */
/* 534 */	"\tDEC(%0);\n",	/* stmt: ASGNU1(rmw,LOADU1(SUBI2(CVUI2(INDIRU1(rmw)),con1))) */
/* 535 */	"\tDEC(%0);\n",	/* stmt: ASGNI1(rmw,LOADI1(SUBI2(CVII2(INDIRI1(rmw)),con1))) */
/* 536 */	"\tINCW(%0);\n",	/* stmt: ASGNP2(rmw,ADDP2(INDIRP2(rmw),con1)) */
/* 537 */	"\tINCW(%0);\n",	/* stmt: ASGNP2(rmw,ADDP2(INDIRP2(rmw),con1)) */
/* 538 */	"\tINCW(%0);\n",	/* stmt: ASGNU2(rmw,ADDU2(INDIRU2(rmw),con1)) */
/* 539 */	"\tINCW(%0);\n",	/* stmt: ASGNI2(rmw,ADDI2(INDIRI2(rmw),con1)) */
/* 540 */	"\tDECW(%0);\n",	/* stmt: ASGNP2(rmw,SUBP2(INDIRP2(rmw),con1)) */
/* 541 */	"\tDECW(%0);\n",	/* stmt: ASGNU2(rmw,SUBU2(INDIRU2(rmw),con1)) */
/* 542 */	"\tDECW(%0);\n",	/* stmt: ASGNI2(rmw,SUBI2(INDIRI2(rmw),con1)) */
/* 543 */	"\tDECW(%0);\n",	/* stmt: ASGNP2(rmw,ADDP2(INDIRP2(rmw),con1n)) */
/* 544 */	"\tDECW(%0);\n",	/* stmt: ASGNU2(rmw,ADDU2(INDIRU2(rmw),con1n)) */
/* 545 */	"\tDECW(%0);\n",	/* stmt: ASGNI2(rmw,ADDI2(INDIRI2(rmw),con1n)) */
/* 546 */	"\tNEGW(%0);\n",	/* stmt: ASGNI2(rmw,NEGI2(INDIRI2(rmw))) */
/* 547 */	"\tNOTW(%0);\n",	/* stmt: ASGNI2(rmw,BCOMI2(INDIRI2(rmw))) */
/* 548 */	"\tNOTW(%0);\n",	/* stmt: ASGNU2(rmw,BCOMU2(INDIRU2(rmw))) */
/* 549 */	"\tLSLV(%0);\n",	/* stmt: ASGNI2(rmw,LSHI2(INDIRI2(rmw),con1)) */
/* 550 */	"\tLSLV(%0);\n",	/* stmt: ASGNU2(rmw,LSHU2(INDIRU2(rmw),con1)) */
/* 551 */	"\tMOVQW(%1,%0)\n",	/* stmt: ASGNI2(rmw,conB) */
/* 552 */	"\tMOVQW(%1,%0)\n",	/* stmt: ASGNU2(rmw,conB) */
/* 553 */	"\tMOVQW(%1,%0)\n",	/* stmt: ASGNP2(rmw,conB) */
/* 554 */	"\tMOVQ(%1,%0)\n",	/* stmt: ASGNI1(rmw,conB) */
/* 555 */	"\tMOVQ(%1,%0)\n",	/* stmt: ASGNU1(rmw,conB) */
};

static char _isinstruction[] = {
/* 0 */	0,
/* 1 */	1,	/* # read register\n */
/* 2 */	1,	/* # read register\n */
/* 3 */	1,	/* # read register\n */
/* 4 */	1,	/* # read register\n */
/* 5 */	1,	/* # read register\n */
/* 6 */	1,	/* # read register\n */
/* 7 */	1,	/* # read register\n */
/* 8 */	1,	/* # read register\n */
/* 9 */	1,	/* # write register\n */
/* 10 */	1,	/* # write register\n */
/* 11 */	1,	/* # write register\n */
/* 12 */	1,	/* # write register\n */
/* 13 */	1,	/* # write register\n */
/* 14 */	1,	/* # write register\n */
/* 15 */	1,	/* # write register\n */
/* 16 */	1,	/* # write register\n */
/* 17 */	1,	/* \t%{#alsoVAC}%{src!=vAC:LD(%0);}%{dst!=vAC:ST(%c);}\n */
/* 18 */	1,	/* \t%{#alsoVAC}%{src!=vAC:LD(%0);}%{dst!=vAC:ST(%c);}\n */
/* 19 */	1,	/* \t%{#alsoVAC}%{src!=vAC:LDW(%0);}%{dst!=vAC:STW(%c);}\n */
/* 20 */	1,	/* \t%{#alsoVAC}%{src!=vAC:LDW(%0);}%{dst!=vAC:STW(%c);}\n */
/* 21 */	1,	/* \t%{#alsoVAC}%{src!=vAC:LDW(%0);}%{dst!=vAC:STW(%c);}\n */
/* 22 */	1,	/* \t_LMOV(%0,%c);\n */
/* 23 */	1,	/* \t_LMOV(%0,%c);\n */
/* 24 */	1,	/* \t_FMOV(%0,%c);\n */
/* 25 */	1,	/* \tLDI(%0);%{dst!=vAC:ST(%c);}\n */
/* 26 */	1,	/* \tLDI(%0);%{dst!=vAC:ST(%c);}\n */
/* 27 */	1,	/* \t_LDI(%0);%{dst!=vAC:STW(%c);}\n */
/* 28 */	1,	/* \t_LDI(%0);%{dst!=vAC:STW(%c);}\n */
/* 29 */	1,	/* \t_LDI(%0);%{dst!=vAC:STW(%c);}\n */
/* 30 */	0,	/* %a */
/* 31 */	0,	/* %a */
/* 32 */	0,	/* %a */
/* 33 */	0,	/* %a */
/* 34 */	0,	/* %a */
/* 35 */	0,	/* %a */
/* 36 */	0,	/* %a */
/* 37 */	0,	/* %a */
/* 38 */	0,	/* %a */
/* 39 */	0,	/* %a */
/* 40 */	0,	/* %a */
/* 41 */	0,	/* %a */
/* 42 */	0,	/* %a */
/* 43 */	0,	/* %a */
/* 44 */	0,	/* %a */
/* 45 */	0,	/* %a */
/* 46 */	0,	/* %0 */
/* 47 */	0,	/* %a */
/* 48 */	0,	/* %a */
/* 49 */	0,	/* %a */
/* 50 */	0,	/* %a */
/* 51 */	0,	/* %a */
/* 52 */	0,	/* %a */
/* 53 */	0,	/* %a */
/* 54 */	0,	/* %a */
/* 55 */	0,	/* %0 */
/* 56 */	0,	/* %a+%F */
/* 57 */	0,	/* %a+%F */
/* 58 */	0,	/* %a */
/* 59 */	0,	/* %0 */
/* 60 */	0,	/* %0 */
/* 61 */	0,	/* %a */
/* 62 */	0,	/* %0 */
/* 63 */	0,	/*  */
/* 64 */	1,	/* \t%0\n */
/* 65 */	1,	/* \t%{#alsoVAC}%0%{dst!=vAC:STW(%c);}\n */
/* 66 */	0,	/* %{src!=vAC:LDW(%0);} */
/* 67 */	0,	/* %0 */
/* 68 */	0,	/* %0 */
/* 69 */	0,	/* %0 */
/* 70 */	0,	/* LDI(%0); */
/* 71 */	0,	/* _LDI(%0); */
/* 72 */	0,	/* LDI(%0); */
/* 73 */	0,	/* _LDI(%0); */
/* 74 */	0,	/* %{src!=vAC:LDW(%0);} */
/* 75 */	0,	/* %0 */
/* 76 */	0,	/* LDI(%0); */
/* 77 */	0,	/* _LDI(%0); */
/* 78 */	0,	/* _SP(%0); */
/* 79 */	0,	/* %0DEEK(); */
/* 80 */	0,	/* %0DEEK(); */
/* 81 */	0,	/* %0DEEK(); */
/* 82 */	0,	/* %0PEEK(); */
/* 83 */	0,	/* %0PEEK(); */
/* 84 */	0,	/* LDW(%0); */
/* 85 */	0,	/* LDW(%0); */
/* 86 */	0,	/* LDW(%0); */
/* 87 */	0,	/* LD(%0); */
/* 88 */	0,	/* LD(%0); */
/* 89 */	0,	/* %0DEEK(); */
/* 90 */	0,	/* %0DEEK(); */
/* 91 */	0,	/* %0DEEK(); */
/* 92 */	0,	/* %0PEEK(); */
/* 93 */	0,	/* %0PEEK(); */
/* 94 */	0,	/* %0 */
/* 95 */	0,	/* %0 */
/* 96 */	0,	/* %0 */
/* 97 */	0,	/* %0 */
/* 98 */	0,	/* %a+%F */
/* 99 */	0,	/* T3|STW(T1);_MOV([SP,%0],T3);LDW(T1); */
/* 100 */	0,	/* T3|STW(T1);_MOV([SP,%0],T3);LDW(T1); */
/* 101 */	0,	/* T3|STW(T1);_MOV([SP,%0],T3);LDW(T1); */
/* 102 */	0,	/* %0%[1b]ADDW(%1); */
/* 103 */	0,	/* %0%[1b]ADDW(%1); */
/* 104 */	0,	/* %0%[1b]ADDW(%1); */
/* 105 */	0,	/* %1%[0b]ADDW(%0); */
/* 106 */	0,	/* %1%[0b]ADDW(%0); */
/* 107 */	0,	/* %1%[0b]ADDW(%0); */
/* 108 */	0,	/* %0ADDI(%1); */
/* 109 */	0,	/* %0ADDI(%1); */
/* 110 */	0,	/* %0ADDI(%1); */
/* 111 */	0,	/* %0SUBI(-(%1)); */
/* 112 */	0,	/* %0SUBI(-(%1)); */
/* 113 */	0,	/* %0SUBI(-(%1)); */
/* 114 */	0,	/* %0%[1b]SUBW(%1); */
/* 115 */	0,	/* %0%[1b]SUBW(%1); */
/* 116 */	0,	/* %0%[1b]SUBW(%1); */
/* 117 */	0,	/* %0SUBI(%1); */
/* 118 */	0,	/* %0SUBI(%1); */
/* 119 */	0,	/* %0SUBI(%1); */
/* 120 */	0,	/* %0ADDI(-(%1)); */
/* 121 */	0,	/* %0ADDI(-(%1)); */
/* 122 */	0,	/* %0ADDI(-(%1)); */
/* 123 */	0,	/* %0STW(T3);LDI(0);SUBW(T3); */
/* 124 */	0,	/* LDI(0);SUBW(%0); */
/* 125 */	0,	/* %0LSLW(); */
/* 126 */	0,	/* %0LSLW(); */
/* 127 */	0,	/* %0_SHLI(%1); */
/* 128 */	0,	/* %0_SHLI(%1); */
/* 129 */	0,	/* %0_SHRIS(%1); */
/* 130 */	0,	/* %0_SHRIU(%1); */
/* 131 */	0,	/* %0%[1b]_SHL(%1); */
/* 132 */	0,	/* %0%[1b]_SHRS(%1); */
/* 133 */	0,	/* %0%[1b]_SHL(%1); */
/* 134 */	0,	/* %0%[1b]_SHRU(%1); */
/* 135 */	0,	/* %1%{mul0} */
/* 136 */	0,	/* %1%{mul0} */
/* 137 */	0,	/* %{mul0%1} */
/* 138 */	0,	/* %{mul0%1} */
/* 139 */	0,	/* %1_MULI(%0); */
/* 140 */	0,	/* %0%[1b]_MUL(%1); */
/* 141 */	0,	/* %1%[0b]_MUL(%0); */
/* 142 */	0,	/* %1%{mul0} */
/* 143 */	0,	/* %1_MULI(%0); */
/* 144 */	0,	/* %0%[1b]_MUL(%1); */
/* 145 */	0,	/* %1%[0b]_MUL(%0); */
/* 146 */	0,	/* %0%[1b]_DIVS(%1); */
/* 147 */	0,	/* %0%[1b]_DIVU(%1); */
/* 148 */	0,	/* %0%[1b]_MODS(%1); */
/* 149 */	0,	/* %0%[1b]_MODU(%1); */
/* 150 */	0,	/* %0%[1b]_DIVIS(%1); */
/* 151 */	0,	/* %0%[1b]_DIVIU(%1); */
/* 152 */	0,	/* %0%[1b]_MODIS(%1); */
/* 153 */	0,	/* %0%[1b]_MODIU(%1); */
/* 154 */	0,	/* %0STW(T3);_LDI(-1);XORW(T3); */
/* 155 */	0,	/* %0STW(T3);_LDI(-1);XORW(T3); */
/* 156 */	0,	/* %0%[1b]ANDW(%1); */
/* 157 */	0,	/* %0%[1b]ANDW(%1); */
/* 158 */	0,	/* %1%[0b]ANDW(%0); */
/* 159 */	0,	/* %1%[0b]ANDW(%0); */
/* 160 */	0,	/* %0ANDI(%1); */
/* 161 */	0,	/* %0ANDI(%1); */
/* 162 */	0,	/* %0%[1b]ORW(%1); */
/* 163 */	0,	/* %0%[1b]ORW(%1); */
/* 164 */	0,	/* %1%[0b]ORW(%0); */
/* 165 */	0,	/* %1%[0b]ORW(%0); */
/* 166 */	0,	/* %0ORI(%1); */
/* 167 */	0,	/* %0ORI(%1); */
/* 168 */	0,	/* %0%[1b]XORW(%1); */
/* 169 */	0,	/* %0%[1b]XORW(%1); */
/* 170 */	0,	/* %1%[0b]XORW(%0); */
/* 171 */	0,	/* %1%[0b]XORW(%0); */
/* 172 */	0,	/* %0XORI(%1); */
/* 173 */	0,	/* %0XORI(%1); */
/* 174 */	0,	/* %0ADDI(%1); */
/* 175 */	0,	/* %0ADDI(%1); */
/* 176 */	0,	/* %0ADDI(%1); */
/* 177 */	0,	/* %0SUBI(-(%1)); */
/* 178 */	0,	/* %0SUBI(-(%1)); */
/* 179 */	0,	/* %0SUBI(-(%1)); */
/* 180 */	0,	/* %0SUBI(%1); */
/* 181 */	0,	/* %0SUBI(%1); */
/* 182 */	0,	/* %0SUBI(%1); */
/* 183 */	0,	/* %0ADDI(-(%1)); */
/* 184 */	0,	/* %0ADDI(-(%1)); */
/* 185 */	0,	/* %0ADDI(-(%1)); */
/* 186 */	0,	/* %0LSLW(); */
/* 187 */	0,	/* %0LSLW(); */
/* 188 */	0,	/* %0_SHLI(%1); */
/* 189 */	0,	/* %0_SHLI(%1); */
/* 190 */	0,	/* %1%{mul0} */
/* 191 */	0,	/* %1%{mul0} */
/* 192 */	0,	/* %0%[1b]ADDW(%1); */
/* 193 */	0,	/* %0%[1b]ADDW(%1); */
/* 194 */	0,	/* %0%[1b]ADDW(%1); */
/* 195 */	0,	/* %1%[0b]ADDW(%0); */
/* 196 */	0,	/* %1%[0b]ADDW(%0); */
/* 197 */	0,	/* %1%[0b]ADDW(%0); */
/* 198 */	0,	/* %0%[1b]SUBW(%1); */
/* 199 */	0,	/* %0%[1b]SUBW(%1); */
/* 200 */	0,	/* %0%[1b]SUBW(%1); */
/* 201 */	1,	/* \t%1STW(%0);\n */
/* 202 */	1,	/* \t%1%[0b]DOKE(%0);\n */
/* 203 */	1,	/* \t%1STW(%0);\n */
/* 204 */	1,	/* \t%1%[0b]DOKE(%0);\n */
/* 205 */	1,	/* \t%1STW(%0);\n */
/* 206 */	1,	/* \t%1%[0b]DOKE(%0);\n */
/* 207 */	1,	/* \t%1ST(%0);\n */
/* 208 */	1,	/* \t%1%[0b]POKE(%0);\n */
/* 209 */	1,	/* \t%1ST(%0);\n */
/* 210 */	1,	/* \t%1%[0b]POKE(%0);\n */
/* 211 */	1,	/* \t%0_BEQ(%a);\n */
/* 212 */	1,	/* \t%0XORI(%1);_BEQ(%a);\n */
/* 213 */	1,	/* \t%0%[1b]XORW(%1);_BEQ(%a);\n */
/* 214 */	1,	/* \t%1%[0b]XORW(%0);_BEQ(%a);\n */
/* 215 */	1,	/* \t%0_BNE(%a);\n */
/* 216 */	1,	/* \t%0XORI(%1);_BNE(%a);\n */
/* 217 */	1,	/* \t%0%[1b]XORW(%1);_BNE(%a);\n */
/* 218 */	1,	/* \t%1%[0b]XORW(%0);_BNE(%a);\n */
/* 219 */	1,	/* \t%0_BEQ(%a);\n */
/* 220 */	1,	/* \t%0XORI(%1);_BEQ(%a);\n */
/* 221 */	1,	/* \t%0%[1b]XORW(%1);_BEQ(%a);\n */
/* 222 */	1,	/* \t%1%[0b]XORW(%0);_BEQ(%a);\n */
/* 223 */	1,	/* \t%0_BNE(%a);\n */
/* 224 */	1,	/* \t%0XORI(%1);_BNE(%a);\n */
/* 225 */	1,	/* \t%0%[1b]XORW(%1);_BNE(%a);\n */
/* 226 */	1,	/* \t%1%[0b]XORW(%0);_BNE(%a);\n */
/* 227 */	1,	/* \t%0_BLT(%a);\n */
/* 228 */	1,	/* \t%0_BLE(%a);\n */
/* 229 */	1,	/* \t%0_BGT(%a);\n */
/* 230 */	1,	/* \t%0_BGE(%a);\n */
/* 231 */	1,	/* \t%0_BNE(%a);\n */
/* 232 */	1,	/* \t%0_BEQ(%a);\n */
/* 233 */	1,	/* \t%0_CMPIS(%1);_BLT(%a);\n */
/* 234 */	1,	/* \t%0_CMPIS(%1);_BLE(%a);\n */
/* 235 */	1,	/* \t%0_CMPIS(%1);_BGT(%a);\n */
/* 236 */	1,	/* \t%0_CMPIS(%1);_BGE(%a);\n */
/* 237 */	1,	/* \t%0_CMPIU(%1);_BLT(%a);\n */
/* 238 */	1,	/* \t%0_CMPIU(%1);_BLE(%a);\n */
/* 239 */	1,	/* \t%0_CMPIU(%1);_BGT(%a);\n */
/* 240 */	1,	/* \t%0_CMPIU(%1);_BGE(%a);\n */
/* 241 */	1,	/* \t%0%[1b]_CMPWS(%1);_BLT(%a);\n */
/* 242 */	1,	/* \t%0%[1b]_CMPWS(%1);_BLE(%a);\n */
/* 243 */	1,	/* \t%0%[1b]_CMPWS(%1);_BGT(%a);\n */
/* 244 */	1,	/* \t%0%[1b]_CMPWS(%1);_BGE(%a);\n */
/* 245 */	1,	/* \t%0%[1b]_CMPWU(%1);_BLT(%a);\n */
/* 246 */	1,	/* \t%0%[1b]_CMPWU(%1);_BLE(%a);\n */
/* 247 */	1,	/* \t%0%[1b]_CMPWU(%1);_BGT(%a);\n */
/* 248 */	1,	/* \t%0%[1b]_CMPWU(%1);_BGE(%a);\n */
/* 249 */	1,	/* \t%1%[0b]_CMPWS(%0);_BGT(%a);\n */
/* 250 */	1,	/* \t%1%[0b]_CMPWS(%0);_BGE(%a);\n */
/* 251 */	1,	/* \t%1%[0b]_CMPWS(%0);_BLT(%a);\n */
/* 252 */	1,	/* \t%1%[0b]_CMPWS(%0);_BLE(%a);\n */
/* 253 */	1,	/* \t%1%[0b]_CMPWU(%0);_BGT(%a);\n */
/* 254 */	1,	/* \t%1%[0b]_CMPWU(%0);_BGE(%a);\n */
/* 255 */	1,	/* \t%1%[0b]_CMPWU(%0);_BLT(%a);\n */
/* 256 */	1,	/* \t%1%[0b]_CMPWU(%0);_BLE(%a);\n */
/* 257 */	0,	/* %0 */
/* 258 */	0,	/* [SP,%0] */
/* 259 */	0,	/* [vAC]|%0 */
/* 260 */	0,	/* %0 */
/* 261 */	0,	/* [SP,%0] */
/* 262 */	0,	/* [vAC]|%0 */
/* 263 */	0,	/* %0 */
/* 264 */	1,	/* \t_SP(%c);STW(T2);%[0b]_BMOV(%0,[T2],%a,%b);\n */
/* 265 */	1,	/* \t%[1b]_BMOV(%1,%0,%a,%b);\n */
/* 266 */	1,	/* \t%0STW(T2);%[1b]_BMOV(%1,[T2],%a,%b);\n */
/* 267 */	1,	/* \t_BMOV(%1,[SP,%0],%a,%b);\n */
/* 268 */	1,	/* \t%0\n */
/* 269 */	0,	/* LDI(%0); */
/* 270 */	0,	/* %0 */
/* 271 */	0,	/* %0 */
/* 272 */	1,	/* \t%{#alsoLAC}%0%{dst!=LAC:_LMOV(LAC,%c);}\n */
/* 273 */	1,	/* \t%0_LMOV([vAC],%c);\n */
/* 274 */	1,	/* \t%0_LMOV([vAC],%c);\n */
/* 275 */	1,	/* \t%_LMOV([SP,%0],%c);\n */
/* 276 */	1,	/* \t%_LMOV([SP,%0],%c);\n */
/* 277 */	1,	/* \t_LMOV(%0,%c);\n */
/* 278 */	1,	/* \t_LMOV(%0,%c);\n */
/* 279 */	0,	/* %{src!=LAC:_LMOV(%0,LAC);} */
/* 280 */	0,	/* %0_LMOV([vAC],LAC); */
/* 281 */	0,	/* %0_LMOV([vAC],LAC); */
/* 282 */	0,	/* _LMOV([SP,%0],LAC); */
/* 283 */	0,	/* _LMOV([SP,%0],LAC); */
/* 284 */	0,	/* _LMOV(%0,LAC); */
/* 285 */	0,	/* _LMOV(%0,LAC); */
/* 286 */	0,	/* %0%1_LADD(); */
/* 287 */	0,	/* %0%1_LADD(); */
/* 288 */	0,	/* %1%0_LADD(); */
/* 289 */	0,	/* %1%0_LADD(); */
/* 290 */	0,	/* %0%1_LSUB(); */
/* 291 */	0,	/* %0%1_LSUB(); */
/* 292 */	0,	/* %0%1_LMUL(); */
/* 293 */	0,	/* %0%1_LMUL(); */
/* 294 */	0,	/* %1%0_LMUL(); */
/* 295 */	0,	/* %1%0_LMUL(); */
/* 296 */	0,	/* %0%1_LDIVS(); */
/* 297 */	0,	/* %0%1_LDIVU(); */
/* 298 */	0,	/* %0%1_LMODS(); */
/* 299 */	0,	/* %0%1_LMODU(); */
/* 300 */	0,	/* %0LDW(%1);_LSHL(); */
/* 301 */	0,	/* %0LDI(%1);_LSHL(); */
/* 302 */	0,	/* %0LDW(%1);_LSHL(); */
/* 303 */	0,	/* %0LDI(%1);_LSHL(); */
/* 304 */	0,	/* %0LDW(%1);_LSHRS(); */
/* 305 */	0,	/* %0LDI(%1);_LSHRS(); */
/* 306 */	0,	/* %0LDW(%1);_LSHRU(); */
/* 307 */	0,	/* %0LDI(%1);_LSHRU(); */
/* 308 */	0,	/* %0_LNEG(); */
/* 309 */	0,	/* %0_LCOM(); */
/* 310 */	0,	/* %0%1_LAND(); */
/* 311 */	0,	/* %1%0_LAND(); */
/* 312 */	0,	/* %0%1_LOR(); */
/* 313 */	0,	/* %1%0_LOR(); */
/* 314 */	0,	/* %0%1_LXOR(); */
/* 315 */	0,	/* %1%0_LXOR(); */
/* 316 */	0,	/* %0_LCOM(); */
/* 317 */	0,	/* %0%1_LAND(); */
/* 318 */	0,	/* %1%0_LAND(); */
/* 319 */	0,	/* %0%1_LOR(); */
/* 320 */	0,	/* %1%0_LOR(); */
/* 321 */	0,	/* %0%1_LXOR(); */
/* 322 */	0,	/* %1%0_LXOR(); */
/* 323 */	1,	/* \t%0%1_LCMPS();_BLT(%a);\n */
/* 324 */	1,	/* \t%0%1_LCMPS();_BLE(%a);\n */
/* 325 */	1,	/* \t%0%1_LCMPS();_BGT(%a);\n */
/* 326 */	1,	/* \t%0%1_LCMPS();_BGE(%a);\n */
/* 327 */	1,	/* \t%0%1_LCMPU();_BLT(%a);\n */
/* 328 */	1,	/* \t%0%1_LCMPU();_BLE(%a);\n */
/* 329 */	1,	/* \t%0%1_LCMPU();_BGT(%a);\n */
/* 330 */	1,	/* \t%0%1_LCMPU();_BGE(%a);\n */
/* 331 */	1,	/* \t%0%1_LCMPX();_BNE(%a);\n */
/* 332 */	1,	/* \t%0%1_LCMPX();_BEQ(%a);\n */
/* 333 */	1,	/* \t%0%1_LCMPX();_BNE(%a);\n */
/* 334 */	1,	/* \t%0%1_LCMPX();_BEQ(%a);\n */
/* 335 */	1,	/* \t%1%0_LCMPS();_BGT(%a);\n */
/* 336 */	1,	/* \t%1%0_LCMPS();_BGE(%a);\n */
/* 337 */	1,	/* \t%1%0_LCMPS();_BLT(%a);\n */
/* 338 */	1,	/* \t%1%0_LCMPS();_BLE(%a);\n */
/* 339 */	1,	/* \t%1%0_LCMPU();_BGT(%a);\n */
/* 340 */	1,	/* \t%1%0_LCMPU();_BGE(%a);\n */
/* 341 */	1,	/* \t%1%0_LCMPU();_BLT(%a);\n */
/* 342 */	1,	/* \t%1%0_LCMPU();_BLE(%a);\n */
/* 343 */	1,	/* \t%1%0_LCMPX();_BNE(%a);\n */
/* 344 */	1,	/* \t%1%0_LCMPX();_BEQ(%a);\n */
/* 345 */	1,	/* \t%1%0_LCMPX();_BNE(%a);\n */
/* 346 */	1,	/* \t%1%0_LCMPX();_BEQ(%a);\n */
/* 347 */	1,	/* \t%1%[0b]_LMOV(LAC,%0);\n */
/* 348 */	1,	/* \t%[0b]_LMOV(%1,%0);\n */
/* 349 */	1,	/* \t%[1b]_LMOV(%1,%0);\n */
/* 350 */	1,	/* \t%0STW(T2);%[1b]_LMOV(%1,[T2]);\n */
/* 351 */	1,	/* \t_LMOV(%1,[SP,%0]);\n */
/* 352 */	1,	/* \t%1%[0b]_LMOV(LAC,%0);\n */
/* 353 */	1,	/* \t%[0b]_LMOV(%1,%0);\n */
/* 354 */	1,	/* \t%[1b]_LMOV(%1,%0);\n */
/* 355 */	1,	/* \t%0STW(T2);%[1b]_LMOV(%1,[T2]);\n */
/* 356 */	1,	/* \t_LMOV(%1,[SP,%0]);\n */
/* 357 */	1,	/* \t%0\n */
/* 358 */	0,	/* LDI(%0); */
/* 359 */	0,	/* %0 */
/* 360 */	1,	/* \t%{#alsoFAC}%0%{dst!=FAC:_FMOV(FAC,%c);}\n */
/* 361 */	1,	/* \t%0_FMOV([vAC],%c);\n */
/* 362 */	1,	/* \t%_FMOV([SP,%0],%c);\n */
/* 363 */	1,	/* \t_FMOV(%0,%c);\n */
/* 364 */	0,	/* %{src!=FAC:_FMOV(%0,FAC);} */
/* 365 */	0,	/* %0_FMOV([vAC],FAC); */
/* 366 */	0,	/* _FMOV([SP,%0],FAC); */
/* 367 */	0,	/* _FMOV(%0,FAC); */
/* 368 */	0,	/* %0%1_FADD(); */
/* 369 */	0,	/* %1%0_FADD(); */
/* 370 */	0,	/* %0%1_FSUB(); */
/* 371 */	0,	/* %1_FNEG();%0_FADD(); */
/* 372 */	0,	/* %0%1_FMUL(); */
/* 373 */	0,	/* %1%0_FMUL(); */
/* 374 */	0,	/* %0%1_FDIV(); */
/* 375 */	0,	/* %0_FNEG(); */
/* 376 */	1,	/* \t%0%1_FCMP();_BEQ(%a);\n */
/* 377 */	1,	/* \t%0%1_FCMP();_BNE(%a);\n */
/* 378 */	1,	/* \t%0%1_FCMP();_BLT(%a);\n */
/* 379 */	1,	/* \t%0%1_FCMP();_BLE(%a);\n */
/* 380 */	1,	/* \t%0%1_FCMP();_BGT(%a);\n */
/* 381 */	1,	/* \t%0%1_FCMP();_BGE(%a);\n */
/* 382 */	1,	/* \t%1%0_FCMP();_BEQ(%a);\n */
/* 383 */	1,	/* \t%1%0_FCMP();_BNE(%a);\n */
/* 384 */	1,	/* \t%1%0_FCMP();_BGT(%a);\n */
/* 385 */	1,	/* \t%1%0_FCMP();_BGE(%a);\n */
/* 386 */	1,	/* \t%1%0_FCMP();_BLT(%a);\n */
/* 387 */	1,	/* \t%1%0_FCMP();_BLE(%a);\n */
/* 388 */	1,	/* \t%1%[0b]_FMOV(FAC,%0);\n */
/* 389 */	1,	/* \t%[0b]_FMOV(%1,%0);\n */
/* 390 */	1,	/* \t%[1b]_FMOV(%1,%0);\n */
/* 391 */	1,	/* \t%0STW(T2);%[1b]_FMOV(%1,[T2]);\n */
/* 392 */	1,	/* \t_FMOV(%1,[SP,%0]);\n */
/* 393 */	0,	/* CALLI(%0); */
/* 394 */	0,	/* CALL(%0); */
/* 395 */	0,	/* %0CALL(vAC); */
/* 396 */	0,	/* CALLI(%0); */
/* 397 */	0,	/* CALL(%0); */
/* 398 */	0,	/* %0CALL(vAC); */
/* 399 */	0,	/* CALLI(%0); */
/* 400 */	0,	/* CALL(%0); */
/* 401 */	0,	/* %0CALL(vAC); */
/* 402 */	0,	/* CALLI(%0); */
/* 403 */	0,	/* CALL(%0); */
/* 404 */	0,	/* %0CALL(vAC); */
/* 405 */	0,	/* CALLI(%0); */
/* 406 */	0,	/* CALL(%0); */
/* 407 */	0,	/* %0CALL(vAC); */
/* 408 */	0,	/* CALLI(%0); */
/* 409 */	0,	/* CALL(%0); */
/* 410 */	0,	/* %0CALL(vAC); */
/* 411 */	1,	/* \tCALLI(%0);\n */
/* 412 */	1,	/* \tCALL(%0);\n */
/* 413 */	1,	/* \t%0CALL(vAC);\n */
/* 414 */	1,	/* \t%_FMOV(%0,[SP,%c]);\n */
/* 415 */	1,	/* \t%_LMOV(%0,[SP,%c]);\n */
/* 416 */	1,	/* \t%_LMOV(%0,[SP,%c]);\n */
/* 417 */	1,	/* \t_MOV(%0,[SP,%c]);\n */
/* 418 */	1,	/* \t_MOV(%0,[SP,%c]);\n */
/* 419 */	1,	/* \t_MOV(%0,[SP,%c]);\n */
/* 420 */	1,	/* # arg\n */
/* 421 */	1,	/* # arg\n */
/* 422 */	1,	/* # arg\n */
/* 423 */	1,	/* # arg\n */
/* 424 */	1,	/* # arg\n */
/* 425 */	1,	/* # arg\n */
/* 426 */	1,	/* \t%0\n */
/* 427 */	1,	/* \t%0\n */
/* 428 */	1,	/* \t%0\n */
/* 429 */	1,	/* \t%0\n */
/* 430 */	1,	/* \t%0\n */
/* 431 */	1,	/* \t%0\n */
/* 432 */	0,	/* LD(%0); */
/* 433 */	0,	/* LD(%0); */
/* 434 */	0,	/* %0 */
/* 435 */	0,	/* %0 */
/* 436 */	0,	/* %0 */
/* 437 */	0,	/* %0 */
/* 438 */	0,	/* %0 */
/* 439 */	0,	/* LDW(%0); */
/* 440 */	0,	/* LDW(%0); */
/* 441 */	0,	/* LDW(%0); */
/* 442 */	0,	/* %0LDW(LAC); */
/* 443 */	0,	/* %0LDW(LAC); */
/* 444 */	0,	/* %0LDW(LAC); */
/* 445 */	0,	/* %0 */
/* 446 */	0,	/* %0 */
/* 447 */	0,	/* %0 */
/* 448 */	0,	/* LD(%0);XORI(128);SUBI(128); */
/* 449 */	0,	/* LD(%0); */
/* 450 */	0,	/* %0XORI(128);SUBI(128); */
/* 451 */	0,	/* %0 */
/* 452 */	0,	/* %0LD(vACL);XORI(128);SUBI(128); */
/* 453 */	0,	/* %0LD(vACL); */
/* 454 */	0,	/* %0STW(LAC);LDI(0);STW(LAC+2); */
/* 455 */	0,	/* %0_LCVI(); */
/* 456 */	0,	/* %0STW(LAC);LDI(0);STW(LAC+2); */
/* 457 */	0,	/* %0STW(LAC);LDI(0);STW(LAC+2); */
/* 458 */	1,	/* \t%0STW(%c);LDI(0);STW(%c+2);\n */
/* 459 */	1,	/* \t%0STW(%c);_LEXTS();STW(%c+2);\n */
/* 460 */	1,	/* \t%0STW(%c);LDI(0);STW(%c+2);\n */
/* 461 */	1,	/* \t%0STW(%c);LDI(0);STW(%c+2);\n */
/* 462 */	0,	/* %0_FTOU();LDW(LAC); */
/* 463 */	0,	/* %0_FTOU(); */
/* 464 */	0,	/* %0STW(LAC);LDI(0);STW(LAC+2);_FCVU(); */
/* 465 */	0,	/* %0_FCVU(); */
/* 466 */	0,	/* %0_FTOI();LDW(LAC); */
/* 467 */	0,	/* %0_FTOI(); */
/* 468 */	0,	/* %0_LCVI();_FCVI(); */
/* 469 */	0,	/* %0_FCVI(); */
/* 470 */	1,	/* \tlabel(%a);\n */
/* 471 */	1,	/* \t_BRA(%0);\n */
/* 472 */	1,	/* \tCALL(%0);\n */
/* 473 */	1,	/* \t%0CALL(vAC);\n */
/* 474 */	1,	/* \tSTW(T1);_MOV(%1,[SP,%0]);LDW(T1) #genspill\n */
/* 475 */	1,	/* \tSTW(T1);_MOV(%1,[SP,%0]);LDW(T1) #genspill\n */
/* 476 */	1,	/* \tSTW(T1);_MOV(%1,[SP,%0]);LDW(T1) #genspill\n */
/* 477 */	1,	/* \tSTW(T1);_LMOV(%1,[SP,%0]);LDW(T1) #genspill\n */
/* 478 */	1,	/* \tSTW(T1);_LMOV(%1,[SP,%0]);LDW(T1) #genspill\n */
/* 479 */	1,	/* \tSTW(T1);_FMOV(%1,[SP,%0]);LDW(T1) #genspill\n */
/* 480 */	1,	/* \t%0%[1b]DOKEA(%1);\n */
/* 481 */	1,	/* \t%0%[1b]DOKEA(%1);\n */
/* 482 */	1,	/* \t%0%[1b]DOKEA(%1);\n */
/* 483 */	1,	/* \t%0%[1b]POKEA(%1);\n */
/* 484 */	1,	/* \t%0%[1b]POKEA(%1);\n */
/* 485 */	1,	/* \t%0%[1b]DOKEI(%1);\n */
/* 486 */	1,	/* \t%0%[1b]DOKEI(%1);\n */
/* 487 */	1,	/* \t%0%[1b]DOKEI(%1);\n */
/* 488 */	1,	/* \t%0%[1b]POKEI(%1);\n */
/* 489 */	1,	/* \t%0%[1b]POKEI(%1);\n */
/* 490 */	1,	/* \t%0%[1b]POKEI(%1);\n */
/* 491 */	1,	/* \t%1STW2(%0);\n */
/* 492 */	1,	/* \t%1STW2(%0);\n */
/* 493 */	1,	/* \t%1STW2(%0);\n */
/* 494 */	1,	/* \t%1ST2(%0);\n */
/* 495 */	1,	/* \t%1ST2(%0);\n */
/* 496 */	1,	/* \t%{#canVAC}%0%{dst!=vAC:DEEKA(%c)}%{dst==vAC:DEEK()};\n */
/* 497 */	1,	/* \t%{#canVAC}%0%{dst!=vAC:DEEKA(%c)}%{dst==vAC:DEEK()};\n */
/* 498 */	1,	/* \t%{#canVAC}%0%{dst!=vAC:DEEKA(%c)}%{dst==vAC:DEEK()};\n */
/* 499 */	1,	/* \t%{#canVAC}%0%{dst!=vAC:PEEKA(%c)}%{dst==vAC:PEEK()};\n */
/* 500 */	1,	/* \t%{#canVAC}%0%{dst!=vAC:PEEKA(%c)}%{dst==vAC:PEEK()};\n */
/* 501 */	0,	/* %{src!=vAC:DEEKV(%0)}%{src==vAC:DEEK()}; */
/* 502 */	0,	/* %{src!=vAC:DEEKV(%0)}%{src==vAC:DEEK()}; */
/* 503 */	0,	/* %{src!=vAC:DEEKV(%0)}%{src==vAC:DEEK()}; */
/* 504 */	0,	/* %{src!=vAC:PEEKV(%0)}%{src==vAC:PEEK()}; */
/* 505 */	0,	/* %{src!=vAC:PEEKV(%0)}%{src==vAC:PEEK()}; */
/* 506 */	0,	/* %0ADDWI(%1); */
/* 507 */	0,	/* %0ADDWI(%1); */
/* 508 */	0,	/* %0ADDWI(%1); */
/* 509 */	0,	/* %0SUBWI(%1); */
/* 510 */	0,	/* %0SUBWI(%1); */
/* 511 */	0,	/* %0SUBWI(%1); */
/* 512 */	0,	/* %0ANDWI(%1); */
/* 513 */	0,	/* %0ANDWI(%1); */
/* 514 */	0,	/* %0ORWI(%1); */
/* 515 */	0,	/* %0ORWI(%1); */
/* 516 */	0,	/* %0XORWI(%1); */
/* 517 */	0,	/* %0XORWI(%1); */
/* 518 */	0,	/* ANDBK(%0,%1); */
/* 519 */	0,	/* ANDBK(%0,%1); */
/* 520 */	0,	/* ORBK(%0,%1); */
/* 521 */	0,	/* ORBK(%0,%1); */
/* 522 */	0,	/* XORBK(%0,%1); */
/* 523 */	0,	/* XORBK(%0,%1); */
/* 524 */	0,	/* %0NEGW(vAC); */
/* 525 */	0,	/* LDW(%0);NEGW(vAC); */
/* 526 */	0,	/* %0ADDBA(%1); */
/* 527 */	0,	/* %0ADDBA(%1); */
/* 528 */	0,	/* %0SUBBA(%1); */
/* 529 */	0,	/* %0SUBBA(%1); */
/* 530 */	0,	/* %a */
/* 531 */	0,	/* %0 */
/* 532 */	1,	/* \tINC(%0);\n */
/* 533 */	1,	/* \tINC(%0);\n */
/* 534 */	1,	/* \tDEC(%0);\n */
/* 535 */	1,	/* \tDEC(%0);\n */
/* 536 */	1,	/* \tINCW(%0);\n */
/* 537 */	1,	/* \tINCW(%0);\n */
/* 538 */	1,	/* \tINCW(%0);\n */
/* 539 */	1,	/* \tINCW(%0);\n */
/* 540 */	1,	/* \tDECW(%0);\n */
/* 541 */	1,	/* \tDECW(%0);\n */
/* 542 */	1,	/* \tDECW(%0);\n */
/* 543 */	1,	/* \tDECW(%0);\n */
/* 544 */	1,	/* \tDECW(%0);\n */
/* 545 */	1,	/* \tDECW(%0);\n */
/* 546 */	1,	/* \tNEGW(%0);\n */
/* 547 */	1,	/* \tNOTW(%0);\n */
/* 548 */	1,	/* \tNOTW(%0);\n */
/* 549 */	1,	/* \tLSLV(%0);\n */
/* 550 */	1,	/* \tLSLV(%0);\n */
/* 551 */	1,	/* \tMOVQW(%1,%0)\n */
/* 552 */	1,	/* \tMOVQW(%1,%0)\n */
/* 553 */	1,	/* \tMOVQW(%1,%0)\n */
/* 554 */	1,	/* \tMOVQ(%1,%0)\n */
/* 555 */	1,	/* \tMOVQ(%1,%0)\n */
};

static char *_string[] = {
/* 0 */	0,
/* 1 */	"reg: INDIRI1(VREGP)",
/* 2 */	"reg: INDIRU1(VREGP)",
/* 3 */	"reg: INDIRI2(VREGP)",
/* 4 */	"reg: INDIRU2(VREGP)",
/* 5 */	"reg: INDIRP2(VREGP)",
/* 6 */	"reg: INDIRI4(VREGP)",
/* 7 */	"reg: INDIRU4(VREGP)",
/* 8 */	"reg: INDIRF5(VREGP)",
/* 9 */	"stmt: ASGNI1(VREGP,reg)",
/* 10 */	"stmt: ASGNU1(VREGP,reg)",
/* 11 */	"stmt: ASGNI2(VREGP,reg)",
/* 12 */	"stmt: ASGNU2(VREGP,reg)",
/* 13 */	"stmt: ASGNP2(VREGP,reg)",
/* 14 */	"stmt: ASGNI4(VREGP,reg)",
/* 15 */	"stmt: ASGNU4(VREGP,reg)",
/* 16 */	"stmt: ASGNF5(VREGP,reg)",
/* 17 */	"reg: LOADI1(reg)",
/* 18 */	"reg: LOADU1(reg)",
/* 19 */	"reg: LOADI2(reg)",
/* 20 */	"reg: LOADU2(reg)",
/* 21 */	"reg: LOADP2(reg)",
/* 22 */	"reg: LOADI4(reg)",
/* 23 */	"reg: LOADU4(reg)",
/* 24 */	"reg: LOADF5(reg)",
/* 25 */	"reg: LOADI1(conBs)",
/* 26 */	"reg: LOADU1(conB)",
/* 27 */	"reg: LOADI2(con)",
/* 28 */	"reg: LOADU2(con)",
/* 29 */	"reg: LOADP2(con)",
/* 30 */	"con0: CNSTI1",
/* 31 */	"con0: CNSTU1",
/* 32 */	"con0: CNSTI2",
/* 33 */	"con0: CNSTU2",
/* 34 */	"con0: CNSTP2",
/* 35 */	"con1: CNSTI1",
/* 36 */	"con1: CNSTU1",
/* 37 */	"con1: CNSTI2",
/* 38 */	"con1: CNSTU2",
/* 39 */	"con1n: CNSTI1",
/* 40 */	"con1n: CNSTI2",
/* 41 */	"conB: CNSTI2",
/* 42 */	"conB: CNSTU2",
/* 43 */	"conB: CNSTP2",
/* 44 */	"conB: CNSTI1",
/* 45 */	"conB: CNSTU1",
/* 46 */	"conB: zddr",
/* 47 */	"conBn: CNSTI2",
/* 48 */	"conBs: CNSTI2",
/* 49 */	"conBs: CNSTI1",
/* 50 */	"con: CNSTI1",
/* 51 */	"con: CNSTU1",
/* 52 */	"con: CNSTI2",
/* 53 */	"con: CNSTU2",
/* 54 */	"con: CNSTP2",
/* 55 */	"con: addr",
/* 56 */	"lddr: ADDRLP2",
/* 57 */	"lddr: ADDRFP2",
/* 58 */	"addr: ADDRGP2",
/* 59 */	"addr: con",
/* 60 */	"addr: zddr",
/* 61 */	"zddr: ADDRGP2",
/* 62 */	"zddr: conB",
/* 63 */	"stmt: reg",
/* 64 */	"stmt: ac",
/* 65 */	"reg: ac",
/* 66 */	"ac: reg",
/* 67 */	"ac: ac0",
/* 68 */	"ac: eac",
/* 69 */	"ac0: eac0",
/* 70 */	"ac0: conB",
/* 71 */	"ac: con",
/* 72 */	"ac: zddr",
/* 73 */	"ac: addr",
/* 74 */	"eac: reg",
/* 75 */	"eac: eac0",
/* 76 */	"eac0: zddr",
/* 77 */	"eac: addr",
/* 78 */	"eac: lddr",
/* 79 */	"eac: INDIRI2(eac)",
/* 80 */	"eac: INDIRU2(eac)",
/* 81 */	"eac: INDIRP2(eac)",
/* 82 */	"eac0: INDIRI1(eac)",
/* 83 */	"eac0: INDIRU1(eac)",
/* 84 */	"eac: INDIRI2(zddr)",
/* 85 */	"eac: INDIRU2(zddr)",
/* 86 */	"eac: INDIRP2(zddr)",
/* 87 */	"eac0: INDIRI1(zddr)",
/* 88 */	"eac0: INDIRU1(zddr)",
/* 89 */	"ac: INDIRI2(ac)",
/* 90 */	"ac: INDIRU2(ac)",
/* 91 */	"ac: INDIRP2(ac)",
/* 92 */	"ac0: INDIRI1(ac)",
/* 93 */	"ac0: INDIRU1(ac)",
/* 94 */	"iarg: reg",
/* 95 */	"iarg: INDIRI2(zddr)",
/* 96 */	"iarg: INDIRU2(zddr)",
/* 97 */	"iarg: INDIRP2(zddr)",
/* 98 */	"spill: ADDRLP2",
/* 99 */	"iarg: INDIRU2(spill)",
/* 100 */	"iarg: INDIRI2(spill)",
/* 101 */	"iarg: INDIRP2(spill)",
/* 102 */	"ac: ADDI2(ac,iarg)",
/* 103 */	"ac: ADDU2(ac,iarg)",
/* 104 */	"ac: ADDP2(ac,iarg)",
/* 105 */	"ac: ADDI2(iarg,ac)",
/* 106 */	"ac: ADDU2(iarg,ac)",
/* 107 */	"ac: ADDP2(iarg,ac)",
/* 108 */	"ac: ADDI2(ac,conB)",
/* 109 */	"ac: ADDU2(ac,conB)",
/* 110 */	"ac: ADDP2(ac,conB)",
/* 111 */	"ac: ADDI2(ac,conBn)",
/* 112 */	"ac: ADDU2(ac,conBn)",
/* 113 */	"ac: ADDP2(ac,conBn)",
/* 114 */	"ac: SUBI2(ac,iarg)",
/* 115 */	"ac: SUBU2(ac,iarg)",
/* 116 */	"ac: SUBP2(ac,iarg)",
/* 117 */	"ac: SUBI2(ac,conB)",
/* 118 */	"ac: SUBU2(ac,conB)",
/* 119 */	"ac: SUBP2(ac,conB)",
/* 120 */	"ac: SUBI2(ac,conBn)",
/* 121 */	"ac: SUBU2(ac,conBn)",
/* 122 */	"ac: SUBP2(ac,conBn)",
/* 123 */	"ac: NEGI2(ac)",
/* 124 */	"ac: NEGI2(reg)",
/* 125 */	"ac: LSHI2(ac,con1)",
/* 126 */	"ac: LSHU2(ac,con1)",
/* 127 */	"ac: LSHI2(ac,conB)",
/* 128 */	"ac: LSHU2(ac,conB)",
/* 129 */	"ac: RSHI2(ac,conB)",
/* 130 */	"ac: RSHU2(ac,conB)",
/* 131 */	"ac: LSHI2(ac,iarg)",
/* 132 */	"ac: RSHI2(ac,iarg)",
/* 133 */	"ac: LSHU2(ac,iarg)",
/* 134 */	"ac: RSHU2(ac,iarg)",
/* 135 */	"ac: MULI2(conB,ac)",
/* 136 */	"ac: MULI2(conBn,ac)",
/* 137 */	"ac: MULI2(conB,reg)",
/* 138 */	"ac: MULI2(conBn,reg)",
/* 139 */	"ac: MULI2(con,ac)",
/* 140 */	"ac: MULI2(ac,iarg)",
/* 141 */	"ac: MULI2(iarg,ac)",
/* 142 */	"ac: MULU2(conB,ac)",
/* 143 */	"ac: MULU2(con,ac)",
/* 144 */	"ac: MULU2(ac,iarg)",
/* 145 */	"ac: MULU2(iarg,ac)",
/* 146 */	"ac: DIVI2(ac,iarg)",
/* 147 */	"ac: DIVU2(ac,iarg)",
/* 148 */	"ac: MODI2(ac,iarg)",
/* 149 */	"ac: MODU2(ac,iarg)",
/* 150 */	"ac: DIVI2(ac,con)",
/* 151 */	"ac: DIVU2(ac,con)",
/* 152 */	"ac: MODI2(ac,con)",
/* 153 */	"ac: MODU2(ac,con)",
/* 154 */	"ac: BCOMI2(ac)",
/* 155 */	"ac: BCOMU2(ac)",
/* 156 */	"ac: BANDI2(ac,iarg)",
/* 157 */	"ac: BANDU2(ac,iarg)",
/* 158 */	"ac: BANDI2(iarg,ac)",
/* 159 */	"ac: BANDU2(iarg,ac)",
/* 160 */	"ac: BANDI2(ac,conB)",
/* 161 */	"ac: BANDU2(ac,conB)",
/* 162 */	"ac: BORI2(ac,iarg)",
/* 163 */	"ac: BORU2(ac,iarg)",
/* 164 */	"ac: BORI2(iarg,ac)",
/* 165 */	"ac: BORU2(iarg,ac)",
/* 166 */	"ac: BORI2(ac,conB)",
/* 167 */	"ac: BORU2(ac,conB)",
/* 168 */	"ac: BXORI2(ac,iarg)",
/* 169 */	"ac: BXORU2(ac,iarg)",
/* 170 */	"ac: BXORI2(iarg,ac)",
/* 171 */	"ac: BXORU2(iarg,ac)",
/* 172 */	"ac: BXORI2(ac,conB)",
/* 173 */	"ac: BXORU2(ac,conB)",
/* 174 */	"eac: ADDI2(eac,conB)",
/* 175 */	"eac: ADDU2(eac,conB)",
/* 176 */	"eac: ADDP2(eac,conB)",
/* 177 */	"eac: ADDI2(eac,conBn)",
/* 178 */	"eac: ADDU2(eac,conBn)",
/* 179 */	"eac: ADDP2(eac,conBn)",
/* 180 */	"eac: SUBI2(eac,conB)",
/* 181 */	"eac: SUBU2(eac,conB)",
/* 182 */	"eac: SUBP2(eac,conB)",
/* 183 */	"eac: SUBI2(eac,conBn)",
/* 184 */	"eac: SUBU2(eac,conBn)",
/* 185 */	"eac: SUBP2(eac,conBn)",
/* 186 */	"eac: LSHI2(eac,con1)",
/* 187 */	"eac: LSHU2(eac,con1)",
/* 188 */	"eac: LSHI2(eac,conB)",
/* 189 */	"eac: LSHU2(eac,conB)",
/* 190 */	"eac: MULI2(conB,eac)",
/* 191 */	"eac: MULI2(conB,eac)",
/* 192 */	"eac: ADDI2(eac,iarg)",
/* 193 */	"eac: ADDU2(eac,iarg)",
/* 194 */	"eac: ADDP2(eac,iarg)",
/* 195 */	"eac: ADDI2(iarg,eac)",
/* 196 */	"eac: ADDU2(iarg,eac)",
/* 197 */	"eac: ADDP2(iarg,eac)",
/* 198 */	"eac: SUBI2(eac,iarg)",
/* 199 */	"eac: SUBU2(eac,iarg)",
/* 200 */	"eac: SUBP2(eac,iarg)",
/* 201 */	"stmt: ASGNP2(zddr,ac)",
/* 202 */	"stmt: ASGNP2(iarg,ac)",
/* 203 */	"stmt: ASGNI2(zddr,ac)",
/* 204 */	"stmt: ASGNI2(iarg,ac)",
/* 205 */	"stmt: ASGNU2(zddr,ac)",
/* 206 */	"stmt: ASGNU2(iarg,ac)",
/* 207 */	"stmt: ASGNI1(zddr,ac)",
/* 208 */	"stmt: ASGNI1(iarg,ac)",
/* 209 */	"stmt: ASGNU1(zddr,ac)",
/* 210 */	"stmt: ASGNU1(iarg,ac)",
/* 211 */	"stmt: EQI2(ac,con0)",
/* 212 */	"stmt: EQI2(ac,conB)",
/* 213 */	"stmt: EQI2(ac,iarg)",
/* 214 */	"stmt: EQI2(iarg,ac)",
/* 215 */	"stmt: NEI2(ac,con0)",
/* 216 */	"stmt: NEI2(ac,conB)",
/* 217 */	"stmt: NEI2(ac,iarg)",
/* 218 */	"stmt: NEI2(iarg,ac)",
/* 219 */	"stmt: EQU2(ac,con0)",
/* 220 */	"stmt: EQU2(ac,conB)",
/* 221 */	"stmt: EQU2(ac,iarg)",
/* 222 */	"stmt: EQU2(iarg,ac)",
/* 223 */	"stmt: NEU2(ac,con0)",
/* 224 */	"stmt: NEU2(ac,conB)",
/* 225 */	"stmt: NEU2(ac,iarg)",
/* 226 */	"stmt: NEU2(iarg,ac)",
/* 227 */	"stmt: LTI2(ac,con0)",
/* 228 */	"stmt: LEI2(ac,con0)",
/* 229 */	"stmt: GTI2(ac,con0)",
/* 230 */	"stmt: GEI2(ac,con0)",
/* 231 */	"stmt: GTU2(ac,con0)",
/* 232 */	"stmt: LEU2(ac,con0)",
/* 233 */	"stmt: LTI2(ac,conB)",
/* 234 */	"stmt: LEI2(ac,conB)",
/* 235 */	"stmt: GTI2(ac,conB)",
/* 236 */	"stmt: GEI2(ac,conB)",
/* 237 */	"stmt: LTU2(ac,conB)",
/* 238 */	"stmt: LEU2(ac,conB)",
/* 239 */	"stmt: GTU2(ac,conB)",
/* 240 */	"stmt: GEU2(ac,conB)",
/* 241 */	"stmt: LTI2(ac,iarg)",
/* 242 */	"stmt: LEI2(ac,iarg)",
/* 243 */	"stmt: GTI2(ac,iarg)",
/* 244 */	"stmt: GEI2(ac,iarg)",
/* 245 */	"stmt: LTU2(ac,iarg)",
/* 246 */	"stmt: LEU2(ac,iarg)",
/* 247 */	"stmt: GTU2(ac,iarg)",
/* 248 */	"stmt: GEU2(ac,iarg)",
/* 249 */	"stmt: LTI2(iarg,ac)",
/* 250 */	"stmt: LEI2(iarg,ac)",
/* 251 */	"stmt: GTI2(iarg,ac)",
/* 252 */	"stmt: GEI2(iarg,ac)",
/* 253 */	"stmt: LTU2(iarg,ac)",
/* 254 */	"stmt: LEU2(iarg,ac)",
/* 255 */	"stmt: GTU2(iarg,ac)",
/* 256 */	"stmt: GEU2(iarg,ac)",
/* 257 */	"vdst: addr",
/* 258 */	"vdst: lddr",
/* 259 */	"vdst: eac",
/* 260 */	"asrc: addr",
/* 261 */	"asrc: lddr",
/* 262 */	"asrc: eac",
/* 263 */	"lsrc: addr",
/* 264 */	"stmt: ARGB(INDIRB(asrc))",
/* 265 */	"stmt: ASGNB(addr,INDIRB(asrc))",
/* 266 */	"stmt: ASGNB(ac,INDIRB(asrc))",
/* 267 */	"stmt: ASGNB(lddr,INDIRB(lsrc))",
/* 268 */	"stmt: lac",
/* 269 */	"larg: reg",
/* 270 */	"larg: INDIRI4(eac)",
/* 271 */	"larg: INDIRU4(eac)",
/* 272 */	"reg: lac",
/* 273 */	"reg: INDIRI4(ac)",
/* 274 */	"reg: INDIRU4(ac)",
/* 275 */	"reg: INDIRI4(lddr)",
/* 276 */	"reg: INDIRU4(lddr)",
/* 277 */	"reg: INDIRI4(addr)",
/* 278 */	"reg: INDIRU4(addr)",
/* 279 */	"lac: reg",
/* 280 */	"lac: INDIRI4(ac)",
/* 281 */	"lac: INDIRU4(ac)",
/* 282 */	"lac: INDIRU4(lddr)",
/* 283 */	"lac: INDIRU4(lddr)",
/* 284 */	"lac: INDIRI4(addr)",
/* 285 */	"lac: INDIRU4(addr)",
/* 286 */	"lac: ADDI4(lac,larg)",
/* 287 */	"lac: ADDU4(lac,larg)",
/* 288 */	"lac: ADDI4(larg,lac)",
/* 289 */	"lac: ADDU4(larg,lac)",
/* 290 */	"lac: SUBI4(lac,larg)",
/* 291 */	"lac: SUBU4(lac,larg)",
/* 292 */	"lac: MULI4(lac,larg)",
/* 293 */	"lac: MULU4(lac,larg)",
/* 294 */	"lac: MULI4(larg,lac)",
/* 295 */	"lac: MULU4(larg,lac)",
/* 296 */	"lac: DIVI4(lac,larg)",
/* 297 */	"lac: DIVU4(lac,larg)",
/* 298 */	"lac: MODI4(lac,larg)",
/* 299 */	"lac: MODU4(lac,larg)",
/* 300 */	"lac: LSHI4(lac,reg)",
/* 301 */	"lac: LSHI4(lac,conB)",
/* 302 */	"lac: LSHU4(lac,reg)",
/* 303 */	"lac: LSHU4(lac,conB)",
/* 304 */	"lac: RSHI4(lac,reg)",
/* 305 */	"lac: RSHI4(lac,conB)",
/* 306 */	"lac: RSHU4(lac,reg)",
/* 307 */	"lac: RSHU4(lac,conB)",
/* 308 */	"lac: NEGI4(lac)",
/* 309 */	"lac: BCOMU4(lac)",
/* 310 */	"lac: BANDU4(lac,larg)",
/* 311 */	"lac: BANDU4(larg,lac)",
/* 312 */	"lac: BORU4(lac,larg)",
/* 313 */	"lac: BORU4(larg,lac)",
/* 314 */	"lac: BXORU4(lac,larg)",
/* 315 */	"lac: BXORU4(larg,lac)",
/* 316 */	"lac: BCOMI4(lac)",
/* 317 */	"lac: BANDI4(lac,larg)",
/* 318 */	"lac: BANDI4(larg,lac)",
/* 319 */	"lac: BORI4(lac,larg)",
/* 320 */	"lac: BORI4(larg,lac)",
/* 321 */	"lac: BXORI4(lac,larg)",
/* 322 */	"lac: BXORI4(larg,lac)",
/* 323 */	"stmt: LTI4(lac,larg)",
/* 324 */	"stmt: LEI4(lac,larg)",
/* 325 */	"stmt: GTI4(lac,larg)",
/* 326 */	"stmt: GEI4(lac,larg)",
/* 327 */	"stmt: LTU4(lac,larg)",
/* 328 */	"stmt: LEU4(lac,larg)",
/* 329 */	"stmt: GTU4(lac,larg)",
/* 330 */	"stmt: GEU4(lac,larg)",
/* 331 */	"stmt: NEI4(lac,larg)",
/* 332 */	"stmt: EQI4(lac,larg)",
/* 333 */	"stmt: NEU4(lac,larg)",
/* 334 */	"stmt: EQU4(lac,larg)",
/* 335 */	"stmt: LTI4(larg,lac)",
/* 336 */	"stmt: LEI4(larg,lac)",
/* 337 */	"stmt: GTI4(larg,lac)",
/* 338 */	"stmt: GEI4(larg,lac)",
/* 339 */	"stmt: LTU4(larg,lac)",
/* 340 */	"stmt: LEU4(larg,lac)",
/* 341 */	"stmt: GTU4(larg,lac)",
/* 342 */	"stmt: GEU4(larg,lac)",
/* 343 */	"stmt: NEI4(larg,lac)",
/* 344 */	"stmt: EQI4(larg,lac)",
/* 345 */	"stmt: NEU4(larg,lac)",
/* 346 */	"stmt: EQU4(larg,lac)",
/* 347 */	"stmt: ASGNI4(vdst,lac)",
/* 348 */	"stmt: ASGNI4(vdst,reg)",
/* 349 */	"stmt: ASGNI4(addr,INDIRI4(asrc))",
/* 350 */	"stmt: ASGNI4(ac,INDIRI4(asrc))",
/* 351 */	"stmt: ASGNI4(lddr,INDIRI4(lsrc))",
/* 352 */	"stmt: ASGNU4(vdst,lac)",
/* 353 */	"stmt: ASGNU4(vdst,reg)",
/* 354 */	"stmt: ASGNU4(addr,INDIRU4(asrc))",
/* 355 */	"stmt: ASGNU4(ac,INDIRU4(asrc))",
/* 356 */	"stmt: ASGNU4(lddr,INDIRU4(lsrc))",
/* 357 */	"stmt: fac",
/* 358 */	"farg: reg",
/* 359 */	"farg: INDIRF5(eac)",
/* 360 */	"reg: fac",
/* 361 */	"reg: INDIRF5(ac)",
/* 362 */	"reg: INDIRF5(lddr)",
/* 363 */	"reg: INDIRF5(addr)",
/* 364 */	"fac: reg",
/* 365 */	"fac: INDIRF5(ac)",
/* 366 */	"fac: INDIRF5(lddr)",
/* 367 */	"fac: INDIRF5(addr)",
/* 368 */	"fac: ADDF5(fac,farg)",
/* 369 */	"fac: ADDF5(farg,fac)",
/* 370 */	"fac: SUBF5(fac,farg)",
/* 371 */	"fac: SUBF5(farg,fac)",
/* 372 */	"fac: MULF5(fac,farg)",
/* 373 */	"fac: MULF5(farg,fac)",
/* 374 */	"fac: DIVF5(fac,farg)",
/* 375 */	"fac: NEGF5(fac)",
/* 376 */	"stmt: EQF5(fac,farg)",
/* 377 */	"stmt: NEF5(fac,farg)",
/* 378 */	"stmt: LTF5(fac,farg)",
/* 379 */	"stmt: LEF5(fac,farg)",
/* 380 */	"stmt: GTF5(fac,farg)",
/* 381 */	"stmt: GEF5(fac,farg)",
/* 382 */	"stmt: EQF5(farg,fac)",
/* 383 */	"stmt: NEF5(farg,fac)",
/* 384 */	"stmt: LTF5(farg,fac)",
/* 385 */	"stmt: LEF5(farg,fac)",
/* 386 */	"stmt: GTF5(farg,fac)",
/* 387 */	"stmt: GEF5(farg,fac)",
/* 388 */	"stmt: ASGNF5(vdst,fac)",
/* 389 */	"stmt: ASGNF5(vdst,reg)",
/* 390 */	"stmt: ASGNF5(addr,INDIRF5(asrc))",
/* 391 */	"stmt: ASGNF5(ac,INDIRF5(asrc))",
/* 392 */	"stmt: ASGNF5(lddr,INDIRF5(lsrc))",
/* 393 */	"fac: CALLF5(addr)",
/* 394 */	"fac: CALLF5(reg)",
/* 395 */	"fac: CALLF5(ac)",
/* 396 */	"lac: CALLI4(addr)",
/* 397 */	"lac: CALLI4(reg)",
/* 398 */	"lac: CALLI4(ac)",
/* 399 */	"lac: CALLU4(addr)",
/* 400 */	"lac: CALLU4(reg)",
/* 401 */	"lac: CALLU4(ac)",
/* 402 */	"ac: CALLI2(addr)",
/* 403 */	"ac: CALLI2(reg)",
/* 404 */	"ac: CALLI2(ac)",
/* 405 */	"ac: CALLU2(addr)",
/* 406 */	"ac: CALLU2(reg)",
/* 407 */	"ac: CALLU2(ac)",
/* 408 */	"ac: CALLP2(addr)",
/* 409 */	"ac: CALLP2(reg)",
/* 410 */	"ac: CALLP2(ac)",
/* 411 */	"stmt: CALLV(addr)",
/* 412 */	"stmt: CALLV(reg)",
/* 413 */	"stmt: CALLV(ac)",
/* 414 */	"stmt: ARGF5(reg)",
/* 415 */	"stmt: ARGI4(reg)",
/* 416 */	"stmt: ARGU4(reg)",
/* 417 */	"stmt: ARGI2(reg)",
/* 418 */	"stmt: ARGU2(reg)",
/* 419 */	"stmt: ARGP2(reg)",
/* 420 */	"stmt: ARGF5(reg)",
/* 421 */	"stmt: ARGI4(reg)",
/* 422 */	"stmt: ARGU4(reg)",
/* 423 */	"stmt: ARGI2(reg)",
/* 424 */	"stmt: ARGU2(reg)",
/* 425 */	"stmt: ARGP2(reg)",
/* 426 */	"stmt: RETF5(fac)",
/* 427 */	"stmt: RETI4(lac)",
/* 428 */	"stmt: RETU4(lac)",
/* 429 */	"stmt: RETI2(ac)",
/* 430 */	"stmt: RETU2(ac)",
/* 431 */	"stmt: RETP2(ac)",
/* 432 */	"ac0: LOADI1(reg)",
/* 433 */	"ac0: LOADU1(reg)",
/* 434 */	"ac: LOADI1(ac)",
/* 435 */	"ac: LOADU1(ac)",
/* 436 */	"ac: LOADI2(ac)",
/* 437 */	"ac: LOADU2(ac)",
/* 438 */	"ac: LOADP2(ac)",
/* 439 */	"ac: LOADI2(reg)",
/* 440 */	"ac: LOADU2(reg)",
/* 441 */	"ac: LOADP2(reg)",
/* 442 */	"ac: LOADI2(lac)",
/* 443 */	"ac: LOADU2(lac)",
/* 444 */	"ac: LOADP2(lac)",
/* 445 */	"lac: LOADI4(lac)",
/* 446 */	"lac: LOADU4(lac)",
/* 447 */	"fac: LOADF5(fac)",
/* 448 */	"ac: CVII2(reg)",
/* 449 */	"ac: CVUI2(reg)",
/* 450 */	"ac: CVII2(ac0)",
/* 451 */	"ac: CVUI2(ac0)",
/* 452 */	"ac: CVII2(ac)",
/* 453 */	"ac: CVUI2(ac)",
/* 454 */	"lac: CVIU4(ac)",
/* 455 */	"lac: CVII4(ac)",
/* 456 */	"lac: CVUU4(ac)",
/* 457 */	"lac: CVUI4(ac)",
/* 458 */	"reg: CVIU4(ac)",
/* 459 */	"reg: CVII4(ac)",
/* 460 */	"reg: CVUU4(ac)",
/* 461 */	"reg: CVUI4(ac)",
/* 462 */	"ac: CVFU2(fac)",
/* 463 */	"lac: CVFU4(fac)",
/* 464 */	"fac: CVUF5(ac)",
/* 465 */	"fac: CVUF5(lac)",
/* 466 */	"ac: CVFI2(fac)",
/* 467 */	"lac: CVFI4(fac)",
/* 468 */	"fac: CVIF5(ac)",
/* 469 */	"fac: CVIF5(lac)",
/* 470 */	"stmt: LABELV",
/* 471 */	"stmt: JUMPV(addr)",
/* 472 */	"stmt: JUMPV(reg)",
/* 473 */	"stmt: JUMPV(ac)",
/* 474 */	"stmt: ASGNI2(spill,reg)",
/* 475 */	"stmt: ASGNU2(spill,reg)",
/* 476 */	"stmt: ASGNP2(spill,reg)",
/* 477 */	"stmt: ASGNI4(spill,reg)",
/* 478 */	"stmt: ASGNU4(spill,reg)",
/* 479 */	"stmt: ASGNF5(spill,reg)",
/* 480 */	"stmt: ASGNP2(ac,iarg)",
/* 481 */	"stmt: ASGNI2(ac,iarg)",
/* 482 */	"stmt: ASGNU2(ac,iarg)",
/* 483 */	"stmt: ASGNI1(ac,iarg)",
/* 484 */	"stmt: ASGNU1(ac,iarg)",
/* 485 */	"stmt: ASGNP2(ac,con)",
/* 486 */	"stmt: ASGNI2(ac,con)",
/* 487 */	"stmt: ASGNU2(ac,con)",
/* 488 */	"stmt: ASGNI1(ac,conB)",
/* 489 */	"stmt: ASGNI1(ac,conBs)",
/* 490 */	"stmt: ASGNU1(ac,conB)",
/* 491 */	"stmt: ASGNP2(addr,ac)",
/* 492 */	"stmt: ASGNI2(addr,ac)",
/* 493 */	"stmt: ASGNU2(addr,ac)",
/* 494 */	"stmt: ASGNI1(addr,ac)",
/* 495 */	"stmt: ASGNU1(addr,ac)",
/* 496 */	"reg: INDIRI2(ac)",
/* 497 */	"reg: INDIRU2(ac)",
/* 498 */	"reg: INDIRP2(ac)",
/* 499 */	"reg: INDIRI1(ac)",
/* 500 */	"reg: INDIRU1(ac)",
/* 501 */	"ac: INDIRI2(reg)",
/* 502 */	"ac: INDIRU2(reg)",
/* 503 */	"ac: INDIRP2(reg)",
/* 504 */	"ac: INDIRI1(reg)",
/* 505 */	"ac: INDIRU1(reg)",
/* 506 */	"ac: ADDI2(ac,con)",
/* 507 */	"ac: ADDU2(ac,con)",
/* 508 */	"ac: ADDP2(ac,con)",
/* 509 */	"ac: SUBI2(ac,con)",
/* 510 */	"ac: SUBU2(ac,con)",
/* 511 */	"ac: SUBP2(ac,con)",
/* 512 */	"ac: BANDI2(ac,con)",
/* 513 */	"ac: BANDU2(ac,con)",
/* 514 */	"ac: BORI2(ac,con)",
/* 515 */	"ac: BORU2(ac,con)",
/* 516 */	"ac: BXORI2(ac,con)",
/* 517 */	"ac: BXORU2(ac,con)",
/* 518 */	"ac: BANDI2(reg,conB)",
/* 519 */	"ac: BANDU2(reg,conB)",
/* 520 */	"ac: BORI2(CVUI2(reg),conB)",
/* 521 */	"ac: BORU2(CVUI2(reg),conB)",
/* 522 */	"ac: BXORI2(CVUI2(reg),conB)",
/* 523 */	"ac: BXORU2(CVUI2(reg),conB)",
/* 524 */	"ac: NEGI2(ac)",
/* 525 */	"ac: NEGI2(reg)",
/* 526 */	"ac: ADDI2(ac,CVUI2(iarg))",
/* 527 */	"ac: ADDU2(ac,CVUI2(iarg))",
/* 528 */	"ac: SUBU2(ac,CVUI2(iarg))",
/* 529 */	"ac: SUBI2(ac,CVUI2(iarg))",
/* 530 */	"rmw: VREGP",
/* 531 */	"rmw: zddr",
/* 532 */	"stmt: ASGNU1(rmw,LOADU1(ADDI2(CVUI2(INDIRU1(rmw)),con1)))",
/* 533 */	"stmt: ASGNI1(rmw,LOADI1(ADDI2(CVII2(INDIRI1(rmw)),con1)))",
/* 534 */	"stmt: ASGNU1(rmw,LOADU1(SUBI2(CVUI2(INDIRU1(rmw)),con1)))",
/* 535 */	"stmt: ASGNI1(rmw,LOADI1(SUBI2(CVII2(INDIRI1(rmw)),con1)))",
/* 536 */	"stmt: ASGNP2(rmw,ADDP2(INDIRP2(rmw),con1))",
/* 537 */	"stmt: ASGNP2(rmw,ADDP2(INDIRP2(rmw),con1))",
/* 538 */	"stmt: ASGNU2(rmw,ADDU2(INDIRU2(rmw),con1))",
/* 539 */	"stmt: ASGNI2(rmw,ADDI2(INDIRI2(rmw),con1))",
/* 540 */	"stmt: ASGNP2(rmw,SUBP2(INDIRP2(rmw),con1))",
/* 541 */	"stmt: ASGNU2(rmw,SUBU2(INDIRU2(rmw),con1))",
/* 542 */	"stmt: ASGNI2(rmw,SUBI2(INDIRI2(rmw),con1))",
/* 543 */	"stmt: ASGNP2(rmw,ADDP2(INDIRP2(rmw),con1n))",
/* 544 */	"stmt: ASGNU2(rmw,ADDU2(INDIRU2(rmw),con1n))",
/* 545 */	"stmt: ASGNI2(rmw,ADDI2(INDIRI2(rmw),con1n))",
/* 546 */	"stmt: ASGNI2(rmw,NEGI2(INDIRI2(rmw)))",
/* 547 */	"stmt: ASGNI2(rmw,BCOMI2(INDIRI2(rmw)))",
/* 548 */	"stmt: ASGNU2(rmw,BCOMU2(INDIRU2(rmw)))",
/* 549 */	"stmt: ASGNI2(rmw,LSHI2(INDIRI2(rmw),con1))",
/* 550 */	"stmt: ASGNU2(rmw,LSHU2(INDIRU2(rmw),con1))",
/* 551 */	"stmt: ASGNI2(rmw,conB)",
/* 552 */	"stmt: ASGNU2(rmw,conB)",
/* 553 */	"stmt: ASGNP2(rmw,conB)",
/* 554 */	"stmt: ASGNI1(rmw,conB)",
/* 555 */	"stmt: ASGNU1(rmw,conB)",
};

static short _decode_stmt[] = {
	0,
	9,
	10,
	11,
	12,
	13,
	14,
	15,
	16,
	63,
	64,
	201,
	202,
	203,
	204,
	205,
	206,
	207,
	208,
	209,
	210,
	211,
	212,
	213,
	214,
	215,
	216,
	217,
	218,
	219,
	220,
	221,
	222,
	223,
	224,
	225,
	226,
	227,
	228,
	229,
	230,
	231,
	232,
	233,
	234,
	235,
	236,
	237,
	238,
	239,
	240,
	241,
	242,
	243,
	244,
	245,
	246,
	247,
	248,
	249,
	250,
	251,
	252,
	253,
	254,
	255,
	256,
	264,
	265,
	266,
	267,
	268,
	323,
	324,
	325,
	326,
	327,
	328,
	329,
	330,
	331,
	332,
	333,
	334,
	335,
	336,
	337,
	338,
	339,
	340,
	341,
	342,
	343,
	344,
	345,
	346,
	347,
	348,
	349,
	350,
	351,
	352,
	353,
	354,
	355,
	356,
	357,
	376,
	377,
	378,
	379,
	380,
	381,
	382,
	383,
	384,
	385,
	386,
	387,
	388,
	389,
	390,
	391,
	392,
	411,
	412,
	413,
	414,
	415,
	416,
	417,
	418,
	419,
	420,
	421,
	422,
	423,
	424,
	425,
	426,
	427,
	428,
	429,
	430,
	431,
	470,
	471,
	472,
	473,
	474,
	475,
	476,
	477,
	478,
	479,
	480,
	481,
	482,
	483,
	484,
	485,
	486,
	487,
	488,
	489,
	490,
	491,
	492,
	493,
	494,
	495,
	532,
	533,
	534,
	535,
	536,
	537,
	538,
	539,
	540,
	541,
	542,
	543,
	544,
	545,
	546,
	547,
	548,
	549,
	550,
	551,
	552,
	553,
	554,
	555,
};

static short _decode_reg[] = {
	0,
	1,
	2,
	3,
	4,
	5,
	6,
	7,
	8,
	17,
	18,
	19,
	20,
	21,
	22,
	23,
	24,
	25,
	26,
	27,
	28,
	29,
	65,
	272,
	273,
	274,
	275,
	276,
	277,
	278,
	360,
	361,
	362,
	363,
	458,
	459,
	460,
	461,
	496,
	497,
	498,
	499,
	500,
};

static short _decode_conBs[] = {
	0,
	48,
	49,
};

static short _decode_conB[] = {
	0,
	41,
	42,
	43,
	44,
	45,
	46,
};

static short _decode_con[] = {
	0,
	50,
	51,
	52,
	53,
	54,
	55,
};

static short _decode_con0[] = {
	0,
	30,
	31,
	32,
	33,
	34,
};

static short _decode_con1[] = {
	0,
	35,
	36,
	37,
	38,
};

static short _decode_con1n[] = {
	0,
	39,
	40,
};

static short _decode_zddr[] = {
	0,
	61,
	62,
};

static short _decode_conBn[] = {
	0,
	47,
};

static short _decode_addr[] = {
	0,
	58,
	59,
	60,
};

static short _decode_lddr[] = {
	0,
	56,
	57,
};

static short _decode_ac[] = {
	0,
	66,
	67,
	68,
	71,
	72,
	73,
	89,
	90,
	91,
	102,
	103,
	104,
	105,
	106,
	107,
	108,
	109,
	110,
	111,
	112,
	113,
	114,
	115,
	116,
	117,
	118,
	119,
	120,
	121,
	122,
	123,
	124,
	125,
	126,
	127,
	128,
	129,
	130,
	131,
	132,
	133,
	134,
	135,
	136,
	137,
	138,
	139,
	140,
	141,
	142,
	143,
	144,
	145,
	146,
	147,
	148,
	149,
	150,
	151,
	152,
	153,
	154,
	155,
	156,
	157,
	158,
	159,
	160,
	161,
	162,
	163,
	164,
	165,
	166,
	167,
	168,
	169,
	170,
	171,
	172,
	173,
	402,
	403,
	404,
	405,
	406,
	407,
	408,
	409,
	410,
	434,
	435,
	436,
	437,
	438,
	439,
	440,
	441,
	442,
	443,
	444,
	448,
	449,
	450,
	451,
	452,
	453,
	462,
	466,
	501,
	502,
	503,
	504,
	505,
	506,
	507,
	508,
	509,
	510,
	511,
	512,
	513,
	514,
	515,
	516,
	517,
	518,
	519,
	520,
	521,
	522,
	523,
	524,
	525,
	526,
	527,
	528,
	529,
};

static short _decode_ac0[] = {
	0,
	69,
	70,
	92,
	93,
	432,
	433,
};

static short _decode_eac[] = {
	0,
	74,
	75,
	77,
	78,
	79,
	80,
	81,
	84,
	85,
	86,
	174,
	175,
	176,
	177,
	178,
	179,
	180,
	181,
	182,
	183,
	184,
	185,
	186,
	187,
	188,
	189,
	190,
	191,
	192,
	193,
	194,
	195,
	196,
	197,
	198,
	199,
	200,
};

static short _decode_eac0[] = {
	0,
	76,
	82,
	83,
	87,
	88,
};

static short _decode_iarg[] = {
	0,
	94,
	95,
	96,
	97,
	99,
	100,
	101,
};

static short _decode_spill[] = {
	0,
	98,
};

static short _decode_vdst[] = {
	0,
	257,
	258,
	259,
};

static short _decode_asrc[] = {
	0,
	260,
	261,
	262,
};

static short _decode_lsrc[] = {
	0,
	263,
};

static short _decode_lac[] = {
	0,
	279,
	280,
	281,
	282,
	283,
	284,
	285,
	286,
	287,
	288,
	289,
	290,
	291,
	292,
	293,
	294,
	295,
	296,
	297,
	298,
	299,
	300,
	301,
	302,
	303,
	304,
	305,
	306,
	307,
	308,
	309,
	310,
	311,
	312,
	313,
	314,
	315,
	316,
	317,
	318,
	319,
	320,
	321,
	322,
	396,
	397,
	398,
	399,
	400,
	401,
	445,
	446,
	454,
	455,
	456,
	457,
	463,
	467,
};

static short _decode_larg[] = {
	0,
	269,
	270,
	271,
};

static short _decode_fac[] = {
	0,
	364,
	365,
	366,
	367,
	368,
	369,
	370,
	371,
	372,
	373,
	374,
	375,
	393,
	394,
	395,
	447,
	464,
	465,
	468,
	469,
};

static short _decode_farg[] = {
	0,
	358,
	359,
};

static short _decode_rmw[] = {
	0,
	530,
	531,
};

static int _rule(void *state, int goalnt) {
	if (goalnt < 1 || goalnt > 26)
		fatal("_rule", "Bad goal nonterminal %d\n", goalnt);
	if (!state)
		return 0;
	switch (goalnt) {
	case _stmt_NT:	return _decode_stmt[((struct _state *)state)->rule._stmt];
	case _reg_NT:	return _decode_reg[((struct _state *)state)->rule._reg];
	case _conBs_NT:	return _decode_conBs[((struct _state *)state)->rule._conBs];
	case _conB_NT:	return _decode_conB[((struct _state *)state)->rule._conB];
	case _con_NT:	return _decode_con[((struct _state *)state)->rule._con];
	case _con0_NT:	return _decode_con0[((struct _state *)state)->rule._con0];
	case _con1_NT:	return _decode_con1[((struct _state *)state)->rule._con1];
	case _con1n_NT:	return _decode_con1n[((struct _state *)state)->rule._con1n];
	case _zddr_NT:	return _decode_zddr[((struct _state *)state)->rule._zddr];
	case _conBn_NT:	return _decode_conBn[((struct _state *)state)->rule._conBn];
	case _addr_NT:	return _decode_addr[((struct _state *)state)->rule._addr];
	case _lddr_NT:	return _decode_lddr[((struct _state *)state)->rule._lddr];
	case _ac_NT:	return _decode_ac[((struct _state *)state)->rule._ac];
	case _ac0_NT:	return _decode_ac0[((struct _state *)state)->rule._ac0];
	case _eac_NT:	return _decode_eac[((struct _state *)state)->rule._eac];
	case _eac0_NT:	return _decode_eac0[((struct _state *)state)->rule._eac0];
	case _iarg_NT:	return _decode_iarg[((struct _state *)state)->rule._iarg];
	case _spill_NT:	return _decode_spill[((struct _state *)state)->rule._spill];
	case _vdst_NT:	return _decode_vdst[((struct _state *)state)->rule._vdst];
	case _asrc_NT:	return _decode_asrc[((struct _state *)state)->rule._asrc];
	case _lsrc_NT:	return _decode_lsrc[((struct _state *)state)->rule._lsrc];
	case _lac_NT:	return _decode_lac[((struct _state *)state)->rule._lac];
	case _larg_NT:	return _decode_larg[((struct _state *)state)->rule._larg];
	case _fac_NT:	return _decode_fac[((struct _state *)state)->rule._fac];
	case _farg_NT:	return _decode_farg[((struct _state *)state)->rule._farg];
	case _rmw_NT:	return _decode_rmw[((struct _state *)state)->rule._rmw];
	default:
		fatal("_rule", "Bad goal nonterminal %d\n", goalnt);
		return 0;
	}
}

static void _closure_reg(NODEPTR_TYPE, int);
static void _closure_conB(NODEPTR_TYPE, int);
static void _closure_con(NODEPTR_TYPE, int);
static void _closure_zddr(NODEPTR_TYPE, int);
static void _closure_addr(NODEPTR_TYPE, int);
static void _closure_lddr(NODEPTR_TYPE, int);
static void _closure_ac(NODEPTR_TYPE, int);
static void _closure_ac0(NODEPTR_TYPE, int);
static void _closure_eac(NODEPTR_TYPE, int);
static void _closure_eac0(NODEPTR_TYPE, int);
static void _closure_lac(NODEPTR_TYPE, int);
static void _closure_fac(NODEPTR_TYPE, int);

static void _closure_reg(NODEPTR_TYPE a, int c) {
	struct _state *p = STATE_LABEL(a);
	if (c + 150 < p->cost[_fac_NT]) {
		p->cost[_fac_NT] = c + 150;
		p->rule._fac = 1;
		_closure_fac(a, c + 150);
	}
	if (c + 21 < p->cost[_farg_NT]) {
		p->cost[_farg_NT] = c + 21;
		p->rule._farg = 1;
	}
	if (c + 120 < p->cost[_lac_NT]) {
		p->cost[_lac_NT] = c + 120;
		p->rule._lac = 1;
		_closure_lac(a, c + 120);
	}
	if (c + 21 < p->cost[_larg_NT]) {
		p->cost[_larg_NT] = c + 21;
		p->rule._larg = 1;
	}
	if (c + 0 < p->cost[_iarg_NT]) {
		p->cost[_iarg_NT] = c + 0;
		p->rule._iarg = 1;
	}
	if (c + 20 < p->cost[_eac_NT]) {
		p->cost[_eac_NT] = c + 20;
		p->rule._eac = 1;
		_closure_eac(a, c + 20);
	}
	if (c + 20 < p->cost[_ac_NT]) {
		p->cost[_ac_NT] = c + 20;
		p->rule._ac = 1;
		_closure_ac(a, c + 20);
	}
	if (c + 0 < p->cost[_stmt_NT]) {
		p->cost[_stmt_NT] = c + 0;
		p->rule._stmt = 9;
	}
}

static void _closure_conB(NODEPTR_TYPE a, int c) {
	struct _state *p = STATE_LABEL(a);
	if (c + 16 < p->cost[_ac0_NT]) {
		p->cost[_ac0_NT] = c + 16;
		p->rule._ac0 = 2;
		_closure_ac0(a, c + 16);
	}
	if (c + 0 < p->cost[_zddr_NT]) {
		p->cost[_zddr_NT] = c + 0;
		p->rule._zddr = 2;
		_closure_zddr(a, c + 0);
	}
}

static void _closure_con(NODEPTR_TYPE a, int c) {
	struct _state *p = STATE_LABEL(a);
	if (c + 21 < p->cost[_ac_NT]) {
		p->cost[_ac_NT] = c + 21;
		p->rule._ac = 4;
		_closure_ac(a, c + 21);
	}
	if (c + 0 < p->cost[_addr_NT]) {
		p->cost[_addr_NT] = c + 0;
		p->rule._addr = 2;
		_closure_addr(a, c + 0);
	}
}

static void _closure_zddr(NODEPTR_TYPE a, int c) {
	struct _state *p = STATE_LABEL(a);
	if (c + 0 < p->cost[_rmw_NT]) {
		p->cost[_rmw_NT] = c + 0;
		p->rule._rmw = 2;
	}
	if (c + 16 < p->cost[_eac0_NT]) {
		p->cost[_eac0_NT] = c + 16;
		p->rule._eac0 = 1;
		_closure_eac0(a, c + 16);
	}
	if (c + 16 < p->cost[_ac_NT]) {
		p->cost[_ac_NT] = c + 16;
		p->rule._ac = 5;
		_closure_ac(a, c + 16);
	}
	if (c + 0 < p->cost[_addr_NT]) {
		p->cost[_addr_NT] = c + 0;
		p->rule._addr = 3;
		_closure_addr(a, c + 0);
	}
	if (c + 0 < p->cost[_conB_NT]) {
		p->cost[_conB_NT] = c + 0;
		p->rule._conB = 6;
		_closure_conB(a, c + 0);
	}
}

static void _closure_addr(NODEPTR_TYPE a, int c) {
	struct _state *p = STATE_LABEL(a);
	if (c + 0 < p->cost[_lsrc_NT]) {
		p->cost[_lsrc_NT] = c + 0;
		p->rule._lsrc = 1;
	}
	if (c + 0 < p->cost[_asrc_NT]) {
		p->cost[_asrc_NT] = c + 0;
		p->rule._asrc = 1;
	}
	if (c + 0 < p->cost[_vdst_NT]) {
		p->cost[_vdst_NT] = c + 0;
		p->rule._vdst = 1;
	}
	if (c + 21 < p->cost[_eac_NT]) {
		p->cost[_eac_NT] = c + 21;
		p->rule._eac = 3;
		_closure_eac(a, c + 21);
	}
	if (c + 21 < p->cost[_ac_NT]) {
		p->cost[_ac_NT] = c + 21;
		p->rule._ac = 6;
		_closure_ac(a, c + 21);
	}
	if (c + 0 < p->cost[_con_NT]) {
		p->cost[_con_NT] = c + 0;
		p->rule._con = 6;
		_closure_con(a, c + 0);
	}
}

static void _closure_lddr(NODEPTR_TYPE a, int c) {
	struct _state *p = STATE_LABEL(a);
	if (c + 40 < p->cost[_asrc_NT]) {
		p->cost[_asrc_NT] = c + 40;
		p->rule._asrc = 2;
	}
	if (c + 60 < p->cost[_vdst_NT]) {
		p->cost[_vdst_NT] = c + 60;
		p->rule._vdst = 2;
	}
	if (c + 41 < p->cost[_eac_NT]) {
		p->cost[_eac_NT] = c + 41;
		p->rule._eac = 4;
		_closure_eac(a, c + 41);
	}
}

static void _closure_ac(NODEPTR_TYPE a, int c) {
	struct _state *p = STATE_LABEL(a);
	if (c + 20 < p->cost[_reg_NT]) {
		p->cost[_reg_NT] = c + 20;
		p->rule._reg = 22;
		_closure_reg(a, c + 20);
	}
	if (c + 0 < p->cost[_stmt_NT]) {
		p->cost[_stmt_NT] = c + 0;
		p->rule._stmt = 10;
	}
}

static void _closure_ac0(NODEPTR_TYPE a, int c) {
	struct _state *p = STATE_LABEL(a);
	if (c + 0 < p->cost[_ac_NT]) {
		p->cost[_ac_NT] = c + 0;
		p->rule._ac = 2;
		_closure_ac(a, c + 0);
	}
}

static void _closure_eac(NODEPTR_TYPE a, int c) {
	struct _state *p = STATE_LABEL(a);
	if (c + 0 < p->cost[_asrc_NT]) {
		p->cost[_asrc_NT] = c + 0;
		p->rule._asrc = 3;
	}
	if (c + 20 < p->cost[_vdst_NT]) {
		p->cost[_vdst_NT] = c + 20;
		p->rule._vdst = 3;
	}
	if (c + 0 < p->cost[_ac_NT]) {
		p->cost[_ac_NT] = c + 0;
		p->rule._ac = 3;
		_closure_ac(a, c + 0);
	}
}

static void _closure_eac0(NODEPTR_TYPE a, int c) {
	struct _state *p = STATE_LABEL(a);
	if (c + 0 < p->cost[_eac_NT]) {
		p->cost[_eac_NT] = c + 0;
		p->rule._eac = 2;
		_closure_eac(a, c + 0);
	}
	if (c + 0 < p->cost[_ac0_NT]) {
		p->cost[_ac0_NT] = c + 0;
		p->rule._ac0 = 1;
		_closure_ac0(a, c + 0);
	}
}

static void _closure_lac(NODEPTR_TYPE a, int c) {
	struct _state *p = STATE_LABEL(a);
	if (c + 120 < p->cost[_reg_NT]) {
		p->cost[_reg_NT] = c + 120;
		p->rule._reg = 23;
		_closure_reg(a, c + 120);
	}
	if (c + 0 < p->cost[_stmt_NT]) {
		p->cost[_stmt_NT] = c + 0;
		p->rule._stmt = 71;
	}
}

static void _closure_fac(NODEPTR_TYPE a, int c) {
	struct _state *p = STATE_LABEL(a);
	if (c + 180 < p->cost[_reg_NT]) {
		p->cost[_reg_NT] = c + 180;
		p->rule._reg = 30;
		_closure_reg(a, c + 180);
	}
	if (c + 0 < p->cost[_stmt_NT]) {
		p->cost[_stmt_NT] = c + 0;
		p->rule._stmt = 106;
	}
}

static void _label(NODEPTR_TYPE a) {
	int c;
	struct _state *p;

	if (!a)
		fatal("_label", "Null tree\n", 0);
	STATE_LABEL(a) = p = allocate(sizeof *p, FUNC);
	p->rule._stmt = 0;
	p->cost[1] =
	p->cost[2] =
	p->cost[3] =
	p->cost[4] =
	p->cost[5] =
	p->cost[6] =
	p->cost[7] =
	p->cost[8] =
	p->cost[9] =
	p->cost[10] =
	p->cost[11] =
	p->cost[12] =
	p->cost[13] =
	p->cost[14] =
	p->cost[15] =
	p->cost[16] =
	p->cost[17] =
	p->cost[18] =
	p->cost[19] =
	p->cost[20] =
	p->cost[21] =
	p->cost[22] =
	p->cost[23] =
	p->cost[24] =
	p->cost[25] =
	p->cost[26] =
		0x7fff;
	switch (OP_LABEL(a)) {
	case 41: /* ARGB */
		_label(LEFT_CHILD(a));
		if (	/* stmt: ARGB(INDIRB(asrc)) */
			LEFT_CHILD(a)->op == 73 /* INDIRB */
		) {
			c = ((struct _state *)(LEFT_CHILD(LEFT_CHILD(a))->x.state))->cost[_asrc_NT] + 200;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 67;
			}
		}
		break;
	case 57: /* ASGNB */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		if (	/* stmt: ASGNB(addr,INDIRB(asrc)) */
			RIGHT_CHILD(a)->op == 73 /* INDIRB */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_asrc_NT] + 200;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 68;
			}
		}
		if (	/* stmt: ASGNB(ac,INDIRB(asrc)) */
			RIGHT_CHILD(a)->op == 73 /* INDIRB */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_asrc_NT] + 200;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 69;
			}
		}
		if (	/* stmt: ASGNB(lddr,INDIRB(lsrc)) */
			RIGHT_CHILD(a)->op == 73 /* INDIRB */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lddr_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_lsrc_NT] + 200;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 70;
			}
		}
		break;
	case 73: /* INDIRB */
		_label(LEFT_CHILD(a));
		break;
	case 216: /* CALLV */
		_label(LEFT_CHILD(a));
		/* stmt: CALLV(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + (mincpu5(28));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 124;
		}
		/* stmt: CALLV(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 26;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 125;
		}
		/* stmt: CALLV(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 26;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 126;
		}
		break;
	case 217: /* CALLB */
		break;
	case 233: /* LOADB */
		break;
	case 248: /* RETV */
		break;
	case 584: /* JUMPV */
		_label(LEFT_CHILD(a));
		/* stmt: JUMPV(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + 14;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 146;
		}
		/* stmt: JUMPV(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 14;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 147;
		}
		/* stmt: JUMPV(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 14;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 148;
		}
		break;
	case 600: /* LABELV */
		/* stmt: LABELV */
		if (0 + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = 0 + 0;
			p->rule._stmt = 145;
		}
		break;
	case 711: /* VREGP */
		/* rmw: VREGP */
		if (0 + 0 < p->cost[_rmw_NT]) {
			p->cost[_rmw_NT] = 0 + 0;
			p->rule._rmw = 1;
		}
		break;
	case 1045: /* CNSTI1 */
		/* con0: CNSTI1 */
		c = (range(a,0,0));
		if (c + 0 < p->cost[_con0_NT]) {
			p->cost[_con0_NT] = c + 0;
			p->rule._con0 = 1;
		}
		/* con1: CNSTI1 */
		c = (range(a,1,1));
		if (c + 0 < p->cost[_con1_NT]) {
			p->cost[_con1_NT] = c + 0;
			p->rule._con1 = 1;
		}
		/* con1n: CNSTI1 */
		c = (range(a,-1,-1));
		if (c + 0 < p->cost[_con1n_NT]) {
			p->cost[_con1n_NT] = c + 0;
			p->rule._con1n = 1;
		}
		/* conB: CNSTI1 */
		if (0 + 0 < p->cost[_conB_NT]) {
			p->cost[_conB_NT] = 0 + 0;
			p->rule._conB = 4;
			_closure_conB(a, 0 + 0);
		}
		/* conBs: CNSTI1 */
		if (0 + 0 < p->cost[_conBs_NT]) {
			p->cost[_conBs_NT] = 0 + 0;
			p->rule._conBs = 2;
		}
		/* con: CNSTI1 */
		if (0 + 0 < p->cost[_con_NT]) {
			p->cost[_con_NT] = 0 + 0;
			p->rule._con = 1;
			_closure_con(a, 0 + 0);
		}
		break;
	case 1046: /* CNSTU1 */
		/* con0: CNSTU1 */
		c = (range(a,0,0));
		if (c + 0 < p->cost[_con0_NT]) {
			p->cost[_con0_NT] = c + 0;
			p->rule._con0 = 2;
		}
		/* con1: CNSTU1 */
		c = (range(a,1,1));
		if (c + 0 < p->cost[_con1_NT]) {
			p->cost[_con1_NT] = c + 0;
			p->rule._con1 = 2;
		}
		/* conB: CNSTU1 */
		if (0 + 0 < p->cost[_conB_NT]) {
			p->cost[_conB_NT] = 0 + 0;
			p->rule._conB = 5;
			_closure_conB(a, 0 + 0);
		}
		/* con: CNSTU1 */
		if (0 + 0 < p->cost[_con_NT]) {
			p->cost[_con_NT] = 0 + 0;
			p->rule._con = 2;
			_closure_con(a, 0 + 0);
		}
		break;
	case 1077: /* ASGNI1 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		if (	/* stmt: ASGNI1(VREGP,reg) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			c = ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 1;
			}
		}
		/* stmt: ASGNI1(zddr,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 20;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 17;
		}
		/* stmt: ASGNI1(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 26;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 18;
		}
		/* stmt: ASGNI1(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + (mincpu6(28));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 158;
		}
		/* stmt: ASGNI1(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(27));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 163;
		}
		/* stmt: ASGNI1(ac,conBs) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBs_NT] + (mincpu6(27));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 164;
		}
		/* stmt: ASGNI1(addr,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + (mincpu6(26+26));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 169;
		}
		if (	/* stmt: ASGNI1(rmw,LOADI1(ADDI2(CVII2(INDIRI1(rmw)),con1))) */
			RIGHT_CHILD(a)->op == 1253 && /* LOADI1 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2357 && /* ADDI2 */
			LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->op == 2181 && /* CVII2 */
			LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a))))->op == 1093 /* INDIRI1 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_con1_NT] + (if_rmw(a,16));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 172;
			}
		}
		if (	/* stmt: ASGNI1(rmw,LOADI1(SUBI2(CVII2(INDIRI1(rmw)),con1))) */
			RIGHT_CHILD(a)->op == 1253 && /* LOADI1 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2373 && /* SUBI2 */
			LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->op == 2181 && /* CVII2 */
			LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a))))->op == 1093 /* INDIRI1 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_con1_NT] + (mincpu6(if_rmw(a,16)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 174;
			}
		}
		/* stmt: ASGNI1(rmw,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(if_not_asgn_tmp(a,27)));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 193;
		}
		break;
	case 1078: /* ASGNU1 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		if (	/* stmt: ASGNU1(VREGP,reg) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			c = ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 2;
			}
		}
		/* stmt: ASGNU1(zddr,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 20;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 19;
		}
		/* stmt: ASGNU1(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 26;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 20;
		}
		/* stmt: ASGNU1(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + (mincpu6(28));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 159;
		}
		/* stmt: ASGNU1(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(28));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 165;
		}
		/* stmt: ASGNU1(addr,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + (mincpu6(26+26));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 170;
		}
		if (	/* stmt: ASGNU1(rmw,LOADU1(ADDI2(CVUI2(INDIRU1(rmw)),con1))) */
			RIGHT_CHILD(a)->op == 1254 && /* LOADU1 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2357 && /* ADDI2 */
			LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->op == 2229 && /* CVUI2 */
			LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a))))->op == 1094 /* INDIRU1 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_con1_NT] + (if_rmw(a,16));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 171;
			}
		}
		if (	/* stmt: ASGNU1(rmw,LOADU1(SUBI2(CVUI2(INDIRU1(rmw)),con1))) */
			RIGHT_CHILD(a)->op == 1254 && /* LOADU1 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2373 && /* SUBI2 */
			LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->op == 2229 && /* CVUI2 */
			LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a))))->op == 1094 /* INDIRU1 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_con1_NT] + (mincpu6(if_rmw(a,16)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 173;
			}
		}
		/* stmt: ASGNU1(rmw,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(if_not_asgn_tmp(a,27)));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 194;
		}
		break;
	case 1093: /* INDIRI1 */
		_label(LEFT_CHILD(a));
		if (	/* reg: INDIRI1(VREGP) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			if (mayrecalc(a)) {
				struct _state *q = a->syms[RX]->u.t.cse->x.state;
				*p = *q;
			}
			c = 0;
			if (c + 0 < p->cost[_reg_NT]) {
				p->cost[_reg_NT] = c + 0;
				p->rule._reg = 1;
				_closure_reg(a, c + 0);
			}
		}
		/* eac0: INDIRI1(eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + 17;
		if (c + 0 < p->cost[_eac0_NT]) {
			p->cost[_eac0_NT] = c + 0;
			p->rule._eac0 = 2;
			_closure_eac0(a, c + 0);
		}
		/* eac0: INDIRI1(zddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + 18;
		if (c + 0 < p->cost[_eac0_NT]) {
			p->cost[_eac0_NT] = c + 0;
			p->rule._eac0 = 4;
			_closure_eac0(a, c + 0);
		}
		/* ac0: INDIRI1(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 17;
		if (c + 0 < p->cost[_ac0_NT]) {
			p->cost[_ac0_NT] = c + 0;
			p->rule._ac0 = 3;
			_closure_ac0(a, c + 0);
		}
		/* reg: INDIRI1(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + (mincpu6(28));
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 41;
			_closure_reg(a, c + 0);
		}
		/* ac: INDIRI1(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (mincpu6(30));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 113;
			_closure_ac(a, c + 0);
		}
		break;
	case 1094: /* INDIRU1 */
		_label(LEFT_CHILD(a));
		if (	/* reg: INDIRU1(VREGP) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			if (mayrecalc(a)) {
				struct _state *q = a->syms[RX]->u.t.cse->x.state;
				*p = *q;
			}
			c = 0;
			if (c + 0 < p->cost[_reg_NT]) {
				p->cost[_reg_NT] = c + 0;
				p->rule._reg = 2;
				_closure_reg(a, c + 0);
			}
		}
		/* eac0: INDIRU1(eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + 17;
		if (c + 0 < p->cost[_eac0_NT]) {
			p->cost[_eac0_NT] = c + 0;
			p->rule._eac0 = 3;
			_closure_eac0(a, c + 0);
		}
		/* eac0: INDIRU1(zddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + 18;
		if (c + 0 < p->cost[_eac0_NT]) {
			p->cost[_eac0_NT] = c + 0;
			p->rule._eac0 = 5;
			_closure_eac0(a, c + 0);
		}
		/* ac0: INDIRU1(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 17;
		if (c + 0 < p->cost[_ac0_NT]) {
			p->cost[_ac0_NT] = c + 0;
			p->rule._ac0 = 4;
			_closure_ac0(a, c + 0);
		}
		/* reg: INDIRU1(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + (mincpu6(28));
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 42;
			_closure_reg(a, c + 0);
		}
		/* ac: INDIRU1(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (mincpu6(30));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 114;
			_closure_ac(a, c + 0);
		}
		break;
	case 1157: /* CVII1 */
		break;
	case 1158: /* CVIU1 */
		break;
	case 1205: /* CVUI1 */
		break;
	case 1206: /* CVUU1 */
		break;
	case 1253: /* LOADI1 */
		_label(LEFT_CHILD(a));
		/* reg: LOADI1(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 34;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 9;
			_closure_reg(a, c + 0);
		}
		/* reg: LOADI1(conBs) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_conBs_NT] + 36;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 17;
			_closure_reg(a, c + 0);
		}
		/* ac0: LOADI1(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 18;
		if (c + 0 < p->cost[_ac0_NT]) {
			p->cost[_ac0_NT] = c + 0;
			p->rule._ac0 = 5;
			_closure_ac0(a, c + 0);
		}
		/* ac: LOADI1(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 0;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 91;
			_closure_ac(a, c + 0);
		}
		break;
	case 1254: /* LOADU1 */
		_label(LEFT_CHILD(a));
		/* reg: LOADU1(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 34;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 10;
			_closure_reg(a, c + 0);
		}
		/* reg: LOADU1(conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_conB_NT] + 36;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 18;
			_closure_reg(a, c + 0);
		}
		/* ac0: LOADU1(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 18;
		if (c + 0 < p->cost[_ac0_NT]) {
			p->cost[_ac0_NT] = c + 0;
			p->rule._ac0 = 6;
			_closure_ac0(a, c + 0);
		}
		/* ac: LOADU1(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 0;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 92;
			_closure_ac(a, c + 0);
		}
		break;
	case 2069: /* CNSTI2 */
		/* con0: CNSTI2 */
		c = (range(a,0,0));
		if (c + 0 < p->cost[_con0_NT]) {
			p->cost[_con0_NT] = c + 0;
			p->rule._con0 = 3;
		}
		/* con1: CNSTI2 */
		c = (range(a,1,1));
		if (c + 0 < p->cost[_con1_NT]) {
			p->cost[_con1_NT] = c + 0;
			p->rule._con1 = 3;
		}
		/* con1n: CNSTI2 */
		c = (range(a,-1,-1));
		if (c + 0 < p->cost[_con1n_NT]) {
			p->cost[_con1n_NT] = c + 0;
			p->rule._con1n = 2;
		}
		/* conB: CNSTI2 */
		c = (range(a,0,255));
		if (c + 0 < p->cost[_conB_NT]) {
			p->cost[_conB_NT] = c + 0;
			p->rule._conB = 1;
			_closure_conB(a, c + 0);
		}
		/* conBn: CNSTI2 */
		c = (range(a,-255,-1));
		if (c + 0 < p->cost[_conBn_NT]) {
			p->cost[_conBn_NT] = c + 0;
			p->rule._conBn = 1;
		}
		/* conBs: CNSTI2 */
		c = (range(a,-128,127));
		if (c + 0 < p->cost[_conBs_NT]) {
			p->cost[_conBs_NT] = c + 0;
			p->rule._conBs = 1;
		}
		/* con: CNSTI2 */
		if (0 + 0 < p->cost[_con_NT]) {
			p->cost[_con_NT] = 0 + 0;
			p->rule._con = 3;
			_closure_con(a, 0 + 0);
		}
		break;
	case 2070: /* CNSTU2 */
		/* con0: CNSTU2 */
		c = (range(a,0,0));
		if (c + 0 < p->cost[_con0_NT]) {
			p->cost[_con0_NT] = c + 0;
			p->rule._con0 = 4;
		}
		/* con1: CNSTU2 */
		c = (range(a,1,1));
		if (c + 0 < p->cost[_con1_NT]) {
			p->cost[_con1_NT] = c + 0;
			p->rule._con1 = 4;
		}
		/* conB: CNSTU2 */
		c = (range(a,0,255));
		if (c + 0 < p->cost[_conB_NT]) {
			p->cost[_conB_NT] = c + 0;
			p->rule._conB = 2;
			_closure_conB(a, c + 0);
		}
		/* con: CNSTU2 */
		if (0 + 0 < p->cost[_con_NT]) {
			p->cost[_con_NT] = 0 + 0;
			p->rule._con = 4;
			_closure_con(a, 0 + 0);
		}
		break;
	case 2071: /* CNSTP2 */
		/* con0: CNSTP2 */
		c = (range(a,0,0));
		if (c + 0 < p->cost[_con0_NT]) {
			p->cost[_con0_NT] = c + 0;
			p->rule._con0 = 5;
		}
		/* conB: CNSTP2 */
		c = (if_zpconst(a));
		if (c + 0 < p->cost[_conB_NT]) {
			p->cost[_conB_NT] = c + 0;
			p->rule._conB = 3;
			_closure_conB(a, c + 0);
		}
		/* con: CNSTP2 */
		if (0 + 0 < p->cost[_con_NT]) {
			p->cost[_con_NT] = 0 + 0;
			p->rule._con = 5;
			_closure_con(a, 0 + 0);
		}
		break;
	case 2085: /* ARGI2 */
		_label(LEFT_CHILD(a));
		/* stmt: ARGI2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_arg_stk(a));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 130;
		}
		/* stmt: ARGI2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_arg_reg_only(a));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 136;
		}
		break;
	case 2086: /* ARGU2 */
		_label(LEFT_CHILD(a));
		/* stmt: ARGU2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_arg_stk(a));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 131;
		}
		/* stmt: ARGU2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_arg_reg_only(a));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 137;
		}
		break;
	case 2087: /* ARGP2 */
		_label(LEFT_CHILD(a));
		/* stmt: ARGP2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_arg_stk(a));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 132;
		}
		/* stmt: ARGP2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_arg_reg_only(a));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 138;
		}
		break;
	case 2101: /* ASGNI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		if (	/* stmt: ASGNI2(VREGP,reg) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			c = ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 3;
			}
		}
		/* stmt: ASGNI2(zddr,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 20;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 13;
		}
		/* stmt: ASGNI2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 14;
		}
		/* stmt: ASGNI2(spill,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_spill_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 149;
		}
		/* stmt: ASGNI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + (mincpu6(30));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 156;
		}
		/* stmt: ASGNI2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(29));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 161;
		}
		/* stmt: ASGNI2(addr,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + (mincpu6(26+28));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 167;
		}
		if (	/* stmt: ASGNI2(rmw,ADDI2(INDIRI2(rmw),con1)) */
			RIGHT_CHILD(a)->op == 2357 && /* ADDI2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2117 /* INDIRI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_con1_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 178;
			}
		}
		if (	/* stmt: ASGNI2(rmw,SUBI2(INDIRI2(rmw),con1)) */
			RIGHT_CHILD(a)->op == 2373 && /* SUBI2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2117 /* INDIRI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_con1_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 181;
			}
		}
		if (	/* stmt: ASGNI2(rmw,ADDI2(INDIRI2(rmw),con1n)) */
			RIGHT_CHILD(a)->op == 2357 && /* ADDI2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2117 /* INDIRI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_con1n_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 184;
			}
		}
		if (	/* stmt: ASGNI2(rmw,NEGI2(INDIRI2(rmw))) */
			RIGHT_CHILD(a)->op == 2245 && /* NEGI2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2117 /* INDIRI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 185;
			}
		}
		if (	/* stmt: ASGNI2(rmw,BCOMI2(INDIRI2(rmw))) */
			RIGHT_CHILD(a)->op == 2453 && /* BCOMI2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2117 /* INDIRI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 186;
			}
		}
		if (	/* stmt: ASGNI2(rmw,LSHI2(INDIRI2(rmw),con1)) */
			RIGHT_CHILD(a)->op == 2389 && /* LSHI2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2117 /* INDIRI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_con1_NT] + (mincpu6(if_rmw(a, 28)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 188;
			}
		}
		/* stmt: ASGNI2(rmw,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(if_not_asgn_tmp(a,29)));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 190;
		}
		break;
	case 2102: /* ASGNU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		if (	/* stmt: ASGNU2(VREGP,reg) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			c = ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 4;
			}
		}
		/* stmt: ASGNU2(zddr,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 20;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 15;
		}
		/* stmt: ASGNU2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 16;
		}
		/* stmt: ASGNU2(spill,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_spill_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 150;
		}
		/* stmt: ASGNU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + (mincpu6(30));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 157;
		}
		/* stmt: ASGNU2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(29));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 162;
		}
		/* stmt: ASGNU2(addr,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + (mincpu6(26+28));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 168;
		}
		if (	/* stmt: ASGNU2(rmw,ADDU2(INDIRU2(rmw),con1)) */
			RIGHT_CHILD(a)->op == 2358 && /* ADDU2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2118 /* INDIRU2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_con1_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 177;
			}
		}
		if (	/* stmt: ASGNU2(rmw,SUBU2(INDIRU2(rmw),con1)) */
			RIGHT_CHILD(a)->op == 2374 && /* SUBU2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2118 /* INDIRU2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_con1_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 180;
			}
		}
		if (	/* stmt: ASGNU2(rmw,ADDU2(INDIRU2(rmw),con1n)) */
			RIGHT_CHILD(a)->op == 2358 && /* ADDU2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2118 /* INDIRU2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_con1n_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 183;
			}
		}
		if (	/* stmt: ASGNU2(rmw,BCOMU2(INDIRU2(rmw))) */
			RIGHT_CHILD(a)->op == 2454 && /* BCOMU2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2118 /* INDIRU2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 187;
			}
		}
		if (	/* stmt: ASGNU2(rmw,LSHU2(INDIRU2(rmw),con1)) */
			RIGHT_CHILD(a)->op == 2390 && /* LSHU2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2118 /* INDIRU2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_con1_NT] + (mincpu6(if_rmw(a, 28)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 189;
			}
		}
		/* stmt: ASGNU2(rmw,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(if_not_asgn_tmp(a,29)));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 191;
		}
		break;
	case 2103: /* ASGNP2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		if (	/* stmt: ASGNP2(VREGP,reg) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			c = ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 5;
			}
		}
		/* stmt: ASGNP2(zddr,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 20;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 11;
		}
		/* stmt: ASGNP2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 12;
		}
		/* stmt: ASGNP2(spill,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_spill_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 151;
		}
		/* stmt: ASGNP2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + (mincpu6(30));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 155;
		}
		/* stmt: ASGNP2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(29));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 160;
		}
		/* stmt: ASGNP2(addr,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + (mincpu6(26+28));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 166;
		}
		if (	/* stmt: ASGNP2(rmw,ADDP2(INDIRP2(rmw),con1)) */
			RIGHT_CHILD(a)->op == 2359 && /* ADDP2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2119 /* INDIRP2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_con1_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 175;
			}
		}
		if (	/* stmt: ASGNP2(rmw,ADDP2(INDIRP2(rmw),con1)) */
			RIGHT_CHILD(a)->op == 2359 && /* ADDP2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2119 /* INDIRP2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_con1_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 176;
			}
		}
		if (	/* stmt: ASGNP2(rmw,SUBP2(INDIRP2(rmw),con1)) */
			RIGHT_CHILD(a)->op == 2375 && /* SUBP2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2119 /* INDIRP2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_con1_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 179;
			}
		}
		if (	/* stmt: ASGNP2(rmw,ADDP2(INDIRP2(rmw),con1n)) */
			RIGHT_CHILD(a)->op == 2359 && /* ADDP2 */
			LEFT_CHILD(RIGHT_CHILD(a))->op == 2119 /* INDIRP2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(a)))->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_con1n_NT] + (mincpu6(if_rmw(a, 26)));
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 182;
			}
		}
		/* stmt: ASGNP2(rmw,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_rmw_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(if_not_asgn_tmp(a,29)));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 192;
		}
		break;
	case 2117: /* INDIRI2 */
		_label(LEFT_CHILD(a));
		if (	/* reg: INDIRI2(VREGP) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			if (mayrecalc(a)) {
				struct _state *q = a->syms[RX]->u.t.cse->x.state;
				*p = *q;
			}
			c = 0;
			if (c + 0 < p->cost[_reg_NT]) {
				p->cost[_reg_NT] = c + 0;
				p->rule._reg = 3;
				_closure_reg(a, c + 0);
			}
		}
		/* eac: INDIRI2(eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + 21;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 5;
			_closure_eac(a, c + 0);
		}
		/* eac: INDIRI2(zddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + 20;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 8;
			_closure_eac(a, c + 0);
		}
		/* ac: INDIRI2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 21;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 7;
			_closure_ac(a, c + 0);
		}
		/* iarg: INDIRI2(zddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + 0;
		if (c + 0 < p->cost[_iarg_NT]) {
			p->cost[_iarg_NT] = c + 0;
			p->rule._iarg = 2;
		}
		/* iarg: INDIRI2(spill) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_spill_NT] + 21;
		if (c + 0 < p->cost[_iarg_NT]) {
			p->cost[_iarg_NT] = c + 0;
			p->rule._iarg = 6;
		}
		/* reg: INDIRI2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + (mincpu6(30));
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 38;
			_closure_reg(a, c + 0);
		}
		/* ac: INDIRI2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (mincpu6(30));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 110;
			_closure_ac(a, c + 0);
		}
		break;
	case 2118: /* INDIRU2 */
		_label(LEFT_CHILD(a));
		if (	/* reg: INDIRU2(VREGP) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			if (mayrecalc(a)) {
				struct _state *q = a->syms[RX]->u.t.cse->x.state;
				*p = *q;
			}
			c = 0;
			if (c + 0 < p->cost[_reg_NT]) {
				p->cost[_reg_NT] = c + 0;
				p->rule._reg = 4;
				_closure_reg(a, c + 0);
			}
		}
		/* eac: INDIRU2(eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + 21;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 6;
			_closure_eac(a, c + 0);
		}
		/* eac: INDIRU2(zddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + 20;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 9;
			_closure_eac(a, c + 0);
		}
		/* ac: INDIRU2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 21;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 8;
			_closure_ac(a, c + 0);
		}
		/* iarg: INDIRU2(zddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + 0;
		if (c + 0 < p->cost[_iarg_NT]) {
			p->cost[_iarg_NT] = c + 0;
			p->rule._iarg = 3;
		}
		/* iarg: INDIRU2(spill) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_spill_NT] + 21;
		if (c + 0 < p->cost[_iarg_NT]) {
			p->cost[_iarg_NT] = c + 0;
			p->rule._iarg = 5;
		}
		/* reg: INDIRU2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + (mincpu6(30));
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 39;
			_closure_reg(a, c + 0);
		}
		/* ac: INDIRU2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (mincpu6(30));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 111;
			_closure_ac(a, c + 0);
		}
		break;
	case 2119: /* INDIRP2 */
		_label(LEFT_CHILD(a));
		if (	/* reg: INDIRP2(VREGP) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			if (mayrecalc(a)) {
				struct _state *q = a->syms[RX]->u.t.cse->x.state;
				*p = *q;
			}
			c = 0;
			if (c + 0 < p->cost[_reg_NT]) {
				p->cost[_reg_NT] = c + 0;
				p->rule._reg = 5;
				_closure_reg(a, c + 0);
			}
		}
		/* eac: INDIRP2(eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + 21;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 7;
			_closure_eac(a, c + 0);
		}
		/* eac: INDIRP2(zddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + 20;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 10;
			_closure_eac(a, c + 0);
		}
		/* ac: INDIRP2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 21;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 9;
			_closure_ac(a, c + 0);
		}
		/* iarg: INDIRP2(zddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_zddr_NT] + 0;
		if (c + 0 < p->cost[_iarg_NT]) {
			p->cost[_iarg_NT] = c + 0;
			p->rule._iarg = 4;
		}
		/* iarg: INDIRP2(spill) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_spill_NT] + 21;
		if (c + 0 < p->cost[_iarg_NT]) {
			p->cost[_iarg_NT] = c + 0;
			p->rule._iarg = 7;
		}
		/* reg: INDIRP2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + (mincpu6(30));
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 40;
			_closure_reg(a, c + 0);
		}
		/* ac: INDIRP2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (mincpu6(30));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 112;
			_closure_ac(a, c + 0);
		}
		break;
	case 2165: /* CVFI2 */
		_label(LEFT_CHILD(a));
		/* ac: CVFI2(fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 109;
			_closure_ac(a, c + 0);
		}
		break;
	case 2166: /* CVFU2 */
		_label(LEFT_CHILD(a));
		/* ac: CVFU2(fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 108;
			_closure_ac(a, c + 0);
		}
		break;
	case 2181: /* CVII2 */
		_label(LEFT_CHILD(a));
		/* ac: CVII2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_cv_from(a,1,66));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 102;
			_closure_ac(a, c + 0);
		}
		/* ac: CVII2(ac0) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac0_NT] + (if_cv_from(a,1,48));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 104;
			_closure_ac(a, c + 0);
		}
		/* ac: CVII2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + (if_cv_from(a,1,66));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 106;
			_closure_ac(a, c + 0);
		}
		break;
	case 2182: /* CVIU2 */
		break;
	case 2198: /* CVPU2 */
		break;
	case 2229: /* CVUI2 */
		_label(LEFT_CHILD(a));
		/* ac: CVUI2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_cv_from(a,1,18));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 103;
			_closure_ac(a, c + 0);
		}
		/* ac: CVUI2(ac0) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac0_NT] + (if_cv_from(a,1,0));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 105;
			_closure_ac(a, c + 0);
		}
		/* ac: CVUI2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + (if_cv_from(a,1,18));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 107;
			_closure_ac(a, c + 0);
		}
		break;
	case 2230: /* CVUU2 */
		break;
	case 2231: /* CVUP2 */
		break;
	case 2245: /* NEGI2 */
		_label(LEFT_CHILD(a));
		/* ac: NEGI2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 68;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 31;
			_closure_ac(a, c + 0);
		}
		/* ac: NEGI2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 48;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 32;
			_closure_ac(a, c + 0);
		}
		/* ac: NEGI2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + (mincpu6(26));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 133;
			_closure_ac(a, c + 0);
		}
		/* ac: NEGI2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (mincpu6(46));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 134;
			_closure_ac(a, c + 0);
		}
		break;
	case 2261: /* CALLI2 */
		_label(LEFT_CHILD(a));
		/* ac: CALLI2(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + (mincpu5(28));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 82;
			_closure_ac(a, c + 0);
		}
		/* ac: CALLI2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 26;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 83;
			_closure_ac(a, c + 0);
		}
		/* ac: CALLI2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 26;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 84;
			_closure_ac(a, c + 0);
		}
		break;
	case 2262: /* CALLU2 */
		_label(LEFT_CHILD(a));
		/* ac: CALLU2(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + (mincpu5(28));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 85;
			_closure_ac(a, c + 0);
		}
		/* ac: CALLU2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 26;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 86;
			_closure_ac(a, c + 0);
		}
		/* ac: CALLU2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 26;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 87;
			_closure_ac(a, c + 0);
		}
		break;
	case 2263: /* CALLP2 */
		_label(LEFT_CHILD(a));
		/* ac: CALLP2(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + (mincpu5(28));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 88;
			_closure_ac(a, c + 0);
		}
		/* ac: CALLP2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 26;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 89;
			_closure_ac(a, c + 0);
		}
		/* ac: CALLP2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 26;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 90;
			_closure_ac(a, c + 0);
		}
		break;
	case 2277: /* LOADI2 */
		_label(LEFT_CHILD(a));
		/* reg: LOADI2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 40;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 11;
			_closure_reg(a, c + 0);
		}
		/* reg: LOADI2(con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_con_NT] + 41;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 19;
			_closure_reg(a, c + 0);
		}
		/* ac: LOADI2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 0;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 93;
			_closure_ac(a, c + 0);
		}
		/* ac: LOADI2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 20;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 96;
			_closure_ac(a, c + 0);
		}
		/* ac: LOADI2(lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + 20;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 99;
			_closure_ac(a, c + 0);
		}
		break;
	case 2278: /* LOADU2 */
		_label(LEFT_CHILD(a));
		/* reg: LOADU2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 40;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 12;
			_closure_reg(a, c + 0);
		}
		/* reg: LOADU2(con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_con_NT] + 41;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 20;
			_closure_reg(a, c + 0);
		}
		/* ac: LOADU2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 0;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 94;
			_closure_ac(a, c + 0);
		}
		/* ac: LOADU2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 20;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 97;
			_closure_ac(a, c + 0);
		}
		/* ac: LOADU2(lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + 20;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 100;
			_closure_ac(a, c + 0);
		}
		break;
	case 2279: /* LOADP2 */
		_label(LEFT_CHILD(a));
		/* reg: LOADP2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 40;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 13;
			_closure_reg(a, c + 0);
		}
		/* reg: LOADP2(con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_con_NT] + 41;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 21;
			_closure_reg(a, c + 0);
		}
		/* ac: LOADP2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 0;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 95;
			_closure_ac(a, c + 0);
		}
		/* ac: LOADP2(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 20;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 98;
			_closure_ac(a, c + 0);
		}
		/* ac: LOADP2(lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + 20;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 101;
			_closure_ac(a, c + 0);
		}
		break;
	case 2293: /* RETI2 */
		_label(LEFT_CHILD(a));
		/* stmt: RETI2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 1;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 142;
		}
		break;
	case 2294: /* RETU2 */
		_label(LEFT_CHILD(a));
		/* stmt: RETU2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 1;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 143;
		}
		break;
	case 2295: /* RETP2 */
		_label(LEFT_CHILD(a));
		/* stmt: RETP2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 1;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 144;
		}
		break;
	case 2311: /* ADDRGP2 */
		/* addr: ADDRGP2 */
		if (0 + 0 < p->cost[_addr_NT]) {
			p->cost[_addr_NT] = 0 + 0;
			p->rule._addr = 1;
			_closure_addr(a, 0 + 0);
		}
		/* zddr: ADDRGP2 */
		c = (if_zpglobal(a));
		if (c + 0 < p->cost[_zddr_NT]) {
			p->cost[_zddr_NT] = c + 0;
			p->rule._zddr = 1;
			_closure_zddr(a, c + 0);
		}
		break;
	case 2327: /* ADDRFP2 */
		/* lddr: ADDRFP2 */
		if (0 + 0 < p->cost[_lddr_NT]) {
			p->cost[_lddr_NT] = 0 + 0;
			p->rule._lddr = 2;
			_closure_lddr(a, 0 + 0);
		}
		break;
	case 2343: /* ADDRLP2 */
		/* lddr: ADDRLP2 */
		if (0 + 0 < p->cost[_lddr_NT]) {
			p->cost[_lddr_NT] = 0 + 0;
			p->rule._lddr = 1;
			_closure_lddr(a, 0 + 0);
		}
		/* spill: ADDRLP2 */
		c = (if_spill(50));
		if (c + 0 < p->cost[_spill_NT]) {
			p->cost[_spill_NT] = c + 0;
			p->rule._spill = 1;
		}
		break;
	case 2357: /* ADDI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: ADDI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 10;
			_closure_ac(a, c + 0);
		}
		/* ac: ADDI2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 13;
			_closure_ac(a, c + 0);
		}
		/* ac: ADDI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 27;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 16;
			_closure_ac(a, c + 0);
		}
		/* ac: ADDI2(ac,conBn) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBn_NT] + 27;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 19;
			_closure_ac(a, c + 0);
		}
		/* eac: ADDI2(eac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 11;
			_closure_eac(a, c + 0);
		}
		/* eac: ADDI2(eac,conBn) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBn_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 14;
			_closure_eac(a, c + 0);
		}
		/* eac: ADDI2(eac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 29;
			_closure_eac(a, c + 0);
		}
		/* eac: ADDI2(iarg,eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_eac_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 32;
			_closure_eac(a, c + 0);
		}
		/* ac: ADDI2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(26+27));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 115;
			_closure_ac(a, c + 0);
		}
		if (	/* ac: ADDI2(ac,CVUI2(iarg)) */
			RIGHT_CHILD(a)->op == 2229 /* CVUI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_iarg_NT] + (mincpu6(28));
			if (c + 0 < p->cost[_ac_NT]) {
				p->cost[_ac_NT] = c + 0;
				p->rule._ac = 135;
				_closure_ac(a, c + 0);
			}
		}
		break;
	case 2358: /* ADDU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: ADDU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 11;
			_closure_ac(a, c + 0);
		}
		/* ac: ADDU2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 14;
			_closure_ac(a, c + 0);
		}
		/* ac: ADDU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 27;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 17;
			_closure_ac(a, c + 0);
		}
		/* ac: ADDU2(ac,conBn) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBn_NT] + 27;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 20;
			_closure_ac(a, c + 0);
		}
		/* eac: ADDU2(eac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 12;
			_closure_eac(a, c + 0);
		}
		/* eac: ADDU2(eac,conBn) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBn_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 15;
			_closure_eac(a, c + 0);
		}
		/* eac: ADDU2(eac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 30;
			_closure_eac(a, c + 0);
		}
		/* eac: ADDU2(iarg,eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_eac_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 33;
			_closure_eac(a, c + 0);
		}
		/* ac: ADDU2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(26+27));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 116;
			_closure_ac(a, c + 0);
		}
		if (	/* ac: ADDU2(ac,CVUI2(iarg)) */
			RIGHT_CHILD(a)->op == 2229 /* CVUI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_iarg_NT] + (mincpu6(28));
			if (c + 0 < p->cost[_ac_NT]) {
				p->cost[_ac_NT] = c + 0;
				p->rule._ac = 136;
				_closure_ac(a, c + 0);
			}
		}
		break;
	case 2359: /* ADDP2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: ADDP2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 12;
			_closure_ac(a, c + 0);
		}
		/* ac: ADDP2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 15;
			_closure_ac(a, c + 0);
		}
		/* ac: ADDP2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 27;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 18;
			_closure_ac(a, c + 0);
		}
		/* ac: ADDP2(ac,conBn) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBn_NT] + 27;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 21;
			_closure_ac(a, c + 0);
		}
		/* eac: ADDP2(eac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 13;
			_closure_eac(a, c + 0);
		}
		/* eac: ADDP2(eac,conBn) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBn_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 16;
			_closure_eac(a, c + 0);
		}
		/* eac: ADDP2(eac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 31;
			_closure_eac(a, c + 0);
		}
		/* eac: ADDP2(iarg,eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_eac_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 34;
			_closure_eac(a, c + 0);
		}
		/* ac: ADDP2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(26+27));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 117;
			_closure_ac(a, c + 0);
		}
		break;
	case 2373: /* SUBI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: SUBI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 22;
			_closure_ac(a, c + 0);
		}
		/* ac: SUBI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 27;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 25;
			_closure_ac(a, c + 0);
		}
		/* ac: SUBI2(ac,conBn) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBn_NT] + 27;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 28;
			_closure_ac(a, c + 0);
		}
		/* eac: SUBI2(eac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 17;
			_closure_eac(a, c + 0);
		}
		/* eac: SUBI2(eac,conBn) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBn_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 20;
			_closure_eac(a, c + 0);
		}
		/* eac: SUBI2(eac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 35;
			_closure_eac(a, c + 0);
		}
		/* ac: SUBI2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(26+27));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 118;
			_closure_ac(a, c + 0);
		}
		if (	/* ac: SUBI2(ac,CVUI2(iarg)) */
			RIGHT_CHILD(a)->op == 2229 /* CVUI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_iarg_NT] + (mincpu6(28));
			if (c + 0 < p->cost[_ac_NT]) {
				p->cost[_ac_NT] = c + 0;
				p->rule._ac = 138;
				_closure_ac(a, c + 0);
			}
		}
		break;
	case 2374: /* SUBU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: SUBU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 23;
			_closure_ac(a, c + 0);
		}
		/* ac: SUBU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 27;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 26;
			_closure_ac(a, c + 0);
		}
		/* ac: SUBU2(ac,conBn) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBn_NT] + 27;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 29;
			_closure_ac(a, c + 0);
		}
		/* eac: SUBU2(eac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 18;
			_closure_eac(a, c + 0);
		}
		/* eac: SUBU2(eac,conBn) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBn_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 21;
			_closure_eac(a, c + 0);
		}
		/* eac: SUBU2(eac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 36;
			_closure_eac(a, c + 0);
		}
		/* ac: SUBU2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(26+27));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 119;
			_closure_ac(a, c + 0);
		}
		if (	/* ac: SUBU2(ac,CVUI2(iarg)) */
			RIGHT_CHILD(a)->op == 2229 /* CVUI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_iarg_NT] + (mincpu6(28));
			if (c + 0 < p->cost[_ac_NT]) {
				p->cost[_ac_NT] = c + 0;
				p->rule._ac = 137;
				_closure_ac(a, c + 0);
			}
		}
		break;
	case 2375: /* SUBP2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: SUBP2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 24;
			_closure_ac(a, c + 0);
		}
		/* ac: SUBP2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 27;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 27;
			_closure_ac(a, c + 0);
		}
		/* ac: SUBP2(ac,conBn) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBn_NT] + 27;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 30;
			_closure_ac(a, c + 0);
		}
		/* eac: SUBP2(eac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 19;
			_closure_eac(a, c + 0);
		}
		/* eac: SUBP2(eac,conBn) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conBn_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 22;
			_closure_eac(a, c + 0);
		}
		/* eac: SUBP2(eac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 37;
			_closure_eac(a, c + 0);
		}
		/* ac: SUBP2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(26+27));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 120;
			_closure_ac(a, c + 0);
		}
		break;
	case 2389: /* LSHI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: LSHI2(ac,con1) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con1_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 33;
			_closure_ac(a, c + 0);
		}
		/* ac: LSHI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 100;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 35;
			_closure_ac(a, c + 0);
		}
		/* ac: LSHI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 39;
			_closure_ac(a, c + 0);
		}
		/* eac: LSHI2(eac,con1) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con1_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 23;
			_closure_eac(a, c + 0);
		}
		/* eac: LSHI2(eac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 100;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 25;
			_closure_eac(a, c + 0);
		}
		break;
	case 2390: /* LSHU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: LSHU2(ac,con1) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con1_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 34;
			_closure_ac(a, c + 0);
		}
		/* ac: LSHU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 100;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 36;
			_closure_ac(a, c + 0);
		}
		/* ac: LSHU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 41;
			_closure_ac(a, c + 0);
		}
		/* eac: LSHU2(eac,con1) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con1_NT] + 28;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 24;
			_closure_eac(a, c + 0);
		}
		/* eac: LSHU2(eac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 100;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 26;
			_closure_eac(a, c + 0);
		}
		break;
	case 2405: /* MODI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: MODI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 56;
			_closure_ac(a, c + 0);
		}
		/* ac: MODI2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 60;
			_closure_ac(a, c + 0);
		}
		break;
	case 2406: /* MODU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: MODU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 57;
			_closure_ac(a, c + 0);
		}
		/* ac: MODU2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 61;
			_closure_ac(a, c + 0);
		}
		break;
	case 2421: /* RSHI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: RSHI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 100;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 37;
			_closure_ac(a, c + 0);
		}
		/* ac: RSHI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 40;
			_closure_ac(a, c + 0);
		}
		break;
	case 2422: /* RSHU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: RSHU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 100;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 38;
			_closure_ac(a, c + 0);
		}
		/* ac: RSHU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 42;
			_closure_ac(a, c + 0);
		}
		break;
	case 2437: /* BANDI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: BANDI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 64;
			_closure_ac(a, c + 0);
		}
		/* ac: BANDI2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 66;
			_closure_ac(a, c + 0);
		}
		/* ac: BANDI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 16;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 68;
			_closure_ac(a, c + 0);
		}
		/* ac: BANDI2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(26+25));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 121;
			_closure_ac(a, c + 0);
		}
		/* ac: BANDI2(reg,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(29));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 127;
			_closure_ac(a, c + 0);
		}
		break;
	case 2438: /* BANDU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: BANDU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 65;
			_closure_ac(a, c + 0);
		}
		/* ac: BANDU2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 67;
			_closure_ac(a, c + 0);
		}
		/* ac: BANDU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 16;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 69;
			_closure_ac(a, c + 0);
		}
		/* ac: BANDU2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(26+25));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 122;
			_closure_ac(a, c + 0);
		}
		/* ac: BANDU2(reg,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(29));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 128;
			_closure_ac(a, c + 0);
		}
		break;
	case 2453: /* BCOMI2 */
		_label(LEFT_CHILD(a));
		/* ac: BCOMI2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 68;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 62;
			_closure_ac(a, c + 0);
		}
		break;
	case 2454: /* BCOMU2 */
		_label(LEFT_CHILD(a));
		/* ac: BCOMU2(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 68;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 63;
			_closure_ac(a, c + 0);
		}
		break;
	case 2469: /* BORI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: BORI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 70;
			_closure_ac(a, c + 0);
		}
		/* ac: BORI2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 72;
			_closure_ac(a, c + 0);
		}
		/* ac: BORI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 16;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 74;
			_closure_ac(a, c + 0);
		}
		/* ac: BORI2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(26+21));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 123;
			_closure_ac(a, c + 0);
		}
		if (	/* ac: BORI2(CVUI2(reg),conB) */
			LEFT_CHILD(a)->op == 2229 /* CVUI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(LEFT_CHILD(a))->x.state))->cost[_reg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(29));
			if (c + 0 < p->cost[_ac_NT]) {
				p->cost[_ac_NT] = c + 0;
				p->rule._ac = 129;
				_closure_ac(a, c + 0);
			}
		}
		break;
	case 2470: /* BORU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: BORU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 71;
			_closure_ac(a, c + 0);
		}
		/* ac: BORU2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 73;
			_closure_ac(a, c + 0);
		}
		/* ac: BORU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 16;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 75;
			_closure_ac(a, c + 0);
		}
		/* ac: BORU2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(26+21));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 124;
			_closure_ac(a, c + 0);
		}
		if (	/* ac: BORU2(CVUI2(reg),conB) */
			LEFT_CHILD(a)->op == 2229 /* CVUI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(LEFT_CHILD(a))->x.state))->cost[_reg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(29));
			if (c + 0 < p->cost[_ac_NT]) {
				p->cost[_ac_NT] = c + 0;
				p->rule._ac = 130;
				_closure_ac(a, c + 0);
			}
		}
		break;
	case 2485: /* BXORI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: BXORI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 76;
			_closure_ac(a, c + 0);
		}
		/* ac: BXORI2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 78;
			_closure_ac(a, c + 0);
		}
		/* ac: BXORI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 16;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 80;
			_closure_ac(a, c + 0);
		}
		/* ac: BXORI2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(26+21));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 125;
			_closure_ac(a, c + 0);
		}
		if (	/* ac: BXORI2(CVUI2(reg),conB) */
			LEFT_CHILD(a)->op == 2229 /* CVUI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(LEFT_CHILD(a))->x.state))->cost[_reg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(29));
			if (c + 0 < p->cost[_ac_NT]) {
				p->cost[_ac_NT] = c + 0;
				p->rule._ac = 131;
				_closure_ac(a, c + 0);
			}
		}
		break;
	case 2486: /* BXORU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: BXORU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 77;
			_closure_ac(a, c + 0);
		}
		/* ac: BXORU2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 28;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 79;
			_closure_ac(a, c + 0);
		}
		/* ac: BXORU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 0;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 81;
			_closure_ac(a, c + 0);
		}
		/* ac: BXORU2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + (mincpu6(26+21));
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 126;
			_closure_ac(a, c + 0);
		}
		if (	/* ac: BXORU2(CVUI2(reg),conB) */
			LEFT_CHILD(a)->op == 2229 /* CVUI2 */
		) {
			c = ((struct _state *)(LEFT_CHILD(LEFT_CHILD(a))->x.state))->cost[_reg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + (mincpu6(29));
			if (c + 0 < p->cost[_ac_NT]) {
				p->cost[_ac_NT] = c + 0;
				p->rule._ac = 132;
				_closure_ac(a, c + 0);
			}
		}
		break;
	case 2501: /* DIVI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: DIVI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 54;
			_closure_ac(a, c + 0);
		}
		/* ac: DIVI2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 58;
			_closure_ac(a, c + 0);
		}
		break;
	case 2502: /* DIVU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: DIVU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 55;
			_closure_ac(a, c + 0);
		}
		/* ac: DIVU2(ac,con) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 59;
			_closure_ac(a, c + 0);
		}
		break;
	case 2517: /* MULI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: MULI2(conB,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_conB_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 100;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 43;
			_closure_ac(a, c + 0);
		}
		/* ac: MULI2(conBn,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_conBn_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 110;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 44;
			_closure_ac(a, c + 0);
		}
		/* ac: MULI2(conB,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_conB_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 100;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 45;
			_closure_ac(a, c + 0);
		}
		/* ac: MULI2(conBn,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_conBn_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 110;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 46;
			_closure_ac(a, c + 0);
		}
		/* ac: MULI2(con,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_con_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 47;
			_closure_ac(a, c + 0);
		}
		/* ac: MULI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 48;
			_closure_ac(a, c + 0);
		}
		/* ac: MULI2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 49;
			_closure_ac(a, c + 0);
		}
		/* eac: MULI2(conB,eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_conB_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_eac_NT] + 100;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 27;
			_closure_eac(a, c + 0);
		}
		/* eac: MULI2(conB,eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_conB_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_eac_NT] + 100;
		if (c + 0 < p->cost[_eac_NT]) {
			p->cost[_eac_NT] = c + 0;
			p->rule._eac = 28;
			_closure_eac(a, c + 0);
		}
		break;
	case 2518: /* MULU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* ac: MULU2(conB,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_conB_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 100;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 50;
			_closure_ac(a, c + 0);
		}
		/* ac: MULU2(con,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_con_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 51;
			_closure_ac(a, c + 0);
		}
		/* ac: MULU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 52;
			_closure_ac(a, c + 0);
		}
		/* ac: MULU2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 200;
		if (c + 0 < p->cost[_ac_NT]) {
			p->cost[_ac_NT] = c + 0;
			p->rule._ac = 53;
			_closure_ac(a, c + 0);
		}
		break;
	case 2533: /* EQI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: EQI2(ac,con0) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con0_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 21;
		}
		/* stmt: EQI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 42;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 22;
		}
		/* stmt: EQI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 54;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 23;
		}
		/* stmt: EQI2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 54;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 24;
		}
		break;
	case 2534: /* EQU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: EQU2(ac,con0) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con0_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 29;
		}
		/* stmt: EQU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 42;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 30;
		}
		/* stmt: EQU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 54;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 31;
		}
		/* stmt: EQU2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 54;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 32;
		}
		break;
	case 2549: /* GEI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: GEI2(ac,con0) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con0_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 40;
		}
		/* stmt: GEI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 80;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 46;
		}
		/* stmt: GEI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 54;
		}
		/* stmt: GEI2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 62;
		}
		break;
	case 2550: /* GEU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: GEU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 80;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 50;
		}
		/* stmt: GEU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 58;
		}
		/* stmt: GEU2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 66;
		}
		break;
	case 2565: /* GTI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: GTI2(ac,con0) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con0_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 39;
		}
		/* stmt: GTI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 80;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 45;
		}
		/* stmt: GTI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 53;
		}
		/* stmt: GTI2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 61;
		}
		break;
	case 2566: /* GTU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: GTU2(ac,con0) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con0_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 41;
		}
		/* stmt: GTU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 80;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 49;
		}
		/* stmt: GTU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 57;
		}
		/* stmt: GTU2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 65;
		}
		break;
	case 2581: /* LEI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: LEI2(ac,con0) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con0_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 38;
		}
		/* stmt: LEI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 80;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 44;
		}
		/* stmt: LEI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 52;
		}
		/* stmt: LEI2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 60;
		}
		break;
	case 2582: /* LEU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: LEU2(ac,con0) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con0_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 42;
		}
		/* stmt: LEU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 80;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 48;
		}
		/* stmt: LEU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 56;
		}
		/* stmt: LEU2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 64;
		}
		break;
	case 2597: /* LTI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: LTI2(ac,con0) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con0_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 37;
		}
		/* stmt: LTI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 80;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 43;
		}
		/* stmt: LTI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 51;
		}
		/* stmt: LTI2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 59;
		}
		break;
	case 2598: /* LTU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: LTU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 80;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 47;
		}
		/* stmt: LTU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 55;
		}
		/* stmt: LTU2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 63;
		}
		break;
	case 2613: /* NEI2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: NEI2(ac,con0) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con0_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 25;
		}
		/* stmt: NEI2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 42;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 26;
		}
		/* stmt: NEI2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 54;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 27;
		}
		/* stmt: NEI2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 54;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 28;
		}
		break;
	case 2614: /* NEU2 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: NEU2(ac,con0) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_con0_NT] + 28;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 33;
		}
		/* stmt: NEU2(ac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 42;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 34;
		}
		/* stmt: NEU2(ac,iarg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_iarg_NT] + 54;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 35;
		}
		/* stmt: NEU2(iarg,ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_iarg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_ac_NT] + 54;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 36;
		}
		break;
	case 4117: /* CNSTI4 */
		break;
	case 4118: /* CNSTU4 */
		break;
	case 4133: /* ARGI4 */
		_label(LEFT_CHILD(a));
		/* stmt: ARGI4(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_arg_stk(a));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 128;
		}
		/* stmt: ARGI4(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_arg_reg_only(a));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 134;
		}
		break;
	case 4134: /* ARGU4 */
		_label(LEFT_CHILD(a));
		/* stmt: ARGU4(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_arg_stk(a));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 129;
		}
		/* stmt: ARGU4(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_arg_reg_only(a));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 135;
		}
		break;
	case 4149: /* ASGNI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		if (	/* stmt: ASGNI4(VREGP,reg) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			c = ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 6;
			}
		}
		/* stmt: ASGNI4(vdst,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_vdst_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 120;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 96;
		}
		/* stmt: ASGNI4(vdst,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_vdst_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 120;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 97;
		}
		if (	/* stmt: ASGNI4(addr,INDIRI4(asrc)) */
			RIGHT_CHILD(a)->op == 4165 /* INDIRI4 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_asrc_NT] + 120;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 98;
			}
		}
		if (	/* stmt: ASGNI4(ac,INDIRI4(asrc)) */
			RIGHT_CHILD(a)->op == 4165 /* INDIRI4 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_asrc_NT] + 120;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 99;
			}
		}
		if (	/* stmt: ASGNI4(lddr,INDIRI4(lsrc)) */
			RIGHT_CHILD(a)->op == 4165 /* INDIRI4 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lddr_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_lsrc_NT] + 120;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 100;
			}
		}
		/* stmt: ASGNI4(spill,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_spill_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 152;
		}
		break;
	case 4150: /* ASGNU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		if (	/* stmt: ASGNU4(VREGP,reg) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			c = ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 7;
			}
		}
		/* stmt: ASGNU4(vdst,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_vdst_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 120;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 101;
		}
		/* stmt: ASGNU4(vdst,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_vdst_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 120;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 102;
		}
		if (	/* stmt: ASGNU4(addr,INDIRU4(asrc)) */
			RIGHT_CHILD(a)->op == 4166 /* INDIRU4 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_asrc_NT] + 120;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 103;
			}
		}
		if (	/* stmt: ASGNU4(ac,INDIRU4(asrc)) */
			RIGHT_CHILD(a)->op == 4166 /* INDIRU4 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_asrc_NT] + 120;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 104;
			}
		}
		if (	/* stmt: ASGNU4(lddr,INDIRU4(lsrc)) */
			RIGHT_CHILD(a)->op == 4166 /* INDIRU4 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lddr_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_lsrc_NT] + 120;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 105;
			}
		}
		/* stmt: ASGNU4(spill,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_spill_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 153;
		}
		break;
	case 4165: /* INDIRI4 */
		_label(LEFT_CHILD(a));
		if (	/* reg: INDIRI4(VREGP) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			if (mayrecalc(a)) {
				struct _state *q = a->syms[RX]->u.t.cse->x.state;
				*p = *q;
			}
			c = 0;
			if (c + 0 < p->cost[_reg_NT]) {
				p->cost[_reg_NT] = c + 0;
				p->rule._reg = 6;
				_closure_reg(a, c + 0);
			}
		}
		/* larg: INDIRI4(eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + 0;
		if (c + 0 < p->cost[_larg_NT]) {
			p->cost[_larg_NT] = c + 0;
			p->rule._larg = 2;
		}
		/* reg: INDIRI4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 120;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 24;
			_closure_reg(a, c + 0);
		}
		/* reg: INDIRI4(lddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lddr_NT] + 160;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 26;
			_closure_reg(a, c + 0);
		}
		/* reg: INDIRI4(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + 120;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 28;
			_closure_reg(a, c + 0);
		}
		/* lac: INDIRI4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 120;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 2;
			_closure_lac(a, c + 0);
		}
		/* lac: INDIRI4(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + 120;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 6;
			_closure_lac(a, c + 0);
		}
		break;
	case 4166: /* INDIRU4 */
		_label(LEFT_CHILD(a));
		if (	/* reg: INDIRU4(VREGP) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			if (mayrecalc(a)) {
				struct _state *q = a->syms[RX]->u.t.cse->x.state;
				*p = *q;
			}
			c = 0;
			if (c + 0 < p->cost[_reg_NT]) {
				p->cost[_reg_NT] = c + 0;
				p->rule._reg = 7;
				_closure_reg(a, c + 0);
			}
		}
		/* larg: INDIRU4(eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + 0;
		if (c + 0 < p->cost[_larg_NT]) {
			p->cost[_larg_NT] = c + 0;
			p->rule._larg = 3;
		}
		/* reg: INDIRU4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 120;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 25;
			_closure_reg(a, c + 0);
		}
		/* reg: INDIRU4(lddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lddr_NT] + 160;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 27;
			_closure_reg(a, c + 0);
		}
		/* reg: INDIRU4(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + 120;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 29;
			_closure_reg(a, c + 0);
		}
		/* lac: INDIRU4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 120;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 3;
			_closure_lac(a, c + 0);
		}
		/* lac: INDIRU4(lddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lddr_NT] + 160;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 4;
			_closure_lac(a, c + 0);
		}
		/* lac: INDIRU4(lddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lddr_NT] + 160;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 5;
			_closure_lac(a, c + 0);
		}
		/* lac: INDIRU4(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + 120;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 7;
			_closure_lac(a, c + 0);
		}
		break;
	case 4213: /* CVFI4 */
		_label(LEFT_CHILD(a));
		/* lac: CVFI4(fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 58;
			_closure_lac(a, c + 0);
		}
		break;
	case 4214: /* CVFU4 */
		_label(LEFT_CHILD(a));
		/* lac: CVFU4(fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 57;
			_closure_lac(a, c + 0);
		}
		break;
	case 4229: /* CVII4 */
		_label(LEFT_CHILD(a));
		/* lac: CVII4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 100;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 54;
			_closure_lac(a, c + 0);
		}
		/* reg: CVII4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 100;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 35;
			_closure_reg(a, c + 0);
		}
		break;
	case 4230: /* CVIU4 */
		_label(LEFT_CHILD(a));
		/* lac: CVIU4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 50;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 53;
			_closure_lac(a, c + 0);
		}
		/* reg: CVIU4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 50;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 34;
			_closure_reg(a, c + 0);
		}
		break;
	case 4277: /* CVUI4 */
		_label(LEFT_CHILD(a));
		/* lac: CVUI4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 50;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 56;
			_closure_lac(a, c + 0);
		}
		/* reg: CVUI4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 50;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 37;
			_closure_reg(a, c + 0);
		}
		break;
	case 4278: /* CVUU4 */
		_label(LEFT_CHILD(a));
		/* lac: CVUU4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 50;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 55;
			_closure_lac(a, c + 0);
		}
		/* reg: CVUU4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 50;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 36;
			_closure_reg(a, c + 0);
		}
		break;
	case 4293: /* NEGI4 */
		_label(LEFT_CHILD(a));
		/* lac: NEGI4(lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 30;
			_closure_lac(a, c + 0);
		}
		break;
	case 4309: /* CALLI4 */
		_label(LEFT_CHILD(a));
		/* lac: CALLI4(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + (mincpu5(28));
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 45;
			_closure_lac(a, c + 0);
		}
		/* lac: CALLI4(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 26;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 46;
			_closure_lac(a, c + 0);
		}
		/* lac: CALLI4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 26;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 47;
			_closure_lac(a, c + 0);
		}
		break;
	case 4310: /* CALLU4 */
		_label(LEFT_CHILD(a));
		/* lac: CALLU4(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + (mincpu5(28));
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 48;
			_closure_lac(a, c + 0);
		}
		/* lac: CALLU4(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 26;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 49;
			_closure_lac(a, c + 0);
		}
		/* lac: CALLU4(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 26;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 50;
			_closure_lac(a, c + 0);
		}
		break;
	case 4325: /* LOADI4 */
		_label(LEFT_CHILD(a));
		/* reg: LOADI4(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 120;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 14;
			_closure_reg(a, c + 0);
		}
		/* lac: LOADI4(lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + 0;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 51;
			_closure_lac(a, c + 0);
		}
		break;
	case 4326: /* LOADU4 */
		_label(LEFT_CHILD(a));
		/* reg: LOADU4(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 120;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 15;
			_closure_reg(a, c + 0);
		}
		/* lac: LOADU4(lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + 0;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 52;
			_closure_lac(a, c + 0);
		}
		break;
	case 4341: /* RETI4 */
		_label(LEFT_CHILD(a));
		/* stmt: RETI4(lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + 1;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 140;
		}
		break;
	case 4342: /* RETU4 */
		_label(LEFT_CHILD(a));
		/* stmt: RETU4(lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + 1;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 141;
		}
		break;
	case 4405: /* ADDI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: ADDI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 8;
			_closure_lac(a, c + 0);
		}
		/* lac: ADDI4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 10;
			_closure_lac(a, c + 0);
		}
		break;
	case 4406: /* ADDU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: ADDU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 9;
			_closure_lac(a, c + 0);
		}
		/* lac: ADDU4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 11;
			_closure_lac(a, c + 0);
		}
		break;
	case 4421: /* SUBI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: SUBI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 12;
			_closure_lac(a, c + 0);
		}
		break;
	case 4422: /* SUBU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: SUBU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 13;
			_closure_lac(a, c + 0);
		}
		break;
	case 4437: /* LSHI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: LSHI4(lac,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 22;
			_closure_lac(a, c + 0);
		}
		/* lac: LSHI4(lac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 23;
			_closure_lac(a, c + 0);
		}
		break;
	case 4438: /* LSHU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: LSHU4(lac,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 24;
			_closure_lac(a, c + 0);
		}
		/* lac: LSHU4(lac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 25;
			_closure_lac(a, c + 0);
		}
		break;
	case 4453: /* MODI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: MODI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 20;
			_closure_lac(a, c + 0);
		}
		break;
	case 4454: /* MODU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: MODU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 21;
			_closure_lac(a, c + 0);
		}
		break;
	case 4469: /* RSHI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: RSHI4(lac,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 26;
			_closure_lac(a, c + 0);
		}
		/* lac: RSHI4(lac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 27;
			_closure_lac(a, c + 0);
		}
		break;
	case 4470: /* RSHU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: RSHU4(lac,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 28;
			_closure_lac(a, c + 0);
		}
		/* lac: RSHU4(lac,conB) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_conB_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 29;
			_closure_lac(a, c + 0);
		}
		break;
	case 4485: /* BANDI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: BANDI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 39;
			_closure_lac(a, c + 0);
		}
		/* lac: BANDI4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 40;
			_closure_lac(a, c + 0);
		}
		break;
	case 4486: /* BANDU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: BANDU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 32;
			_closure_lac(a, c + 0);
		}
		/* lac: BANDU4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 33;
			_closure_lac(a, c + 0);
		}
		break;
	case 4501: /* BCOMI4 */
		_label(LEFT_CHILD(a));
		/* lac: BCOMI4(lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 38;
			_closure_lac(a, c + 0);
		}
		break;
	case 4502: /* BCOMU4 */
		_label(LEFT_CHILD(a));
		/* lac: BCOMU4(lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 31;
			_closure_lac(a, c + 0);
		}
		break;
	case 4517: /* BORI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: BORI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 41;
			_closure_lac(a, c + 0);
		}
		/* lac: BORI4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 42;
			_closure_lac(a, c + 0);
		}
		break;
	case 4518: /* BORU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: BORU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 34;
			_closure_lac(a, c + 0);
		}
		/* lac: BORU4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 35;
			_closure_lac(a, c + 0);
		}
		break;
	case 4533: /* BXORI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: BXORI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 43;
			_closure_lac(a, c + 0);
		}
		/* lac: BXORI4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 44;
			_closure_lac(a, c + 0);
		}
		break;
	case 4534: /* BXORU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: BXORU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 36;
			_closure_lac(a, c + 0);
		}
		/* lac: BXORU4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 37;
			_closure_lac(a, c + 0);
		}
		break;
	case 4549: /* DIVI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: DIVI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 18;
			_closure_lac(a, c + 0);
		}
		break;
	case 4550: /* DIVU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: DIVU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 19;
			_closure_lac(a, c + 0);
		}
		break;
	case 4565: /* MULI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: MULI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 14;
			_closure_lac(a, c + 0);
		}
		/* lac: MULI4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 16;
			_closure_lac(a, c + 0);
		}
		break;
	case 4566: /* MULU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* lac: MULU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 15;
			_closure_lac(a, c + 0);
		}
		/* lac: MULU4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_lac_NT]) {
			p->cost[_lac_NT] = c + 0;
			p->rule._lac = 17;
			_closure_lac(a, c + 0);
		}
		break;
	case 4581: /* EQI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: EQI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 81;
		}
		/* stmt: EQI4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 93;
		}
		break;
	case 4582: /* EQU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: EQU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 83;
		}
		/* stmt: EQU4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 95;
		}
		break;
	case 4597: /* GEI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: GEI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 75;
		}
		/* stmt: GEI4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 87;
		}
		break;
	case 4598: /* GEU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: GEU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 79;
		}
		/* stmt: GEU4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 91;
		}
		break;
	case 4613: /* GTI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: GTI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 74;
		}
		/* stmt: GTI4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 86;
		}
		break;
	case 4614: /* GTU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: GTU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 78;
		}
		/* stmt: GTU4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 90;
		}
		break;
	case 4629: /* LEI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: LEI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 73;
		}
		/* stmt: LEI4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 85;
		}
		break;
	case 4630: /* LEU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: LEU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 77;
		}
		/* stmt: LEU4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 89;
		}
		break;
	case 4645: /* LTI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: LTI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 72;
		}
		/* stmt: LTI4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 84;
		}
		break;
	case 4646: /* LTU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: LTU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 76;
		}
		/* stmt: LTU4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 88;
		}
		break;
	case 4661: /* NEI4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: NEI4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 80;
		}
		/* stmt: NEI4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 92;
		}
		break;
	case 4662: /* NEU4 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: NEU4(lac,larg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_larg_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 82;
		}
		/* stmt: NEU4(larg,lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_larg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_lac_NT] + 100;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 94;
		}
		break;
	case 5137: /* CNSTF5 */
		break;
	case 5153: /* ARGF5 */
		_label(LEFT_CHILD(a));
		/* stmt: ARGF5(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_arg_stk(a));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 127;
		}
		/* stmt: ARGF5(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + (if_arg_reg_only(a));
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 133;
		}
		break;
	case 5169: /* ASGNF5 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		if (	/* stmt: ASGNF5(VREGP,reg) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			c = ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 8;
			}
		}
		/* stmt: ASGNF5(vdst,fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_vdst_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_fac_NT] + 180;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 119;
		}
		/* stmt: ASGNF5(vdst,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_vdst_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 150;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 120;
		}
		if (	/* stmt: ASGNF5(addr,INDIRF5(asrc)) */
			RIGHT_CHILD(a)->op == 5185 /* INDIRF5 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_asrc_NT] + 150;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 121;
			}
		}
		if (	/* stmt: ASGNF5(ac,INDIRF5(asrc)) */
			RIGHT_CHILD(a)->op == 5185 /* INDIRF5 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_asrc_NT] + 150;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 122;
			}
		}
		if (	/* stmt: ASGNF5(lddr,INDIRF5(lsrc)) */
			RIGHT_CHILD(a)->op == 5185 /* INDIRF5 */
		) {
			c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lddr_NT] + ((struct _state *)(LEFT_CHILD(RIGHT_CHILD(a))->x.state))->cost[_lsrc_NT] + 150;
			if (c + 0 < p->cost[_stmt_NT]) {
				p->cost[_stmt_NT] = c + 0;
				p->rule._stmt = 123;
			}
		}
		/* stmt: ASGNF5(spill,reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_spill_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_reg_NT] + 0;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 154;
		}
		break;
	case 5185: /* INDIRF5 */
		_label(LEFT_CHILD(a));
		if (	/* reg: INDIRF5(VREGP) */
			LEFT_CHILD(a)->op == 711 /* VREGP */
		) {
			if (mayrecalc(a)) {
				struct _state *q = a->syms[RX]->u.t.cse->x.state;
				*p = *q;
			}
			c = 0;
			if (c + 0 < p->cost[_reg_NT]) {
				p->cost[_reg_NT] = c + 0;
				p->rule._reg = 8;
				_closure_reg(a, c + 0);
			}
		}
		/* farg: INDIRF5(eac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_eac_NT] + 0;
		if (c + 0 < p->cost[_farg_NT]) {
			p->cost[_farg_NT] = c + 0;
			p->rule._farg = 2;
		}
		/* reg: INDIRF5(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 150;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 31;
			_closure_reg(a, c + 0);
		}
		/* reg: INDIRF5(lddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lddr_NT] + 190;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 32;
			_closure_reg(a, c + 0);
		}
		/* reg: INDIRF5(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + 150;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 33;
			_closure_reg(a, c + 0);
		}
		/* fac: INDIRF5(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 180;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 2;
			_closure_fac(a, c + 0);
		}
		/* fac: INDIRF5(lddr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lddr_NT] + 220;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 3;
			_closure_fac(a, c + 0);
		}
		/* fac: INDIRF5(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + 180;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 4;
			_closure_fac(a, c + 0);
		}
		break;
	case 5233: /* CVFF5 */
		break;
	case 5249: /* CVIF5 */
		_label(LEFT_CHILD(a));
		/* fac: CVIF5(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + (if_cv_from(a,2,180));
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 19;
			_closure_fac(a, c + 0);
		}
		/* fac: CVIF5(lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + (if_cv_from(a,4,200));
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 20;
			_closure_fac(a, c + 0);
		}
		break;
	case 5297: /* CVUF5 */
		_label(LEFT_CHILD(a));
		/* fac: CVUF5(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + (if_cv_from(a,2,180));
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 17;
			_closure_fac(a, c + 0);
		}
		/* fac: CVUF5(lac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_lac_NT] + (if_cv_from(a,4,200));
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 18;
			_closure_fac(a, c + 0);
		}
		break;
	case 5313: /* NEGF5 */
		_label(LEFT_CHILD(a));
		/* fac: NEGF5(fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + 50;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 12;
			_closure_fac(a, c + 0);
		}
		break;
	case 5329: /* CALLF5 */
		_label(LEFT_CHILD(a));
		/* fac: CALLF5(addr) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_addr_NT] + (mincpu5(28));
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 13;
			_closure_fac(a, c + 0);
		}
		/* fac: CALLF5(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 26;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 14;
			_closure_fac(a, c + 0);
		}
		/* fac: CALLF5(ac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_ac_NT] + 26;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 15;
			_closure_fac(a, c + 0);
		}
		break;
	case 5345: /* LOADF5 */
		_label(LEFT_CHILD(a));
		/* reg: LOADF5(reg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_reg_NT] + 150;
		if (c + 0 < p->cost[_reg_NT]) {
			p->cost[_reg_NT] = c + 0;
			p->rule._reg = 16;
			_closure_reg(a, c + 0);
		}
		/* fac: LOADF5(fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + 0;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 16;
			_closure_fac(a, c + 0);
		}
		break;
	case 5361: /* RETF5 */
		_label(LEFT_CHILD(a));
		/* stmt: RETF5(fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + 1;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 139;
		}
		break;
	case 5425: /* ADDF5 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* fac: ADDF5(fac,farg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_farg_NT] + 200;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 5;
			_closure_fac(a, c + 0);
		}
		/* fac: ADDF5(farg,fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_farg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_fac_NT] + 200;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 6;
			_closure_fac(a, c + 0);
		}
		break;
	case 5441: /* SUBF5 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* fac: SUBF5(fac,farg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_farg_NT] + 200;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 7;
			_closure_fac(a, c + 0);
		}
		/* fac: SUBF5(farg,fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_farg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_fac_NT] + (200+50);
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 8;
			_closure_fac(a, c + 0);
		}
		break;
	case 5569: /* DIVF5 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* fac: DIVF5(fac,farg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_farg_NT] + 200;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 11;
			_closure_fac(a, c + 0);
		}
		break;
	case 5585: /* MULF5 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* fac: MULF5(fac,farg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_farg_NT] + 200;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 9;
			_closure_fac(a, c + 0);
		}
		/* fac: MULF5(farg,fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_farg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_fac_NT] + 200;
		if (c + 0 < p->cost[_fac_NT]) {
			p->cost[_fac_NT] = c + 0;
			p->rule._fac = 10;
			_closure_fac(a, c + 0);
		}
		break;
	case 5601: /* EQF5 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: EQF5(fac,farg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_farg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 107;
		}
		/* stmt: EQF5(farg,fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_farg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_fac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 113;
		}
		break;
	case 5617: /* GEF5 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: GEF5(fac,farg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_farg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 112;
		}
		/* stmt: GEF5(farg,fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_farg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_fac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 118;
		}
		break;
	case 5633: /* GTF5 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: GTF5(fac,farg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_farg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 111;
		}
		/* stmt: GTF5(farg,fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_farg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_fac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 117;
		}
		break;
	case 5649: /* LEF5 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: LEF5(fac,farg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_farg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 110;
		}
		/* stmt: LEF5(farg,fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_farg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_fac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 116;
		}
		break;
	case 5665: /* LTF5 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: LTF5(fac,farg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_farg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 109;
		}
		/* stmt: LTF5(farg,fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_farg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_fac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 115;
		}
		break;
	case 5681: /* NEF5 */
		_label(LEFT_CHILD(a));
		_label(RIGHT_CHILD(a));
		/* stmt: NEF5(fac,farg) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_fac_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_farg_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 108;
		}
		/* stmt: NEF5(farg,fac) */
		c = ((struct _state *)(LEFT_CHILD(a)->x.state))->cost[_farg_NT] + ((struct _state *)(RIGHT_CHILD(a)->x.state))->cost[_fac_NT] + 200;
		if (c + 0 < p->cost[_stmt_NT]) {
			p->cost[_stmt_NT] = c + 0;
			p->rule._stmt = 114;
		}
		break;
	default:
		fatal("_label", "Bad terminal %d\n", OP_LABEL(a));
	}
}

static void _kids(NODEPTR_TYPE p, int eruleno, NODEPTR_TYPE kids[]) {
	if (!p)
		fatal("_kids", "Null tree\n", 0);
	if (!kids)
		fatal("_kids", "Null kids\n", 0);
	switch (eruleno) {
	case 530: /* rmw: VREGP */
	case 470: /* stmt: LABELV */
	case 98: /* spill: ADDRLP2 */
	case 61: /* zddr: ADDRGP2 */
	case 58: /* addr: ADDRGP2 */
	case 57: /* lddr: ADDRFP2 */
	case 56: /* lddr: ADDRLP2 */
	case 54: /* con: CNSTP2 */
	case 53: /* con: CNSTU2 */
	case 52: /* con: CNSTI2 */
	case 51: /* con: CNSTU1 */
	case 50: /* con: CNSTI1 */
	case 49: /* conBs: CNSTI1 */
	case 48: /* conBs: CNSTI2 */
	case 47: /* conBn: CNSTI2 */
	case 45: /* conB: CNSTU1 */
	case 44: /* conB: CNSTI1 */
	case 43: /* conB: CNSTP2 */
	case 42: /* conB: CNSTU2 */
	case 41: /* conB: CNSTI2 */
	case 40: /* con1n: CNSTI2 */
	case 39: /* con1n: CNSTI1 */
	case 38: /* con1: CNSTU2 */
	case 37: /* con1: CNSTI2 */
	case 36: /* con1: CNSTU1 */
	case 35: /* con1: CNSTI1 */
	case 34: /* con0: CNSTP2 */
	case 33: /* con0: CNSTU2 */
	case 32: /* con0: CNSTI2 */
	case 31: /* con0: CNSTU1 */
	case 30: /* con0: CNSTI1 */
	case 8: /* reg: INDIRF5(VREGP) */
	case 7: /* reg: INDIRU4(VREGP) */
	case 6: /* reg: INDIRI4(VREGP) */
	case 5: /* reg: INDIRP2(VREGP) */
	case 4: /* reg: INDIRU2(VREGP) */
	case 3: /* reg: INDIRI2(VREGP) */
	case 2: /* reg: INDIRU1(VREGP) */
	case 1: /* reg: INDIRI1(VREGP) */
		break;
	case 16: /* stmt: ASGNF5(VREGP,reg) */
	case 15: /* stmt: ASGNU4(VREGP,reg) */
	case 14: /* stmt: ASGNI4(VREGP,reg) */
	case 13: /* stmt: ASGNP2(VREGP,reg) */
	case 12: /* stmt: ASGNU2(VREGP,reg) */
	case 11: /* stmt: ASGNI2(VREGP,reg) */
	case 10: /* stmt: ASGNU1(VREGP,reg) */
	case 9: /* stmt: ASGNI1(VREGP,reg) */
		kids[0] = RIGHT_CHILD(p);
		break;
	case 525: /* ac: NEGI2(reg) */
	case 524: /* ac: NEGI2(ac) */
	case 505: /* ac: INDIRU1(reg) */
	case 504: /* ac: INDIRI1(reg) */
	case 503: /* ac: INDIRP2(reg) */
	case 502: /* ac: INDIRU2(reg) */
	case 501: /* ac: INDIRI2(reg) */
	case 500: /* reg: INDIRU1(ac) */
	case 499: /* reg: INDIRI1(ac) */
	case 498: /* reg: INDIRP2(ac) */
	case 497: /* reg: INDIRU2(ac) */
	case 496: /* reg: INDIRI2(ac) */
	case 473: /* stmt: JUMPV(ac) */
	case 472: /* stmt: JUMPV(reg) */
	case 471: /* stmt: JUMPV(addr) */
	case 469: /* fac: CVIF5(lac) */
	case 468: /* fac: CVIF5(ac) */
	case 467: /* lac: CVFI4(fac) */
	case 466: /* ac: CVFI2(fac) */
	case 465: /* fac: CVUF5(lac) */
	case 464: /* fac: CVUF5(ac) */
	case 463: /* lac: CVFU4(fac) */
	case 462: /* ac: CVFU2(fac) */
	case 461: /* reg: CVUI4(ac) */
	case 460: /* reg: CVUU4(ac) */
	case 459: /* reg: CVII4(ac) */
	case 458: /* reg: CVIU4(ac) */
	case 457: /* lac: CVUI4(ac) */
	case 456: /* lac: CVUU4(ac) */
	case 455: /* lac: CVII4(ac) */
	case 454: /* lac: CVIU4(ac) */
	case 453: /* ac: CVUI2(ac) */
	case 452: /* ac: CVII2(ac) */
	case 451: /* ac: CVUI2(ac0) */
	case 450: /* ac: CVII2(ac0) */
	case 449: /* ac: CVUI2(reg) */
	case 448: /* ac: CVII2(reg) */
	case 447: /* fac: LOADF5(fac) */
	case 446: /* lac: LOADU4(lac) */
	case 445: /* lac: LOADI4(lac) */
	case 444: /* ac: LOADP2(lac) */
	case 443: /* ac: LOADU2(lac) */
	case 442: /* ac: LOADI2(lac) */
	case 441: /* ac: LOADP2(reg) */
	case 440: /* ac: LOADU2(reg) */
	case 439: /* ac: LOADI2(reg) */
	case 438: /* ac: LOADP2(ac) */
	case 437: /* ac: LOADU2(ac) */
	case 436: /* ac: LOADI2(ac) */
	case 435: /* ac: LOADU1(ac) */
	case 434: /* ac: LOADI1(ac) */
	case 433: /* ac0: LOADU1(reg) */
	case 432: /* ac0: LOADI1(reg) */
	case 431: /* stmt: RETP2(ac) */
	case 430: /* stmt: RETU2(ac) */
	case 429: /* stmt: RETI2(ac) */
	case 428: /* stmt: RETU4(lac) */
	case 427: /* stmt: RETI4(lac) */
	case 426: /* stmt: RETF5(fac) */
	case 425: /* stmt: ARGP2(reg) */
	case 424: /* stmt: ARGU2(reg) */
	case 423: /* stmt: ARGI2(reg) */
	case 422: /* stmt: ARGU4(reg) */
	case 421: /* stmt: ARGI4(reg) */
	case 420: /* stmt: ARGF5(reg) */
	case 419: /* stmt: ARGP2(reg) */
	case 418: /* stmt: ARGU2(reg) */
	case 417: /* stmt: ARGI2(reg) */
	case 416: /* stmt: ARGU4(reg) */
	case 415: /* stmt: ARGI4(reg) */
	case 414: /* stmt: ARGF5(reg) */
	case 413: /* stmt: CALLV(ac) */
	case 412: /* stmt: CALLV(reg) */
	case 411: /* stmt: CALLV(addr) */
	case 410: /* ac: CALLP2(ac) */
	case 409: /* ac: CALLP2(reg) */
	case 408: /* ac: CALLP2(addr) */
	case 407: /* ac: CALLU2(ac) */
	case 406: /* ac: CALLU2(reg) */
	case 405: /* ac: CALLU2(addr) */
	case 404: /* ac: CALLI2(ac) */
	case 403: /* ac: CALLI2(reg) */
	case 402: /* ac: CALLI2(addr) */
	case 401: /* lac: CALLU4(ac) */
	case 400: /* lac: CALLU4(reg) */
	case 399: /* lac: CALLU4(addr) */
	case 398: /* lac: CALLI4(ac) */
	case 397: /* lac: CALLI4(reg) */
	case 396: /* lac: CALLI4(addr) */
	case 395: /* fac: CALLF5(ac) */
	case 394: /* fac: CALLF5(reg) */
	case 393: /* fac: CALLF5(addr) */
	case 375: /* fac: NEGF5(fac) */
	case 367: /* fac: INDIRF5(addr) */
	case 366: /* fac: INDIRF5(lddr) */
	case 365: /* fac: INDIRF5(ac) */
	case 363: /* reg: INDIRF5(addr) */
	case 362: /* reg: INDIRF5(lddr) */
	case 361: /* reg: INDIRF5(ac) */
	case 359: /* farg: INDIRF5(eac) */
	case 316: /* lac: BCOMI4(lac) */
	case 309: /* lac: BCOMU4(lac) */
	case 308: /* lac: NEGI4(lac) */
	case 285: /* lac: INDIRU4(addr) */
	case 284: /* lac: INDIRI4(addr) */
	case 283: /* lac: INDIRU4(lddr) */
	case 282: /* lac: INDIRU4(lddr) */
	case 281: /* lac: INDIRU4(ac) */
	case 280: /* lac: INDIRI4(ac) */
	case 278: /* reg: INDIRU4(addr) */
	case 277: /* reg: INDIRI4(addr) */
	case 276: /* reg: INDIRU4(lddr) */
	case 275: /* reg: INDIRI4(lddr) */
	case 274: /* reg: INDIRU4(ac) */
	case 273: /* reg: INDIRI4(ac) */
	case 271: /* larg: INDIRU4(eac) */
	case 270: /* larg: INDIRI4(eac) */
	case 155: /* ac: BCOMU2(ac) */
	case 154: /* ac: BCOMI2(ac) */
	case 124: /* ac: NEGI2(reg) */
	case 123: /* ac: NEGI2(ac) */
	case 101: /* iarg: INDIRP2(spill) */
	case 100: /* iarg: INDIRI2(spill) */
	case 99: /* iarg: INDIRU2(spill) */
	case 97: /* iarg: INDIRP2(zddr) */
	case 96: /* iarg: INDIRU2(zddr) */
	case 95: /* iarg: INDIRI2(zddr) */
	case 93: /* ac0: INDIRU1(ac) */
	case 92: /* ac0: INDIRI1(ac) */
	case 91: /* ac: INDIRP2(ac) */
	case 90: /* ac: INDIRU2(ac) */
	case 89: /* ac: INDIRI2(ac) */
	case 88: /* eac0: INDIRU1(zddr) */
	case 87: /* eac0: INDIRI1(zddr) */
	case 86: /* eac: INDIRP2(zddr) */
	case 85: /* eac: INDIRU2(zddr) */
	case 84: /* eac: INDIRI2(zddr) */
	case 83: /* eac0: INDIRU1(eac) */
	case 82: /* eac0: INDIRI1(eac) */
	case 81: /* eac: INDIRP2(eac) */
	case 80: /* eac: INDIRU2(eac) */
	case 79: /* eac: INDIRI2(eac) */
	case 29: /* reg: LOADP2(con) */
	case 28: /* reg: LOADU2(con) */
	case 27: /* reg: LOADI2(con) */
	case 26: /* reg: LOADU1(conB) */
	case 25: /* reg: LOADI1(conBs) */
	case 24: /* reg: LOADF5(reg) */
	case 23: /* reg: LOADU4(reg) */
	case 22: /* reg: LOADI4(reg) */
	case 21: /* reg: LOADP2(reg) */
	case 20: /* reg: LOADU2(reg) */
	case 19: /* reg: LOADI2(reg) */
	case 18: /* reg: LOADU1(reg) */
	case 17: /* reg: LOADI1(reg) */
		kids[0] = LEFT_CHILD(p);
		break;
	case 531: /* rmw: zddr */
	case 364: /* fac: reg */
	case 360: /* reg: fac */
	case 358: /* farg: reg */
	case 357: /* stmt: fac */
	case 279: /* lac: reg */
	case 272: /* reg: lac */
	case 269: /* larg: reg */
	case 268: /* stmt: lac */
	case 263: /* lsrc: addr */
	case 262: /* asrc: eac */
	case 261: /* asrc: lddr */
	case 260: /* asrc: addr */
	case 259: /* vdst: eac */
	case 258: /* vdst: lddr */
	case 257: /* vdst: addr */
	case 94: /* iarg: reg */
	case 78: /* eac: lddr */
	case 77: /* eac: addr */
	case 76: /* eac0: zddr */
	case 75: /* eac: eac0 */
	case 74: /* eac: reg */
	case 73: /* ac: addr */
	case 72: /* ac: zddr */
	case 71: /* ac: con */
	case 70: /* ac0: conB */
	case 69: /* ac0: eac0 */
	case 68: /* ac: eac */
	case 67: /* ac: ac0 */
	case 66: /* ac: reg */
	case 65: /* reg: ac */
	case 64: /* stmt: ac */
	case 63: /* stmt: reg */
	case 62: /* zddr: conB */
	case 60: /* addr: zddr */
	case 59: /* addr: con */
	case 55: /* con: addr */
	case 46: /* conB: zddr */
		kids[0] = p;
		break;
	case 555: /* stmt: ASGNU1(rmw,conB) */
	case 554: /* stmt: ASGNI1(rmw,conB) */
	case 553: /* stmt: ASGNP2(rmw,conB) */
	case 552: /* stmt: ASGNU2(rmw,conB) */
	case 551: /* stmt: ASGNI2(rmw,conB) */
	case 519: /* ac: BANDU2(reg,conB) */
	case 518: /* ac: BANDI2(reg,conB) */
	case 517: /* ac: BXORU2(ac,con) */
	case 516: /* ac: BXORI2(ac,con) */
	case 515: /* ac: BORU2(ac,con) */
	case 514: /* ac: BORI2(ac,con) */
	case 513: /* ac: BANDU2(ac,con) */
	case 512: /* ac: BANDI2(ac,con) */
	case 511: /* ac: SUBP2(ac,con) */
	case 510: /* ac: SUBU2(ac,con) */
	case 509: /* ac: SUBI2(ac,con) */
	case 508: /* ac: ADDP2(ac,con) */
	case 507: /* ac: ADDU2(ac,con) */
	case 506: /* ac: ADDI2(ac,con) */
	case 495: /* stmt: ASGNU1(addr,ac) */
	case 494: /* stmt: ASGNI1(addr,ac) */
	case 493: /* stmt: ASGNU2(addr,ac) */
	case 492: /* stmt: ASGNI2(addr,ac) */
	case 491: /* stmt: ASGNP2(addr,ac) */
	case 490: /* stmt: ASGNU1(ac,conB) */
	case 489: /* stmt: ASGNI1(ac,conBs) */
	case 488: /* stmt: ASGNI1(ac,conB) */
	case 487: /* stmt: ASGNU2(ac,con) */
	case 486: /* stmt: ASGNI2(ac,con) */
	case 485: /* stmt: ASGNP2(ac,con) */
	case 484: /* stmt: ASGNU1(ac,iarg) */
	case 483: /* stmt: ASGNI1(ac,iarg) */
	case 482: /* stmt: ASGNU2(ac,iarg) */
	case 481: /* stmt: ASGNI2(ac,iarg) */
	case 480: /* stmt: ASGNP2(ac,iarg) */
	case 479: /* stmt: ASGNF5(spill,reg) */
	case 478: /* stmt: ASGNU4(spill,reg) */
	case 477: /* stmt: ASGNI4(spill,reg) */
	case 476: /* stmt: ASGNP2(spill,reg) */
	case 475: /* stmt: ASGNU2(spill,reg) */
	case 474: /* stmt: ASGNI2(spill,reg) */
	case 389: /* stmt: ASGNF5(vdst,reg) */
	case 388: /* stmt: ASGNF5(vdst,fac) */
	case 387: /* stmt: GEF5(farg,fac) */
	case 386: /* stmt: GTF5(farg,fac) */
	case 385: /* stmt: LEF5(farg,fac) */
	case 384: /* stmt: LTF5(farg,fac) */
	case 383: /* stmt: NEF5(farg,fac) */
	case 382: /* stmt: EQF5(farg,fac) */
	case 381: /* stmt: GEF5(fac,farg) */
	case 380: /* stmt: GTF5(fac,farg) */
	case 379: /* stmt: LEF5(fac,farg) */
	case 378: /* stmt: LTF5(fac,farg) */
	case 377: /* stmt: NEF5(fac,farg) */
	case 376: /* stmt: EQF5(fac,farg) */
	case 374: /* fac: DIVF5(fac,farg) */
	case 373: /* fac: MULF5(farg,fac) */
	case 372: /* fac: MULF5(fac,farg) */
	case 371: /* fac: SUBF5(farg,fac) */
	case 370: /* fac: SUBF5(fac,farg) */
	case 369: /* fac: ADDF5(farg,fac) */
	case 368: /* fac: ADDF5(fac,farg) */
	case 353: /* stmt: ASGNU4(vdst,reg) */
	case 352: /* stmt: ASGNU4(vdst,lac) */
	case 348: /* stmt: ASGNI4(vdst,reg) */
	case 347: /* stmt: ASGNI4(vdst,lac) */
	case 346: /* stmt: EQU4(larg,lac) */
	case 345: /* stmt: NEU4(larg,lac) */
	case 344: /* stmt: EQI4(larg,lac) */
	case 343: /* stmt: NEI4(larg,lac) */
	case 342: /* stmt: GEU4(larg,lac) */
	case 341: /* stmt: GTU4(larg,lac) */
	case 340: /* stmt: LEU4(larg,lac) */
	case 339: /* stmt: LTU4(larg,lac) */
	case 338: /* stmt: GEI4(larg,lac) */
	case 337: /* stmt: GTI4(larg,lac) */
	case 336: /* stmt: LEI4(larg,lac) */
	case 335: /* stmt: LTI4(larg,lac) */
	case 334: /* stmt: EQU4(lac,larg) */
	case 333: /* stmt: NEU4(lac,larg) */
	case 332: /* stmt: EQI4(lac,larg) */
	case 331: /* stmt: NEI4(lac,larg) */
	case 330: /* stmt: GEU4(lac,larg) */
	case 329: /* stmt: GTU4(lac,larg) */
	case 328: /* stmt: LEU4(lac,larg) */
	case 327: /* stmt: LTU4(lac,larg) */
	case 326: /* stmt: GEI4(lac,larg) */
	case 325: /* stmt: GTI4(lac,larg) */
	case 324: /* stmt: LEI4(lac,larg) */
	case 323: /* stmt: LTI4(lac,larg) */
	case 322: /* lac: BXORI4(larg,lac) */
	case 321: /* lac: BXORI4(lac,larg) */
	case 320: /* lac: BORI4(larg,lac) */
	case 319: /* lac: BORI4(lac,larg) */
	case 318: /* lac: BANDI4(larg,lac) */
	case 317: /* lac: BANDI4(lac,larg) */
	case 315: /* lac: BXORU4(larg,lac) */
	case 314: /* lac: BXORU4(lac,larg) */
	case 313: /* lac: BORU4(larg,lac) */
	case 312: /* lac: BORU4(lac,larg) */
	case 311: /* lac: BANDU4(larg,lac) */
	case 310: /* lac: BANDU4(lac,larg) */
	case 307: /* lac: RSHU4(lac,conB) */
	case 306: /* lac: RSHU4(lac,reg) */
	case 305: /* lac: RSHI4(lac,conB) */
	case 304: /* lac: RSHI4(lac,reg) */
	case 303: /* lac: LSHU4(lac,conB) */
	case 302: /* lac: LSHU4(lac,reg) */
	case 301: /* lac: LSHI4(lac,conB) */
	case 300: /* lac: LSHI4(lac,reg) */
	case 299: /* lac: MODU4(lac,larg) */
	case 298: /* lac: MODI4(lac,larg) */
	case 297: /* lac: DIVU4(lac,larg) */
	case 296: /* lac: DIVI4(lac,larg) */
	case 295: /* lac: MULU4(larg,lac) */
	case 294: /* lac: MULI4(larg,lac) */
	case 293: /* lac: MULU4(lac,larg) */
	case 292: /* lac: MULI4(lac,larg) */
	case 291: /* lac: SUBU4(lac,larg) */
	case 290: /* lac: SUBI4(lac,larg) */
	case 289: /* lac: ADDU4(larg,lac) */
	case 288: /* lac: ADDI4(larg,lac) */
	case 287: /* lac: ADDU4(lac,larg) */
	case 286: /* lac: ADDI4(lac,larg) */
	case 256: /* stmt: GEU2(iarg,ac) */
	case 255: /* stmt: GTU2(iarg,ac) */
	case 254: /* stmt: LEU2(iarg,ac) */
	case 253: /* stmt: LTU2(iarg,ac) */
	case 252: /* stmt: GEI2(iarg,ac) */
	case 251: /* stmt: GTI2(iarg,ac) */
	case 250: /* stmt: LEI2(iarg,ac) */
	case 249: /* stmt: LTI2(iarg,ac) */
	case 248: /* stmt: GEU2(ac,iarg) */
	case 247: /* stmt: GTU2(ac,iarg) */
	case 246: /* stmt: LEU2(ac,iarg) */
	case 245: /* stmt: LTU2(ac,iarg) */
	case 244: /* stmt: GEI2(ac,iarg) */
	case 243: /* stmt: GTI2(ac,iarg) */
	case 242: /* stmt: LEI2(ac,iarg) */
	case 241: /* stmt: LTI2(ac,iarg) */
	case 240: /* stmt: GEU2(ac,conB) */
	case 239: /* stmt: GTU2(ac,conB) */
	case 238: /* stmt: LEU2(ac,conB) */
	case 237: /* stmt: LTU2(ac,conB) */
	case 236: /* stmt: GEI2(ac,conB) */
	case 235: /* stmt: GTI2(ac,conB) */
	case 234: /* stmt: LEI2(ac,conB) */
	case 233: /* stmt: LTI2(ac,conB) */
	case 232: /* stmt: LEU2(ac,con0) */
	case 231: /* stmt: GTU2(ac,con0) */
	case 230: /* stmt: GEI2(ac,con0) */
	case 229: /* stmt: GTI2(ac,con0) */
	case 228: /* stmt: LEI2(ac,con0) */
	case 227: /* stmt: LTI2(ac,con0) */
	case 226: /* stmt: NEU2(iarg,ac) */
	case 225: /* stmt: NEU2(ac,iarg) */
	case 224: /* stmt: NEU2(ac,conB) */
	case 223: /* stmt: NEU2(ac,con0) */
	case 222: /* stmt: EQU2(iarg,ac) */
	case 221: /* stmt: EQU2(ac,iarg) */
	case 220: /* stmt: EQU2(ac,conB) */
	case 219: /* stmt: EQU2(ac,con0) */
	case 218: /* stmt: NEI2(iarg,ac) */
	case 217: /* stmt: NEI2(ac,iarg) */
	case 216: /* stmt: NEI2(ac,conB) */
	case 215: /* stmt: NEI2(ac,con0) */
	case 214: /* stmt: EQI2(iarg,ac) */
	case 213: /* stmt: EQI2(ac,iarg) */
	case 212: /* stmt: EQI2(ac,conB) */
	case 211: /* stmt: EQI2(ac,con0) */
	case 210: /* stmt: ASGNU1(iarg,ac) */
	case 209: /* stmt: ASGNU1(zddr,ac) */
	case 208: /* stmt: ASGNI1(iarg,ac) */
	case 207: /* stmt: ASGNI1(zddr,ac) */
	case 206: /* stmt: ASGNU2(iarg,ac) */
	case 205: /* stmt: ASGNU2(zddr,ac) */
	case 204: /* stmt: ASGNI2(iarg,ac) */
	case 203: /* stmt: ASGNI2(zddr,ac) */
	case 202: /* stmt: ASGNP2(iarg,ac) */
	case 201: /* stmt: ASGNP2(zddr,ac) */
	case 200: /* eac: SUBP2(eac,iarg) */
	case 199: /* eac: SUBU2(eac,iarg) */
	case 198: /* eac: SUBI2(eac,iarg) */
	case 197: /* eac: ADDP2(iarg,eac) */
	case 196: /* eac: ADDU2(iarg,eac) */
	case 195: /* eac: ADDI2(iarg,eac) */
	case 194: /* eac: ADDP2(eac,iarg) */
	case 193: /* eac: ADDU2(eac,iarg) */
	case 192: /* eac: ADDI2(eac,iarg) */
	case 191: /* eac: MULI2(conB,eac) */
	case 190: /* eac: MULI2(conB,eac) */
	case 189: /* eac: LSHU2(eac,conB) */
	case 188: /* eac: LSHI2(eac,conB) */
	case 187: /* eac: LSHU2(eac,con1) */
	case 186: /* eac: LSHI2(eac,con1) */
	case 185: /* eac: SUBP2(eac,conBn) */
	case 184: /* eac: SUBU2(eac,conBn) */
	case 183: /* eac: SUBI2(eac,conBn) */
	case 182: /* eac: SUBP2(eac,conB) */
	case 181: /* eac: SUBU2(eac,conB) */
	case 180: /* eac: SUBI2(eac,conB) */
	case 179: /* eac: ADDP2(eac,conBn) */
	case 178: /* eac: ADDU2(eac,conBn) */
	case 177: /* eac: ADDI2(eac,conBn) */
	case 176: /* eac: ADDP2(eac,conB) */
	case 175: /* eac: ADDU2(eac,conB) */
	case 174: /* eac: ADDI2(eac,conB) */
	case 173: /* ac: BXORU2(ac,conB) */
	case 172: /* ac: BXORI2(ac,conB) */
	case 171: /* ac: BXORU2(iarg,ac) */
	case 170: /* ac: BXORI2(iarg,ac) */
	case 169: /* ac: BXORU2(ac,iarg) */
	case 168: /* ac: BXORI2(ac,iarg) */
	case 167: /* ac: BORU2(ac,conB) */
	case 166: /* ac: BORI2(ac,conB) */
	case 165: /* ac: BORU2(iarg,ac) */
	case 164: /* ac: BORI2(iarg,ac) */
	case 163: /* ac: BORU2(ac,iarg) */
	case 162: /* ac: BORI2(ac,iarg) */
	case 161: /* ac: BANDU2(ac,conB) */
	case 160: /* ac: BANDI2(ac,conB) */
	case 159: /* ac: BANDU2(iarg,ac) */
	case 158: /* ac: BANDI2(iarg,ac) */
	case 157: /* ac: BANDU2(ac,iarg) */
	case 156: /* ac: BANDI2(ac,iarg) */
	case 153: /* ac: MODU2(ac,con) */
	case 152: /* ac: MODI2(ac,con) */
	case 151: /* ac: DIVU2(ac,con) */
	case 150: /* ac: DIVI2(ac,con) */
	case 149: /* ac: MODU2(ac,iarg) */
	case 148: /* ac: MODI2(ac,iarg) */
	case 147: /* ac: DIVU2(ac,iarg) */
	case 146: /* ac: DIVI2(ac,iarg) */
	case 145: /* ac: MULU2(iarg,ac) */
	case 144: /* ac: MULU2(ac,iarg) */
	case 143: /* ac: MULU2(con,ac) */
	case 142: /* ac: MULU2(conB,ac) */
	case 141: /* ac: MULI2(iarg,ac) */
	case 140: /* ac: MULI2(ac,iarg) */
	case 139: /* ac: MULI2(con,ac) */
	case 138: /* ac: MULI2(conBn,reg) */
	case 137: /* ac: MULI2(conB,reg) */
	case 136: /* ac: MULI2(conBn,ac) */
	case 135: /* ac: MULI2(conB,ac) */
	case 134: /* ac: RSHU2(ac,iarg) */
	case 133: /* ac: LSHU2(ac,iarg) */
	case 132: /* ac: RSHI2(ac,iarg) */
	case 131: /* ac: LSHI2(ac,iarg) */
	case 130: /* ac: RSHU2(ac,conB) */
	case 129: /* ac: RSHI2(ac,conB) */
	case 128: /* ac: LSHU2(ac,conB) */
	case 127: /* ac: LSHI2(ac,conB) */
	case 126: /* ac: LSHU2(ac,con1) */
	case 125: /* ac: LSHI2(ac,con1) */
	case 122: /* ac: SUBP2(ac,conBn) */
	case 121: /* ac: SUBU2(ac,conBn) */
	case 120: /* ac: SUBI2(ac,conBn) */
	case 119: /* ac: SUBP2(ac,conB) */
	case 118: /* ac: SUBU2(ac,conB) */
	case 117: /* ac: SUBI2(ac,conB) */
	case 116: /* ac: SUBP2(ac,iarg) */
	case 115: /* ac: SUBU2(ac,iarg) */
	case 114: /* ac: SUBI2(ac,iarg) */
	case 113: /* ac: ADDP2(ac,conBn) */
	case 112: /* ac: ADDU2(ac,conBn) */
	case 111: /* ac: ADDI2(ac,conBn) */
	case 110: /* ac: ADDP2(ac,conB) */
	case 109: /* ac: ADDU2(ac,conB) */
	case 108: /* ac: ADDI2(ac,conB) */
	case 107: /* ac: ADDP2(iarg,ac) */
	case 106: /* ac: ADDU2(iarg,ac) */
	case 105: /* ac: ADDI2(iarg,ac) */
	case 104: /* ac: ADDP2(ac,iarg) */
	case 103: /* ac: ADDU2(ac,iarg) */
	case 102: /* ac: ADDI2(ac,iarg) */
		kids[0] = LEFT_CHILD(p);
		kids[1] = RIGHT_CHILD(p);
		break;
	case 264: /* stmt: ARGB(INDIRB(asrc)) */
		kids[0] = LEFT_CHILD(LEFT_CHILD(p));
		break;
	case 529: /* ac: SUBI2(ac,CVUI2(iarg)) */
	case 528: /* ac: SUBU2(ac,CVUI2(iarg)) */
	case 527: /* ac: ADDU2(ac,CVUI2(iarg)) */
	case 526: /* ac: ADDI2(ac,CVUI2(iarg)) */
	case 392: /* stmt: ASGNF5(lddr,INDIRF5(lsrc)) */
	case 391: /* stmt: ASGNF5(ac,INDIRF5(asrc)) */
	case 390: /* stmt: ASGNF5(addr,INDIRF5(asrc)) */
	case 356: /* stmt: ASGNU4(lddr,INDIRU4(lsrc)) */
	case 355: /* stmt: ASGNU4(ac,INDIRU4(asrc)) */
	case 354: /* stmt: ASGNU4(addr,INDIRU4(asrc)) */
	case 351: /* stmt: ASGNI4(lddr,INDIRI4(lsrc)) */
	case 350: /* stmt: ASGNI4(ac,INDIRI4(asrc)) */
	case 349: /* stmt: ASGNI4(addr,INDIRI4(asrc)) */
	case 267: /* stmt: ASGNB(lddr,INDIRB(lsrc)) */
	case 266: /* stmt: ASGNB(ac,INDIRB(asrc)) */
	case 265: /* stmt: ASGNB(addr,INDIRB(asrc)) */
		kids[0] = LEFT_CHILD(p);
		kids[1] = LEFT_CHILD(RIGHT_CHILD(p));
		break;
	case 523: /* ac: BXORU2(CVUI2(reg),conB) */
	case 522: /* ac: BXORI2(CVUI2(reg),conB) */
	case 521: /* ac: BORU2(CVUI2(reg),conB) */
	case 520: /* ac: BORI2(CVUI2(reg),conB) */
		kids[0] = LEFT_CHILD(LEFT_CHILD(p));
		kids[1] = RIGHT_CHILD(p);
		break;
	case 535: /* stmt: ASGNI1(rmw,LOADI1(SUBI2(CVII2(INDIRI1(rmw)),con1))) */
	case 534: /* stmt: ASGNU1(rmw,LOADU1(SUBI2(CVUI2(INDIRU1(rmw)),con1))) */
	case 533: /* stmt: ASGNI1(rmw,LOADI1(ADDI2(CVII2(INDIRI1(rmw)),con1))) */
	case 532: /* stmt: ASGNU1(rmw,LOADU1(ADDI2(CVUI2(INDIRU1(rmw)),con1))) */
		kids[0] = LEFT_CHILD(p);
		kids[1] = LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(p)))));
		kids[2] = RIGHT_CHILD(LEFT_CHILD(RIGHT_CHILD(p)));
		break;
	case 550: /* stmt: ASGNU2(rmw,LSHU2(INDIRU2(rmw),con1)) */
	case 549: /* stmt: ASGNI2(rmw,LSHI2(INDIRI2(rmw),con1)) */
	case 545: /* stmt: ASGNI2(rmw,ADDI2(INDIRI2(rmw),con1n)) */
	case 544: /* stmt: ASGNU2(rmw,ADDU2(INDIRU2(rmw),con1n)) */
	case 543: /* stmt: ASGNP2(rmw,ADDP2(INDIRP2(rmw),con1n)) */
	case 542: /* stmt: ASGNI2(rmw,SUBI2(INDIRI2(rmw),con1)) */
	case 541: /* stmt: ASGNU2(rmw,SUBU2(INDIRU2(rmw),con1)) */
	case 540: /* stmt: ASGNP2(rmw,SUBP2(INDIRP2(rmw),con1)) */
	case 539: /* stmt: ASGNI2(rmw,ADDI2(INDIRI2(rmw),con1)) */
	case 538: /* stmt: ASGNU2(rmw,ADDU2(INDIRU2(rmw),con1)) */
	case 537: /* stmt: ASGNP2(rmw,ADDP2(INDIRP2(rmw),con1)) */
	case 536: /* stmt: ASGNP2(rmw,ADDP2(INDIRP2(rmw),con1)) */
		kids[0] = LEFT_CHILD(p);
		kids[1] = LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(p)));
		kids[2] = RIGHT_CHILD(RIGHT_CHILD(p));
		break;
	case 548: /* stmt: ASGNU2(rmw,BCOMU2(INDIRU2(rmw))) */
	case 547: /* stmt: ASGNI2(rmw,BCOMI2(INDIRI2(rmw))) */
	case 546: /* stmt: ASGNI2(rmw,NEGI2(INDIRI2(rmw))) */
		kids[0] = LEFT_CHILD(p);
		kids[1] = LEFT_CHILD(LEFT_CHILD(RIGHT_CHILD(p)));
		break;
	default:
		fatal("_kids", "Bad rule number %d\n", eruleno);
	}
}

#line 936 "src/gigatron.md"
/*---- BEGIN CODE --*/


static const char *segname() {
  if (cseg == CODE) return "CODE";
  if (cseg == DATA) return "DATA";
  if (cseg == LIT)  return "DATA";
  if (cseg == BSS)  return "BSS";
  return "?";
}

static void lprint(const char *fmt, ...) {
  char buf[1024];
  SList n;
  va_list ap;
  va_start(ap, fmt);
  vfprint(NULL, buf, fmt, ap);
  va_end(ap);
  n = allocate(sizeof(struct slist)+strlen(buf), PERM);
  strcpy(n->s, buf);
  n->next = &lhead;
  n->prev = lhead.prev;
  n->next->prev = n;
  n->prev->next = n;
}

/* Sometimes gen outputs data in the middle of a function.
   We don't want that here. */
static void xprint_init(void)
{
  in_function = 1;
  xhead.prev = xhead.next = &xhead;
}
static void xprint(const char *fmt, ...)
{
  char buf[1024];
  SList n;
  va_list ap;
  va_start(ap, fmt);
  vfprint(NULL, buf, fmt, ap);
  va_end(ap);
  if (in_function) {
    n = allocate(sizeof(struct slist)+strlen(buf), FUNC);
    strcpy(n->s, buf);
    n->next = &xhead;
    n->prev = xhead.prev;
    n->next->prev = n;
    n->prev->next = n;
  } else {
    print("%s", buf);
  }
}
static void xprint_finish(void)
{
  SList n;
  for (n = xhead.next; n != &xhead; n = n->next)
    print("%s", n->s);
  xhead.prev = xhead.next = &xhead;
  in_function = 0;
}

static int bitcount(unsigned mask) {
  unsigned i, n = 0;
  for (i = 1; i; i <<= 1)
    if (mask&i)
      n++;
  return n;
}

static int if_arg_reg_only(Node p)
{
  return p->syms[2] ? LBURG_MAX : 1;
}

static int if_arg_stk(Node p)
{
  return p->syms[2] ? 1 : LBURG_MAX;
}

static int if_zpconst(Node p)
{
  Symbol s = p->syms[0];
  assert(specific(p->op) == CNST+P);
  if ((size_t)s->u.c.v.p == ((size_t)s->u.c.v.p & 0xff))
    return 0;
  return LBURG_MAX;
}

static int if_zpglobal(Node p)
{
  /* TODO */
  return LBURG_MAX;
}

static int sametree(Node p, Node q) {
  return p == NULL && q == NULL
    || p && q && p->op == q->op && p->syms[0] == q->syms[0]
    && sametree(p->kids[0], q->kids[0])
    && sametree(p->kids[1], q->kids[1]);
}

static int if_rmw(Node a, int cost)
{
  Node r;
  assert(a);
  assert(generic(a->op) == ASGN);
  assert(a->kids[0]);
  assert(a->kids[1]);
  r = a->kids[1];
  while (generic(r->op) != INDIR)
    {
      if (r->kids[0])
        r = r->kids[0];
      else
        return LBURG_MAX;
    }
  if (sametree(a->kids[0], r->kids[0]))
    return cost;
  if (r->syms[RX]->temporary && r->syms[RX]->generated && r->syms[RX]->u.t.cse)
    {
      r = r->syms[RX]->u.t.cse;
      if (generic(r->op) == LOAD && r->kids[0])
        r = r->kids[0];
      if (generic(r->op) == INDIR && sametree(a->kids[0], r->kids[0]))
        return cost;
    }
  return LBURG_MAX;
}

static int if_not_asgn_tmp(Node p, int cost)
{
  Node n;
  assert(p);
  assert(generic(p->op) == ASGN);
  assert(p->kids[0]);
  n = p->kids[0];
  if (specific(n->op) == VREG+P && n->syms[0]->temporary)
    return LBURG_MAX;
  return cost;
}

static int if_cv_from(Node p, int sz, int cost)
{
  assert(p->syms[0]);
  assert(p->syms[0]->scope == CONSTANTS);
  assert(p->syms[0]->type = inttype);
  if (p->syms[0]->u.c.v.i == sz)
    return cost;
  return LBURG_MAX;
}

static void progend(void)
{
  extern char *firstfile; /* From input.c */
  SList s;
  print("# ======== (epilog)\n");
  print("code=[\n");
  for (s = lhead.next; s != &lhead; s = s->next)
    print("\t%s%s", s->s, (s->next == &lhead) ? "" : ",\n");
  print(" ]\n");
  print("module(code=code, ");
  if (firstfile)
    print("name='%s', ", firstfile);
  print("cpu=%d);\n", cpu);
  print("\n# Local Variables:"
        "\n# mode: python"
        "\n# indent-tabs-mode: t"
        "\n# End:\n");
}

static void progbeg(int argc, char *argv[])
{
  int i;
  /* Parse flags */
  parseflags(argc, argv);
  for (i=0; i<argc; i++)
    if (!strcmp(argv[i],"-cpu=4"))
      cpu = 4;
    else if (!strcmp(argv[i],"-cpu=5"))
      cpu = 5; /* Has CALLI,CMPHI,CMPHS. */
    else if (!strcmp(argv[i],"-cpu=6"))
      cpu = 6; /* TBD */
    else if (!strncmp(argv[i],"-cpu=",5))
      warning("invalid cpu %s\n", argv[i]+5);
  /* Print header */
  print("#VCPUv%d\n\n",cpu);
  /* Prepare registers */
  ireg[23] = mkreg("SP", 23, 1, IREG);
  for (i=0; i<23; i++)
    ireg[i] = mkreg("R%d", i, 1, IREG);
  for (i=0; i+1<23; i++)
    lreg[i] = mkreg("L%d", i, 3, IREG);
  for (i=0; i+2<23; i++)
    freg[i] = mkreg("F%d", i, 7, IREG);
  /* vAC/LAC/FAC */
  ireg[31] = mkreg("vAC", 24, 1, IREG);
  lreg[31] = mkreg("LAC", 26, 3, IREG);
  freg[31] = mkreg("FAC", 25, 7, IREG);
  /* Prepare wildcards */
  iregw = mkwildcard(ireg);
  lregw = mkwildcard(lreg);
  fregw = mkwildcard(freg);
  tmask[IREG] = REGMASK_TEMPS; /* nonleaf */
  vmask[IREG] = REGMASK_SAVED; /* nonleaf */
  tmask[FREG] = vmask[FREG] = 0;
  /* No segment */
  cseg = -1;
}

static Symbol rmap(int opk)
{
  switch(optype(opk)) {
  case I: case U:
    return (opsize(opk)==4) ? lregw : iregw;
  case P: case B:
    return iregw;
  case F:
    return fregw;
  default:
    return 0;
  }
}
  
static Symbol argreg(int argno, int ty, int sz, int *roffset)
{
  Symbol r = 0;
  if (argno == 0)
    *roffset = 8; /* First register is R8 */
  if (*roffset >= 16)
    return 0;
  if (ty == I || ty == U || ty == P)
    if (sz <= 2)
      r = ireg[*roffset];
    else
      r = lreg[*roffset];
  else if (ty == F)
    r = freg[*roffset];
  if (r == 0 || r->x.regnode->mask & ~REGMASK_ARGS)
    return 0;
  *roffset += roundup(sz,2)/2;
  return r;
}

static void target(Node p)
{
  assert(p);
  switch (specific(p->op))
    {
    case ARG+F: case ARG+I: case ARG+P: case ARG+U:
      if (p->syms[1])
        rtarget(p, 0, p->syms[1]);
      break;
    }
}

static int inst_contains_call(Node p)
{
  if ((generic(p->op) == CALL) ||
      (p->kids[0] && !p->kids[0]->x.inst && inst_contains_call(p->kids[0])) ||
      (p->kids[1] && !p->kids[1]->x.inst && inst_contains_call(p->kids[1])) )
    return 1;
  return 0;
}

static void clobber(Node p)
{
  static unsigned argmask = 0;
  assert(p);
  if (generic(p->op) == ARG) {
    /* Mark argument register as used so that it is not allocated as a
       temporary while preparing the remaining args. */
    Symbol r = p->syms[1];
    if (p->x.argno == 0)
      argmask = 0;
    if (r && r->x.regnode) {
      assert(r->x.regnode->set == 0);
      argmask |= r->x.regnode->mask;
      freemask[0] &= ~r->x.regnode->mask;
    }
  }
  if (inst_contains_call(p)) {
    /* Clobber all caller-saved registers before a call. */
    unsigned mask =  REGMASK_TEMPS & ~REGMASK_SAVED;
    if (p->x.registered && p->syms[2] && p->syms[2]->x.regnode->set == IREG)
      mask &= ~p->syms[2]->x.regnode->mask;
    if (mask)
      spill(mask, IREG, p);
  }
  if (argmask && p->x.next && inst_contains_call(p->x.next)) {
    /* Free all argument registers before the call */
    freemask[0] |= argmask;
    argmask = 0;
  }
}


/* Helper for preralloc */
static const char *skip_comment_in_template(const char *tpl)
{
  const char *s;
  for (s = tpl; s && *s; s++) {
    if (! strncmp(s, "%{#", 3)) {
      if (! (s = strchr(s, '}')))
        return tpl;
    } else if (!isspace(*s))
      break;
  }
  return s;
}

/* Helper for preralloc */
static int find_reguse(Node p, int nt, Symbol sym,
                       const char **lefttpl, int *leftkid, Node *leftkn)
{
  Node n = p;
  int rulenum = (*IR->x._rule)(n->x.state, nt);
  const short *nts = IR->x._nts[rulenum];
  const char *template = IR->x._templates[rulenum];
  Node kids[10];
  int leftidx = -1;
  int count = 0;
  int i;

  template = skip_comment_in_template(template);
  if (template[0] == '%' && isdigit(template[1]))
    leftidx = template[1] - '0';
  (*IR->x._kids)(n, rulenum, kids);
  for (i=0; nts[i] && i<NELEMS(kids); i++)
    {
      Node k = kids[i];
      int knt = nts[i];
      if (knt == k->x.inst) {
        if (k->syms[RX] == sym) {
          count += 1;
          if (lefttpl && leftidx < 0) {
            *lefttpl = template;
            *leftkid = i;
            *leftkn = k;
          }
        }
      } else if (i == leftidx) {
        count += find_reguse(k, knt, sym, lefttpl, leftkid, leftkn);
      } else {
        count += find_reguse(k, knt, sym, 0, 0, 0);
      }
    }
  return count;
}

/* Helper for preralloc */
static void change_sym_to_ac(Node p, Symbol sym, Symbol ac)
{
  assert(p->syms[RX] == sym);
  p->syms[RX] = ac;
  p->x.registered = 1;
  if (sym->temporary) {
    Node *q = &sym->x.lastuse;
    while (*q) {
      if (*q == p)
        *q = (*q)->x.prevuse;
      else
        q = &(*q)->x.prevuse;
    }
  }
  p->x.prevuse = 0;
}

/* Helper for preralloc */
static int scan_ac_preserving_instructions(Symbol sym, Symbol r, Node q, Symbol pr)
{
  int count, usecount;
  const char *lefttpl;
  int leftkid;
  Node p;
  /* count temporary variable uses */
  usecount = -1;
  for (p = sym->x.lastuse; p; p = p->x.prevuse)
    usecount += 1;
  /* scan instructions until finding the last use of sym */
  for(; ; q = q->x.next)
    {
      /* Acceptable instructions here fall in two categories:
         instructions that leave vAC/LAC/FAC unchanged, and
         instructions that load sym into vAC/LAC/FAC. Since
         we do not have the infrastructure to do this generally,
         we only recognize a couple common cases. */
      if (! q)
        return 0;
      /* Instructions that generate no code */
      if (generic(q->op)==INDIR && specific(q->kids[0]->op) == VREG+P)
        /* matches INDIR(VREGP) rule which does not generate code */
        continue;
      if (generic(q->op)==ASGN && specific(q->kids[0]->op) == VREG+P
          && q->kids[1]->x.inst == _reg_NT)
        /* matches ASGN(VREGP,reg) which does not generate code */
        continue;
      /* For instructions that generate code, we start
         by counting how many times the instruction uses sym. */
      lefttpl = 0;
      count = find_reguse(q, q->x.inst, sym, &lefttpl, &leftkid, &p);
      usecount -= count;
      if (generic(q->op)==ASGN && specific(q->kids[0]->op) == VREG+P
          && q->kids[0]->syms[0] != sym && q->kids[0]->syms[0] != ireg[31]
          && count == 0)
        /* matches a RMW rule whose code preserves vAC/LAC/FAC */
        continue;
      if (generic(q->op)==LOAD && q->kids[0]->x.inst == _reg_NT
          && generic(q->kids[0]->op) == INDIR
          && specific(q->kids[0]->kids[0]->op) == VREG+P
          && q->kids[0]->kids[0]->syms[0] == sym)
        /* matches a move instruction whose source is sym */
        {
          if (pr && lefttpl && count == 1 && p)
            change_sym_to_ac(p, sym, pr);
          if (usecount == 0)
            /* signal that we've reached the last use of sym */
            return 1;
          continue;
        }
      /* Next instruction is not known to preserve ac.
         But its first opcode might be the last use of sym */
#define ONLY_ELIDED_OPCODES 1
#if ONLY_ELIDED_OPCODES
      if (lefttpl && leftkid == 0) {
        char buf[32];
        sprintf(buf,"%%{src!=%s:", r->x.name);
        lefttpl = skip_comment_in_template(lefttpl);
        if (! strncmp(lefttpl, buf, strlen(buf)))
          for(; *lefttpl && *lefttpl != '}'; lefttpl++)
            if (*lefttpl == ';' && !strstr(lefttpl, "%0")) {
              /* First opcode can be elided and no reference to %0 follows.
                 We could also have checked that %0 appears in the opcode. */
              if (pr)
                change_sym_to_ac(p, sym, pr);
              if (count == 1 && usecount == 0)
                /* signal we've reached the last use of sym */
                return 1;
            }
      }
#else
      /* This older variation catches a couple 
         more cases but feels more risky */
      if (lefttpl) {
        char buf[3] = { '%', '0' + leftkid, 0 };
        /* Template expansion refers to sym as %0.
           But it also has to be in the first opcode.
           Note: this test is fragile because the code above
           does not understand the %[0b] constructs! */
        const char *p0 = strstr(lefttpl, buf);
        const char *p1 = strchr(lefttpl, ';');
        if (p0 && p1 && p0 < p1 && !strstr(p1, buf)) {
          if (pr)
            change_sym_to_ac(p, sym, pr);
          if (count == 1 && usecount == 0)
            return 1;
        }
      }
#endif
      return 0;
    }
}

static void preralloc(Node p)
{
  Symbol sym = p->syms[RX];
  int rulenum = (*IR->x._rule)(p->x.state, p->x.inst);
  short *nts = IR->x._nts[rulenum];
  const char *template = IR->x._templates[rulenum];
  Symbol r = 0;
  Node q = p->x.next;
  
  /* Try to eliminate useless data moving operations between
     successive trees in the same forest, by using vAC/LAC/FAC instead
     of allocating a temporary register. */
  Symbol patch = 0;
  if (!strncmp(template,"\t%{#alsoVAC}", 12))
    patch = r = ireg[31];
  else if (!strncmp(template,"\t%{#alsoLAC}", 12))
    patch = r = lreg[31];
  else if (!strncmp(template,"\t%{#alsoFAC}", 12))
    patch = r = freg[31];
  else if (sym->temporary && !strncmp(template,"\t%{#canVAC}", 11))
    r = ireg[31];
  if (r && q && generic(q->op) == ASGN && q->kids[0]->op == VREG+P)
    {
      /* in order to use vAC/LAC/FAC instead of a temporary register,
         we must be sure that the value of vAC/LAC/FAC is unchanged
         whenever the code needs it.*/
      if (scan_ac_preserving_instructions(sym, r, q->x.next, patch)
          && sym->temporary)
        {
          /* optimize the temporary out of existence because 
             we have reached its last use. */
          r->x.lastuse = sym->x.lastuse;
          for (q = sym->x.lastuse; q; q = q->x.prevuse) {
            q->syms[RX] = r;
            q->x.registered = 1;
          }
        }
    }
}

static void myemitfmt(const char *fmt, Node p, Node *kids, short *nts)
{
  /* Enhancements of emitfmt with respect to the original version:

     - delegates %{...} delegates to the IR function emit3(),
       which can call emitasm/emitfmt() recursively.

     - Templates might be split in sections with |. Writing $0 to $9
       only prints the first section of the specified kid template.
       The other sections can be accessed with syntax $[0b] where '0'
       is the kid number and 'b' is a letter indicating 
       which section to process. 
  */
  static int alt_s;
  int s = alt_s;
  alt_s = 0;
  for (; *fmt; fmt++)
    if (*fmt == '|' && s == 0)
      break;
    else if (*fmt == '|')
      s -= 1;
    else if (s > 0)
      continue;
    else if (*fmt != '%')
      (void)putchar(*fmt);
    else if (*++fmt == 'F')                                   /* %F */
      print("%d", framesize);
    else if (*fmt >= 'a' && *fmt < 'a' + NELEMS(p->syms))     /* %a..%c */
      fputs(p->syms[*fmt - 'a']->x.name, stdout);
    else if (*fmt >= '0' && *fmt <= '9')                      /* %0..%9 */
      emitasm(kids[*fmt - '0'], nts[*fmt - '0']);
    else if (*fmt == '[' && fmt[3] == ']' && fmt[1]>='0' && fmt[1]<='9'
             && fmt[2] >= 'a' && fmt[2] <= 'z') {      /* %[0a] */
      fmt += 3;
      alt_s = fmt[-1] - 'a';
      emitasm(kids[fmt[-2] - '0'], nts[fmt[-2] - '0']);
      alt_s = 0;
    } else if (*fmt == '{') {
      int level = 0;
      const char *s;
      for (s=fmt++; *s; s++)
        if (*s=='{')
          level += 1;
        else if (*s=='}' && !--level)
          break;
      assert(!level);
      emit3(stringn(fmt, s-fmt), p, kids, nts);
      fmt = s;
    } else
      (void)putchar(*fmt);
}

static void emit3(const char *fmt, Node p, Node *kids, short *nts)
{
  int i = 0;
  /* %{#COMMENT} -- comment [nothing emitted]  */
  if (fmt[0]=='#')
    {
      /* This is mostly used to help preralloc.
         %{#alsoVAC} : contents of destination reg is also left in vAC.
         %{#alsoLAC} : contents of destination reg is also left in LAC.
         %{#alsoFAC} : contents of destination reg is also left in FAC.
         %{#canVAC}  : destination reg could be vAC. */
      return;
    }
  while (fmt[i] && fmt[i++] != ':')
    { }
  /* %{dst!=XXX:YYY} */
  if (!strncmp(fmt,"dst!=",5) && fmt[i])
    {
      if (p->syms[RX]->x.name != stringn(fmt+5,i-6))
        myemitfmt(fmt+i, p, kids, nts);
      return;
    }
  /* %{src!=XXX:YYY} */
  else if (!strncmp(fmt,"src!=", 5) && fmt[i])
    {
      if (!kids[0] || !kids[0]->syms[RX] || kids[0]->syms[RX]->x.name != stringn(fmt+5,i-6))
        myemitfmt(fmt+i, p, kids, nts);
      return;
    }
  /* %{dst==XXX:YYY} */
  if (!strncmp(fmt,"dst==",5) && fmt[i])
    {
      if (p->syms[RX]->x.name == stringn(fmt+5,i-6))
        myemitfmt(fmt+i, p, kids, nts);
      return;
    }
  /* %{src==XXX:YYY} */
  else if (!strncmp(fmt,"src==", 5) && fmt[i])
    {
      if (kids[0] && kids[0]->syms[RX] && kids[0]->syms[RX]->x.name == stringn(fmt+5,i-6))
        myemitfmt(fmt+i, p, kids, nts);
      return;
    }
  /* %{mulC[:R]} -- multiplication by a small constant */
  else if (!strncmp(fmt,"mul", 3) && fmt[3] >= '0' && fmt[3] <= '9')
    {
      int c;
      Node k;
      const char *r = "T3";
      i = fmt[3] - '0';
      k = kids[i];
      assert(k);
      if (! (k->syms[0] && k->syms[0]->scope == CONSTANTS))
        if (generic(k->op) == INDIR && k->syms[2] && k->syms[2]->u.t.cse)
          k = k->syms[2]->u.t.cse;
      assert(k->syms[0] && k->syms[0]->scope == CONSTANTS);
      c = k->syms[0]->u.c.v.i;
      if (fmt[4]) {
        assert(fmt[4]=='%' && fmt[5]>='0' && fmt[5]<='9' && !fmt[6]);
        assert(kids[fmt[5]-'0'] && kids[fmt[5]-'0']->syms[RX]);
        r = kids[fmt[5]-'0']->syms[RX]->x.name;
      }
      if(c == 0) {
        print("LDI(0);");
      } else {
        int m = 0x80;
        int x = (c >= 0) ? c : -c;
        assert(x>=0 && x<256);
        while (m && !(m & x))
          m >>= 1;
        if (fmt[4] && c < 0)
          print("LDI(0);SUBW(%s);", r);
        else if (fmt[4])
          print("LDW(%s);", r);
        else if (c < 0)
          print("STW(T3);LDI(0);SUBW(T3);");
        else if (x & (m-1))
          print("STW(T3);");
        for (m >>= 1; m; m >>= 1) {
          print("LSLW();");
          if (m & x)
            print("%s(%s);", (c > 0) ? "ADDW" : "SUBW", r);
        }
      }
      return;
    }
  /* otherwise complain */
  assert(0);
}

static void doarg(Node p)
{
  /* Important change in arg passing:
     - When calling a function, all arguments beyond
       those specified in the prototype are written to the stack 
       in addition to being possibly passed in registers.
       In particular this happens for all arguments
       when calling a non prototyped function,
       and this happens for all supplementary arguments
       when the function has a variadic prototype.
     - When defining a function, prototyped or not,
       arguments are read from registers whenever possible.
     - The stdarg macros always read arguments from the stack.
  */
  static int argno;
  static int argmaxno;
  static int roffset;
  int offset;
  Symbol r;
  Node c;
  if (argoffset == 0) {
    argno = 0;
    argmaxno = 0;
    argoffset = 2;
    for (c=p; c; c=c->link)
      if (generic(c->op) == CALL ||
          (generic(c->op) == ASGN && generic(c->kids[1]->op) == CALL &&
           (c = c->kids[1]) ) )
        break;
    if (c && c->syms[0]->type->u.f.proto)
      while (c->syms[0]->type->u.f.proto[argmaxno] &&
             c->syms[0]->type->u.f.proto[argmaxno] != voidtype)
        argmaxno += 1;
  }
  r  = argreg(argno, optype(p->op), opsize(p->op), &roffset);
  offset = mkactual(p->syms[1]->u.c.v.i, p->syms[0]->u.c.v.i);
  p->x.argno = argno++;
  p->syms[2] = (r && p->x.argno < argmaxno) ? 0 : intconst(offset);
  if (optype(p->op) != B) /* keep alignment info for structures */
    p->syms[1] = r;
}

static void local(Symbol p)
{
  /* The size check restricts allocating registers for longs and
     floats local variables (but not temporaries). The register
     benefit for longs and floats is minimal. Best to heuristically
     keep enough of them for ints and pointers. */
  if (p->type->size > 2 && ! p->temporary)
    if (bitcount(vmask[IREG] & freemask[IREG]) < p->type->size)
      p->sclass = AUTO;
  if (askregvar(p, rmap(ttob(p->type))) == 0)
    mkauto(p);
}

static void printregmask(unsigned mask) {
  unsigned i, m;
  char *prefix = "R";
  for (i=0, m=1; i<31; i++, m<<=1)
    if (mask & m) {
      print("%s%d", prefix, i);
      prefix = ",";
      if (i<30 && (mask & (m+m))) {
        for (; i<30 && (mask & (m+m)); i++, m<<=1) {}
        print("-%d", i);
      }
    }
  if (!mask)
    print("None");
}

static void function(Symbol f, Symbol caller[], Symbol callee[], int ncalls)
{
  /* stack frame:
  |                    n bytes                   : arguments
  |    SP+Framesize -> 2 bytes                   : saved vLR
  |                    maxoffset bytes           : local variables
  |                    sizesave bytes            : saved registers
  |                    maxargoffset bytes        : argument building area
  |              SP -> 2 bytes                   : buffer where callees can save vLR
  **/

  int i, roffset, sizesave, ty;
  unsigned savemask;
  Symbol r;
  usedmask[0] = usedmask[1] = 0;
  freemask[0] = freemask[1] = ~(unsigned)0;
  offset = maxoffset = 0;
  maxargoffset = 2;
  assert(f->type && f->type->type);
  ty = ttob(f->type->type);
  if (ncalls) {
    tmask[IREG] = REGMASK_TEMPS;
    vmask[IREG] = REGMASK_SAVED;
  } else {
    tmask[IREG] = REGMASK_TEMPS;
    vmask[IREG] = REGMASK_MOREVARS;
  }
  /* locate incoming arguments */
  offset = 2;
  roffset = 0;
  for (i = 0; callee[i]; i++) {
    Symbol p = callee[i];
    Symbol q = caller[i];
    assert(q);
    offset = roundup(offset, q->type->align);
    p->x.offset = q->x.offset = offset;
    p->x.name = q->x.name = stringd(offset);
    r = argreg(i, optype(ttob(q->type)), q->type->size, &roffset);
    offset += q->type->size;
    if (r) {
      if (ncalls == 0 && !p->addressed && p->ref > 0) {
        /* Leaf function: leave register arguments in place */
        p->sclass = q->sclass = REGISTER;
        askregvar(p, r);
        assert(p->x.regnode && p->x.regnode->vbl == p);
        q->x = p->x;
        q->type = p->type;
      } else {
        /* Aggressively ask new registers for args passed in registers */
        if (!p->addressed && p->ref > 0)
          p->sclass = REGISTER;
        /* Let gencode know args were passed in register */
        q->sclass = REGISTER;
        q->x = r->x;
      }
    }
    if (p->sclass == REGISTER && !p->x.regnode && p->ref > 0) {
      /* Allocate register argument. Gencode does the rest. */
      askregvar(p, rmap(ttob(p->type)));
    }
  }
  /* gen code */
  assert(!caller[i]);
  offset = 0;
  gencode(caller, callee);
  /* compute framesize */
  savemask = usedmask[IREG] & REGMASK_SAVED;
  sizesave = 2 * bitcount(savemask);
  maxargoffset = (maxargoffset + 1) & ~0x1;
  maxoffset = (maxoffset + 1) & ~0x1;
  framesize = maxargoffset + sizesave + maxoffset;
  assert(framesize >= 2);
  /* can we make a frameless leaf function */
  if (ncalls == 0 && framesize == 2 && (tmask[IREG] & ~usedmask[IREG]))
    framesize = 0;
  /* prologue */
  xprint_init();
  segment(CODE);
  lprint("('%s', %s, code%d)", segname(), f->x.name, codenum);
  print("# ======== %s\n", lhead.prev->s);
  print("def code%d():\n", codenum++);
  print("\tlabel(%s);\n", f->x.name);
  if (framesize == 0) {
    print("\tPUSH();\n");
  } else {
    print("\t_PROLOGUE(%d,%d,0x%x); # save=", framesize, maxargoffset, savemask);
    printregmask(savemask);
    print("\n");
  }
  /* Emit actual code */
  emitcode();
  /* Epilogue */
  if (framesize == 0) {
    print("\ttryhop(2);POP();RET()\n");
  } else {
    const char *saveac = "";
    if (opsize(ty) <= 2 && (optype(ty) == I || optype(ty) == U || optype(ty) == P))
      saveac = ",saveAC=True";
    printf("\t_EPILOGUE(%d,%d,0x%x%s);\n", framesize, maxargoffset, savemask, saveac);
  }
  /* print delayed data */
  xprint_finish();
}

static void defconst(int suffix, int size, Value v)
{
  if (suffix == F) {
    double d = v.d;
    int exp;
    unsigned long mantissa;
    assert(size == 5);
    assert(isfinite(d));
    mantissa = (unsigned long)(frexp(fabs(d),&exp) * 4294967296.0 + 0.4999999995343387);
    if (exp < -127)
      mantissa = 0;
    if (mantissa == 0) 
      xprint("\tbytes(0,0,0,0,0);");
    else if (exp > 127)
      error("floating point constant overflow\n");
    else
      xprint("\tbytes(%d,%d,%d,%d,%d);",
             exp+128, ((mantissa>>24)&0x7f)|((d<0.0)?0x80:0x00),
             (mantissa>>16)&0xff, (mantissa>>8)&0xff, (mantissa&0xff) );
    xprint(" # %g\n", d);
  } else {
    unsigned long x = (suffix == P) ? (unsigned)(size_t)v.p : (suffix == I) ? v.i : v.u;
    if (size == 1) 
      print("\tbytes(%d);", x&0xff);
    else if (size == 2)
      print("\twords(%d);", x&0xffff);
    else if (size == 4)
      print("\twords(%d,%d);", x&0xffff, (x>>16)&0xffff);
    if (suffix == I)
      xprint(" # %D", (long)x);
    else if (suffix == U)
      xprint(" # %U", (unsigned long)x);
    xprint("\n");
  }
}

static void defaddress(Symbol p)
{
  xprint("\twords(%s);\n", p->x.name);
}

static void defstring(int n, char *str)
{
  int i;
  for (i=0; i<n; i++)
    xprint( ((i&7)==0) ? "\tbytes(%d" : ((i&7)==7) ? ",%d);\n" : ",%d", (int)str[i]&0xff );
  if (i&7)
    xprint(");\n");
}

static void import(Symbol p)
{
  if (p->ref > 0 && strncmp(p->x.name, "'__glink_weak_", 14) != 0)
    lprint("('IMPORT', %s)", p->x.name);
}

static void export(Symbol p)
{
  if (p->u.seg != BSS)
    lprint("('EXPORT', %s)", p->x.name);
}

static void defsymbol(Symbol p)
{
  if (p->scope >= LOCAL && p->sclass == STATIC)
    p->x.name = stringf("'.%d'", genlabel(1));
  else if (p->generated)
    p->x.name = stringf("'.%s'", p->name);
  else if (p->scope == GLOBAL || p->sclass == EXTERN)
    p->x.name = stringf("'%s'", p->name);
  else
    p->x.name = p->name;
}

static void address(Symbol q, Symbol p, long n)
{
  if (p->scope == GLOBAL || p->sclass == STATIC || p->sclass == EXTERN)
    q->x.name = stringf("v(%s)%s%D", p->x.name, n >= 0 ? "+" : "", n);
  else {
    assert(n <= INT_MAX && n >= INT_MIN);
    q->x.offset = p->x.offset + n;
    q->x.name = stringd(q->x.offset);
  }
}

static void global(Symbol p)
{
  unsigned int size = p->type->size;
  const char *s = segname();
  if (p->u.seg == BSS && p->sclass != STATIC)
    s = "COMMON";
  if (p->u.seg == LIT)
    size = 0; /* unreliable in switch tables */
  lprint("('%s', %s, code%d, %d, %d)",
          s, p->x.name, codenum, size, p->type->align);
  xprint("# ======== %s\n", lhead.prev->s);
  xprint("def code%d():\n", codenum++);
  if (p->type->align > 1)
    xprint("\talign(%d);\n", p->type->align);
  xprint("\tlabel(%s);\n", p->x.name);
  if (p->u.seg == BSS)
    xprint("\tspace(%d);\n", p->type->size);
}

static void segment(int n)
{
  cseg = n;
}

static void space(int n)
{
  if (cseg != BSS)
    xprint("\tspace(%d);\n", n);
}

Interface gigatronIR = {
        1, 1, 0,  /* char */
        2, 2, 0,  /* short */
        2, 2, 0,  /* int */
        4, 2, 1,  /* long */
        4, 2, 1,  /* long long */
        5, 1, 1,  /* float */
        5, 1, 1,  /* double */
        5, 1, 1,  /* long double */
        2, 2, 0,  /* pointer */
        0, 1, 0,  /* struct */
        1,        /* little_endian */
        0,        /* mulops_calls */
        0,        /* wants_callb */
        1,        /* wants_argb */
        1,        /* left_to_right */
        0,        /* wants_dag */
        1,        /* unsigned_char !!!! */
        1,        /* wants_cvfu_cvuf */
        address,
        blockbeg,
        blockend,
        defaddress,
        defconst,
        defstring,
        defsymbol,
        emit,
        export,
        function,
        gen,
        global,
        import,
        local,
        progbeg,
        progend,
        segment,
        space,
        /* stabblock, stabend, 0, stabinit, stabline, stabsym, stabtype */
        0, 0, 0, 0, 0, 0, 0,
        /* Xinterface */
        { 1,
          rmap,
          blkfetch, blkstore, blkloop,
          _label,
          _rule,
          _nts,
          _kids,
          _string,
          _templates,
          _isinstruction,
          _ntname,
          emit2,
          myemitfmt,
          doarg,
          target,
          clobber,
          preralloc,
        }
};

/*---- END CODE --*/

/* Local Variables: */
/* mode: c */
/* c-basic-offset: 2 */
/* indent-tabs-mode: () */
/* End: */
